<?php
/**
 * Category course widget class
 *
 * @since 2.8.0
 */


class nolez_widget_category_course extends WP_Widget {

    function __construct() {
        $widget_ops = array('classname' => 'widget_category_course', 'description' => esc_html__( "Category course on your site", 'nolez') );
        parent::__construct('category_course', esc_html__('Category Course', 'nolez'), $widget_ops);
        $this->alt_option_name = 'widget_category_course';

    }

    function widget($args, $instance) {
        $cache = wp_cache_get('nolez_widget_category_course', 'widget');

        if ( !is_array($cache) )
            $cache = array();

        if ( ! isset( $args['widget_id'] ) )
            $args['widget_id'] = $this->id;

        if ( isset( $cache[ $args['widget_id'] ] ) ) {
            echo wp_specialchars_decode(esc_attr($cache[ $args['widget_id'] ]));
            return;
        }

        ob_start();
        extract($args);

        $title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : esc_html__( 'Category course', 'nolez' );
        $title = apply_filters( 'widget_title', $title, $instance, $this->id_base );

        ?>
        <?php echo wp_specialchars_decode(esc_attr($before_widget),ENT_QUOTES); ?>
        <div class="sidebar-title">
            <h4><?php echo esc_attr($instance['title']); ?></h4>
        </div>
        <div class="sidebar-content categories">
            <ul>
                <?php  $categories = get_terms('category2'); 
                $i = 0;
                foreach( (array)$categories as $categorie){

                $cat_name = $categorie->name; 
                $cat_slug = $categorie->slug; 
                $cat_count = $categorie->count; 
                
                $i++;
                ?>
                <li><a href="<?php echo esc_url(home_url('/')); ?>?category2=<?php echo esc_attr($cat_slug);?>"><?php echo $cat_name ?></a></li>
                <?php } ?>
            </ul>
        </div>


        <?php echo wp_specialchars_decode(esc_attr($after_widget)); ?>
<?php
        // Reset the global $the_post as this query will have stomped on it
   

        $cache[$args['widget_id']] = ob_get_flush();
        wp_cache_set('nolez_widget_category_course', $cache, 'widget');
    }

    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);

        $alloptions = wp_cache_get( 'alloptions', 'options' );
        if ( isset($alloptions['widget_category_course']) )
            delete_option('widget_category_course');

        return $instance;
    }

    

    function form( $instance ) {
        $title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
?>
        <p><label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e( 'Title:', 'nolez' ); ?></label>
        <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_attr($title); ?>" /></p>

      
<?php
    }
}

function nolez_register5_custom_widgets() {
    register_widget( 'nolez_widget_category_course' );
}
add_action( 'widgets_init', 'nolez_register5_custom_widgets' );    