<?php
/**
 * Search Course widget class
 *
 * @since 2.8.0
 */

class nolez_widget_searchcourse extends WP_Widget {

    function __construct() {
        $widget_ops = array('classname' => 'widget_searchcourse', 'description' => esc_html__( "Search courses on your site", 'nolez') );
        parent::__construct('search', esc_html__('Search Course', 'nolez'), $widget_ops);
        $this->alt_option_name = 'widget_searchcourse';

    }

    function widget($args, $instance) {
        $cache = wp_cache_get('nolez_widget_searchcourse', 'widget');

        if ( !is_array($cache) )
            $cache = array();

        if ( ! isset( $args['widget_id'] ) )
            $args['widget_id'] = $this->id;

        if ( isset( $cache[ $args['widget_id'] ] ) ) {
            echo wp_specialchars_decode(esc_attr($cache[ $args['widget_id'] ]));
            return;
        }

        ob_start();
        extract($args);

        $title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : esc_html__( 'Search Course', 'nolez' );
        $title = apply_filters( 'widget_title', $title, $instance, $this->id_base );

        ?>
        <?php echo wp_specialchars_decode(esc_attr($before_widget),ENT_QUOTES); ?>
          <div class="fine-course-title">
            <h4><?php echo esc_attr($instance['title']); ?></h4>
          </div>
          <div class="short-search search-course">
            <form method="get" action="<?php echo esc_url( home_url( '/' ) );?>">
              <input type="hidden" name="post_type" value="course">
              <input type="search" class="field s" id="s" name="s" value="" placeholder="Search your course">
              <button type="submit"><i class="fas fa-search"></i></button>
            </form>
          </div>

        <?php echo wp_specialchars_decode(esc_attr($after_widget)); ?>
    <?php
        // Reset the global $the_post as this query will have stomped on it
   

        $cache[$args['widget_id']] = ob_get_flush();
        wp_cache_set('nolez_widget_searchcourse', $cache, 'widget');
    }

    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);

        $alloptions = wp_cache_get( 'alloptions', 'options' );
        if ( isset($alloptions['widget_searchcourse']) )
            delete_option('widget_searchcourse');

        return $instance;
    }

    function form( $instance ) {
        $title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
?>
        <p><label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e( 'Title:', 'nolez' ); ?></label>
        <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_attr($title); ?>" /></p>

      
<?php
    }
}


function nolez_register4_custom_widgets() {
    register_widget( 'nolez_widget_searchcourse' );
}
add_action( 'widgets_init', 'nolez_register4_custom_widgets' );  