<?php
/**
 * Plugin Name: Meta Box
 * Plugin URI:  https://metabox.io
 * Description: Create custom meta boxes and custom fields in WordPress.
 * Version:     5.3.3
 * Author:      MetaBox.io
 * Author URI:  https://metabox.io
 * License:     GPL2+
 * Text Domain: meta-box
 * Domain Path: /languages/
 *
 * @package Meta Box
 */

if ( defined( 'ABSPATH' ) && ! defined( 'RWMB_VER' ) ) {
    register_activation_hook( __file__, 'rwmb_check_php_version' );

    /**
     * Display notice for old PHP version.
     */
    function rwmb_check_php_version() {
        if ( version_compare( phpversion(), '5.3', '<' ) ) {
            die( esc_html__( 'Meta Box requires PHP version 5.3+. Please contact your host to upgrade.', 'meta-box' ) );
        }
    }




    require_once dirname( __file__ ) . '/inc/loader.php';
    $rwmb_loader = new RWMB_Loader();
    $rwmb_loader->init();


    add_filter( 'rwmb_meta_boxes', function ( $meta_boxes ) {

    $prefix = '_cmb_';


  // Open Code

    $meta_boxes[] = array(
        'id'         => 'post_setting',
        'title'      => 'Post Setting',
        'pages'      => array('post'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
            array(
                'name' => 'Featured Image 2',
                'desc' => 'Show in sidebar',
                'id'   => $prefix . 'featured_image_2',
                'type'    => 'single_image',
            ),
            array(
                'name' => 'Featured Image 3',
                'desc' => 'Show in blog grid',
                'id'   => $prefix . 'featured_image_3',
                'type'    => 'single_image',
            ),
            array(
                'name' => 'Link Video',
                'desc' => 'Input Link Video',
                'id'   => $prefix . 'video_link',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link Audio',
                'desc' => 'Input Link Audio',
                'id'   => $prefix . 'audio_link',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link facebook',
                'desc' => 'Input Link facebook',
                'id'   => $prefix . 'single_facebook',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link twitter',
                'desc' => 'Input Link twitter',
                'id'   => $prefix . 'single_twitter',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link Instagram',
                'desc' => 'Input Link Instagram',
                'id'   => $prefix . 'single_instagram',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link Youtube',
                'desc' => 'Input Link Youtube',
                'id'   => $prefix . 'single_youtube',
                'type'    => 'text',
            ),
        )
    );

    $meta_boxes[] = array(
        'id'         => 'instructor_setting',
        'title'      => 'Instructor Setting',
        'pages'      => array('instructor'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
            array(
                'name' => 'Information',
                'desc' => '',
                'id'   => $prefix . 'team_info',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link facebook',
                'desc' => 'Input Link facebook',
                'id'   => $prefix . 'team_facebook',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link twitter',
                'desc' => 'Input Link twitter',
                'id'   => $prefix . 'team_twitter',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link Behance',
                'desc' => 'Input Link Behance',
                'id'   => $prefix . 'team_behance',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link Youtube',
                'desc' => 'Input Link Youtube',
                'id'   => $prefix . 'team_youtube',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link Dribbble',
                'desc' => 'Input Link Dribbble',
                'id'   => $prefix . 'team_dribbble',
                'type'    => 'text',
            ),
        )
    );

    $meta_boxes[] = array(
        'id'         => 'event_setting',
        'title'      => 'Event Setting',
        'pages'      => array('event'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
            array(
                'name' => 'Date',
                'desc' => '',
                'id'   => $prefix . 'date',
                'type'    => 'text',
            ),
            array(
                'name' => 'Month',
                'desc' => '',
                'id'   => $prefix . 'month',
                'type'    => 'text',
            ),
            array(
                'name' => 'Year',
                'desc' => '',
                'id'   => $prefix . 'year',
                'type'    => 'text',
            ),
            array(
                'name' => 'Time',
                'desc' => '',
                'id'   => $prefix . 'time',
                'type'    => 'text',
            ),
            array(
                'name' => 'Address',
                'desc' => '',
                'id'   => $prefix . 'address',
                'type'    => 'text',
            ),
            array(
                'name' => 'Seats',
                'desc' => '',
                'id'   => $prefix . 'seat',
                'type'    => 'text',
            ),
            array(
                'name' => 'Price',
                'desc' => '',
                'id'   => $prefix . 'price',
                'type'    => 'text',
            ),
            array(
                'name' => 'Featured Image 2',
                'desc' => 'Show in sidebar',
                'id'   => $prefix . 'event_image',
                'type'    => 'single_image',
            ),
        )
    );

    $meta_boxes[] = array(
        'id'         => 'gallery_setting',
        'title'      => 'Gallery Setting',
        'pages'      => array('gallery'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
            array(
                'name' => 'Featured Image 2',
                'desc' => '',
                'id'   => $prefix . 'gallery_2',
                'type'    => 'single_image',
            ),    
        )
    );

    $meta_boxes[] = array(
        'id'         => 'course_setting',
        'title'      => 'Course Setting',
        'pages'      => array('course'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
            
            array(
                'name' => 'Instructor Image',
                'desc' => '',
                'id'   => $prefix . 'instructor_image',
                'type'    => 'single_image',
            ),  
            array(
                'name' => 'Profile',
                'desc' => '',
                'id'   => $prefix . 'profile',
                'type'    => 'textarea',
            ),
            array(
                'name' => 'Instructor name',
                'desc' => '',
                'id'   => $prefix . 'instructor',
                'type'    => 'text',
            ),
            array(
                'name' => 'Category Text',
                'desc' => '',
                'id'   => $prefix . 'category_text',
                'type'    => 'text',
            ),
            array(
                'name' => 'Category',
                'desc' => '',
                'id'   => $prefix . 'category_course',
                'type'    => 'text',
            ),
            array(
                'name' => 'Review Text',
                'desc' => '',
                'id'   => $prefix . 'review_text',
                'type'    => 'text',
            ),
            array(
                'name' => 'Select',
                'desc' => 'Select type show rating',
                'id'   => $prefix . 'course_select',
                'type'    => 'select',
                'options'   => array(
                    array( 'value' => 'one', 'name' => 'One Star' ),
                    array( 'value' => 'two', 'name' => 'Two Star' ),
                    array( 'value' => 'three', 'name' => 'Three Star' ),
                    array( 'value' => 'four', 'name' => 'Four Star' ),
                    array( 'value' => 'none', 'name' => 'Five Star'),
                    ),
            'placeholder'     => 'Select an Item',
                    ),
            array(
                'name' => 'Number of student',
                'desc' => '',
                'id'   => $prefix . 'number_student',
                'type'    => 'text',
            ),
            array(
                'name' => 'Time lesson',
                'desc' => '',
                'id'   => $prefix . 'time_course',
                'type'    => 'text',
            ),
            array(
                'name' => 'Price',
                'desc' => '',
                'id'   => $prefix . 'price_course',
                'type'    => 'text',
            ),
            array(
                'name' => 'Featured Image 2',
                'desc' => '',
                'id'   => $prefix . 'course_image',
                'type'    => 'single_image',
            ),  
            array(
                'name' => 'Featured Image 3',
                'desc' => '',
                'id'   => $prefix . 'course_image_3',
                'type'    => 'single_image',
            ),
        )
    );


    

    



// End Code
    return $meta_boxes;
});
}