<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsAbout extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-about';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'About', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'about' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_about',
			[
				'label' => esc_html__( 'About', 'bdevs-elementor' ),
			]	
		);

		$this->add_control(
			'chose_style',
			[
				'label'     => esc_html__( 'Chose Style', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'about_style_1'  => esc_html__( 'About Style 1', 'bdevs-elementor' ),
					'about_style_2' => esc_html__( 'About Style 2', 'bdevs-elementor' ),
				],
				'default'   => 'about_style_1',
			]
		);

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'It is heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'content',
			[
				'label'       => __( 'Content', 'bdevs-elementor' ),
				'type'        => Controls_Manager::WYSIWYG,
				'placeholder' => __( 'Enter your content', 'bdevs-elementor' ),
				'default'     => __( 'It is content', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_author',
			[
				'label' => esc_html__( 'Author', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'background_bg',
			[
				'label'   => esc_html__( 'Author Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'background_bg1',
			[
				'label'   => esc_html__( 'Signature Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_gallery',
			[
				'label' => esc_html__( 'Gallery', 'bdevs-elementor' ),
				'condition' => [
					'chose_style' => ['about_style_1']
				],
			]
		);

		$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'Gallery Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [
					[
						'name'    => 'tab_image',
						'label'   => esc_html__( 'Image', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'default'     => __( '', 'bdevs-elementor' ),
					],
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_image',
			[
				'label' => esc_html__( 'Image', 'bdevs-elementor' ),
				'condition' => [
					'chose_style' => ['about_style_2']
				],
			]
		);

		$this->add_control(
			'background_bg2',
			[
				'label'   => esc_html__( 'Big Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'background_bg3',
			[
				'label'   => esc_html__( 'Small Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
			]
		);

		$this->end_controls_section();

		/** 
		*	Layout section 
		**/
		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->add_control(
			'show_heading',
			[
				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_content',
			[
				'label'   => esc_html__( 'Show Content', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->add_control(
			'show_author',
			[
				'label'   => esc_html__( 'Show Author', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display();
		extract($settings);
		$chose_style = $settings['chose_style'];
		?>
		<?php if( $chose_style == 'about_style_1' ): ?>
		<!-- success area -->
		  <section class="success-area pb-130">
		    <div class="container">
		      <div class="row">
		        <!-- success image -->
		        <div class="col-xl-6 col-lg-6 col-md-6">
		          <div class="success-img">
		          	<?php 
		                foreach ( $settings['tabs'] as $item ) : 
					?>
		            <img src="<?php print esc_url($item['tab_image']['url']); ?>" alt="">
		            <?php endforeach; ?>
		          </div>
		        </div>
		        <!-- success content -->
		        <div class="col-xl-6 col-md-6">
		          <div class="success-content">
		          	<?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>
		            <h2><?php echo wp_kses_post($settings['heading']); ?></h2>
		            <?php endif; ?>
		            <?php if (( '' !== $settings['content'] ) && ( $settings['show_content'] )) : ?>
		            <?php echo wp_kses_post($settings['content']); ?>
		            <?php endif; ?>
		            <?php if ( $settings['show_author'] ) : ?>
		            <div class="success-author d-flex align-items-center">
		              <div class="success-author-img">
		                <img src="<?php print esc_url( $settings['background_bg']['url'] ); ?>" alt="Author">
		              </div>
		              <div class="success-author-sign">
		                <img src="<?php print esc_url( $settings['background_bg1']['url'] ); ?>" alt="">
		              </div>
		            </div>
		            <?php endif; ?>
		          </div>
		        </div>
		      </div>
		    </div>
		  </section>
		  <?php if (is_admin()) { ?>
    <script type="text/javascript">
    
        
           $('.success-img').slick({

    dots: false,

    arrows: true,

    prevArrow: '<button type="button" class="slick-prev"><i class="fas fa-long-arrow-alt-left"></i></button>',

    nextArrow: '<button type="button" class="slick-next"><i class="fas fa-long-arrow-alt-right"></i></button>',

    infinite: true,

    speed: 300,

    slidesToShow: 1,

    slidesToScroll: 1,

    responsive: [{

        breakpoint: 480,

        settings: {

          slidesToShow: 3,

          slidesToScroll: 3,

          infinite: true,

          dots: true

        }

      },

      {

        breakpoint: 480,

        settings: {

          slidesToShow: 1,

          slidesToScroll: 1

        }

      }

      // You can unslick at a given breakpoint now by adding:

      // settings: "unslick"

      // instead of a settings object

    ]

  });
        
        
    </script>   
    <?php } ?>
		  <!-- success area end -->
		  <?php elseif( $chose_style == 'about_style_2' ): ?>
		  <!-- About University -->
		  <section class="about-us-2 pt-130 pb-130">
		    <div class="container">
		      <div class="row">
		        <!-- About University Image -->
		        <div class="col-md-6 col-lg-5 offset-xl-1 pr-xl-0">
		          <div class="about-img-2 pb-55">
		            <div class="row no-gutters">
		              <div class="col-10">
		                <img src="<?php print esc_url( $settings['background_bg2']['url'] ); ?>" class="img-fluid" alt="University Image">
		              </div>
		            </div>
		            <div class="small-about-img">
		              <img src="<?php print esc_url( $settings['background_bg3']['url'] ); ?>" class="img-fluid" alt="University Image">
		            </div>
		          </div>
		        </div>
		        <div class="col-md-6 col-xl-5 offset-lg-1 pl-xl-0">
		          <div class="about-us-content-2 pr-55">
		            <div class="about-title-2 mb-35 pr-60">
		            <?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>
		            <h1><?php echo wp_kses_post($settings['heading']); ?></h1>
		            <?php endif; ?>
		            </div>
		            <?php if (( '' !== $settings['content'] ) && ( $settings['show_content'] )) : ?>
		            <?php echo wp_kses_post($settings['content']); ?>
		            <?php endif; ?>
		            <div class="about-author-area-2 mt-40 d-flex align-items-center">
		              <div class="a-author-img">
		                <img src="<?php print esc_url( $settings['background_bg']['url'] ); ?>" alt="Author Image">
		              </div>
		              <div class="a-author-sing-2">
		                <img src="<?php print esc_url( $settings['background_bg1']['url'] ); ?>" alt="Author Singnature">
		              </div>
		            </div>
		          </div>
		        </div>
		      </div>
		    </div>
		  </section>
		  <!-- About University End -->
		  <?php endif; ?>
	<?php
	}

}