<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsBlogPost extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-blog-post';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Blog', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-post-content';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'blog-post' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_content_heading',
			[
				'label' => esc_html__( 'Blog', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'chose_style',
			[
				'label'     => esc_html__( 'Chose Style', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'blog_style_1'  => esc_html__( 'Blog Style 1', 'bdevs-elementor' ),
					'blog_style_2' => esc_html__( 'Blog Style 2', 'bdevs-elementor' ),
					'blog_style_3' => esc_html__( 'Blog Style 3', 'bdevs-elementor' ),
				],
				'default'   => 'blog_style_1',
			]
		);

		$this->add_control(
			'background_bg',
			[
				'label'   => esc_html__( 'Background Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'     => __( 'It is heading', 'bdevs-elementor' ),
				'placeholder' => __( 'Enter your heading here...', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'subheading',
			[
				'label'       => __( 'Subheading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'     => __( 'It is subheading', 'bdevs-elementor' ),
				'placeholder' => __( 'Enter your subheading here...', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'button',
			[
				'label'       => __( 'Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Button', 'bdevs-elementor' ),
				'placeholder' => __( 'Enter your button', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'link_button',
			[
				'label'       => __( 'Link Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => __( '#', 'bdevs-elementor' ),
				'placeholder' => __( 'Link Button', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'post_number',
			[
				'label'     => esc_html__( 'Post Count', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your count', 'bdevs-elementor' ),
				'default'   => '3',
				'label_block' => true,
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);	

		$this->add_control(
			'show_heading',
			[
				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_subheading',
			[
				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_button',
			[
				'label'   => esc_html__( 'Show Button', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display(); 
		extract($settings);	
		$chose_style = $settings['chose_style'];
		$post_number = $settings['post_number'];

	    $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'post',  'orderby' => 'ID', 'order' => 'ASC'));
	   
	    //other style
	    $args = array('posts_per_page' => $post_number,'post_type' => 'post',  'orderby' => 'ID', 'order' => 'ASC'); ?>
	    <?php if( $chose_style == 'blog_style_1' ): ?>
	    <section class="latest-events-4-wrap home-2 pb-90" style="background: url(<?php print esc_url( $settings['background_bg']['url'] ); ?>);">
	        <div class="container">
	            <div class="row justify-content-center">
	                <div class="col-md-8 col-lg-7 col-xl-6">
	                    <!-- Section Title -->
	                    <div class="section-title-2 pr-20 text-center">
	                        <?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>
				            <h2><?php echo wp_kses_post($settings['heading']); ?></h2>
				            <?php endif; ?>
				            <?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>
				            <p><?php echo wp_kses_post($settings['subheading']); ?></p>
				            <?php endif; ?>
	                    </div>
	                </div>
	            </div>
	            <!-- Events Wrapper -->
	            <div class="row">
	            	<?php $j= 0;
		                $args = new \WP_Query(array(   
		                            'post_type' => 'post', 
		                        ));  
		                while ($wp_query -> have_posts()) : $wp_query -> the_post(); 
		               	$j++;
		            ?>
	                <!-- single news slide -->
	                <div class="col-xl-4 col-lg-4 mb-30">
	                    <div class="single-news-slide">
	                        <div class="news-slide-img"> <a href="<?php the_permalink(); ?>"><img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt="News"></a>
	                        	<?php if($j %3== 1){ ?>
					              <div class="tag">
					              	<?php 
			                            // Show all category for post
			                            $i = 1; foreach((get_the_category()) as $category) { 
			                            if ($i == 1){echo ''; }else {echo ', ';}
			                                echo '<a class="categories" >'.$category->category_nicename . ' '.'</a>'; 
			                                $i++;
			                        } ?>
			                       </div>
			            			<?php }elseif($j %3== 2){ ?>
			            			<div class="tag bg-2">
					              	<?php 
			                            // Show all category for post
			                            $i = 1; foreach((get_the_category()) as $category) { 
			                            if ($i == 1){echo ''; }else {echo ', ';}
			                                echo '<a class="categories" >'.$category->category_nicename . ' '.'</a>'; 
			                                $i++;
			                        } ?></div>

			                		<?php }else{ ?>
			                		<div class="tag bg-3">
					              	<?php 
			                            // Show all category for post
			                            $i = 1; foreach((get_the_category()) as $category) { 
			                            if ($i == 1){echo ''; }else {echo ', ';}
			                                echo '<a class="categories" >'.$category->category_nicename . ' '.'</a>'; 
			                                $i++;
			                        } ?></div>
			                    	<?php } ?>
	                        </div>
	                        <div class="news-slide-content home-2">
	                          <div class="news-meta mb-10"> <span><i class="far fa-user"></i> <?php the_author_posts_link(); ?></span> <span><i class="far fa-calendar-alt"></i> <?php the_time(get_option( 'date_format' ));?></span> </div>
	                            <h4><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>
	                            
	                            <div class="news-slide-text">
					                <p>	<?php if(isset($nolez_redux_demo['blog_excerpt_1'])){?>
						                <?php echo esc_attr(nolez1_excerpt($nolez_redux_demo['blog_excerpt_1'])); ?>
						                <?php }else{?>
						                <?php echo esc_attr(nolez1_excerpt(40)); 
						                ?> 
						            	<?php } ?>
						            </p>
					             </div>
								<div class="rd-more"> 
	                				<a class="b-btn" href="<?php the_permalink(); ?>">
		                				<?php if(isset($nolez_redux_demo['read_more'])){?>
		                                <?php echo wp_specialchars_decode(esc_attr($nolez_redux_demo['read_more']));?>
		                                <?php }else{?>
		                                <?php echo esc_html__( 'Read More', 'nolez' );?>
	                                	<?php } ?>
		                			</a>
								</div>
	                        </div>
	                    </div>
	                </div>
	                <!-- single news slide end -->
	                <?php   
				        endwhile; 
				        wp_reset_postdata();
				    ?>
	            </div>
	            <!-- Events Wrapper End -->
	        </div>
	    </section>
		  <?php elseif( $chose_style == 'blog_style_2' ): ?>
		  <!-- Latest news start -->
		  <section class="latest-events-4-wrap home-2 pb-90">
		    <div class="container">
		      <div class="row justify-content-between">
		        <div class="col-md-8 col-lg-7 col-xl-6">
		          <!-- Section Title -->
		          <div class="section-title-2 pr-20">
		            <?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>
		            <h2><?php echo wp_kses_post($settings['heading']); ?></h2>
		            <?php endif; ?>
		            <?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>
		            <p><?php echo wp_kses_post($settings['subheading']); ?></p>
		            <?php endif; ?>
		          </div>
		        </div>
		        <?php if (( '' !== $settings['button'] ) && ( $settings['show_button'] )) : ?>
		        <div class="col-md-4 col-xl-3">
		          <div class="upcoming-events-link-2 pt-35 text-right">
		            <a href="<?php echo wp_kses_post($settings['link_button']); ?>"><i class="fas fa-book"></i><?php echo wp_kses_post($settings['button']); ?></a>
		          </div>
		        </div>
		        <?php endif; ?>
		      </div>
		      <!-- Events Wrapper -->
		      <div class="latest-event-h2 custom-row">
		      	<?php $j= 0;
	                $args = new \WP_Query(array(   
	                            'post_type' => 'post', 
	                        ));  
	                while ($wp_query -> have_posts()) : $wp_query -> the_post(); 
	               	$j++;
	            ?>
		        <!-- single news slide -->
		        <div class="col-xl-6">
		          <div class="single-news-slide">
		            <div class="news-slide-img">
		              <a href="<?php the_permalink(); ?>"><img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt="News"></a>
		              <?php if($j == 1){ ?>
		              <div class="tag">
		              	<?php 
                            // Show all category for post
                            $i = 1; foreach((get_the_category()) as $category) { 
                            if ($i == 1){echo ''; }else {echo ', ';}
                                echo '<a class="categories" >'.$category->category_nicename . ' '.'</a>'; 
                                $i++;
                        } ?></div>
            			<?php }elseif($j == 2){ ?>
            			<div class="tag bg-2">
		              	<?php 
                            // Show all category for post
                            $i = 1; foreach((get_the_category()) as $category) { 
                            if ($i == 1){echo ''; }else {echo ', ';}
                                echo '<a class="categories" >'.$category->category_nicename . ' '.'</a>'; 
                                $i++;
                        } ?></div>

                		<?php }else{ ?>
                		<div class="tag bg-3">
		              	<?php 
                            // Show all category for post
                            $i = 1; foreach((get_the_category()) as $category) { 
                            if ($i == 1){echo ''; }else {echo ', ';}
                                echo '<a class="categories" >'.$category->category_nicename . ' '.'</a>'; 
                                $i++;
                        } ?></div>
                    	<?php } ?>
		            </div>
		            <div class="news-slide-content home-2">
		              <h4><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>
		              <div class="news-meta">
		                <span><i class="far fa-user"></i><?php the_author_posts_link(); ?></span>
		              	<span><i class="far fa-calendar-alt"></i><?php the_time(get_option( 'date_format' ));?></span>
		              </div>
		              <div class="news-slide-text">
		                <p>	<?php if(isset($nolez_redux_demo['blog_excerpt_1'])){?>
			                <?php echo esc_attr(nolez1_excerpt($nolez_redux_demo['blog_excerpt_1'])); ?>
			                <?php }else{?>
			                <?php echo esc_attr(nolez1_excerpt(40)); 
			                ?> 
			            	<?php } ?>
			            </p>
		              </div>
		              <div class="rd-more"> 
            				<a class="b-btn" href="<?php the_permalink(); ?>">
                				<?php if(isset($nolez_redux_demo['read_more'])){?>
                                <?php echo wp_specialchars_decode(esc_attr($nolez_redux_demo['read_more']));?>
                                <?php }else{?>
                                <?php echo esc_html__( 'Read More', 'nolez' );?>
                            	<?php } ?>
                			</a>
						</div>
		            </div>
		          </div>
		        </div>
		        <!-- single news slide end -->
		        <?php   
			        endwhile; 
			        wp_reset_postdata();
			    ?>
		      </div>
		      <!-- Events Wrapper End -->
		    </div>
		  </section>

		  <!-- Latest news End -->
		  <?php elseif( $chose_style == 'blog_style_3' ): ?>
		  <section class="home3-blog-area pb-90 pt-90" id="blog-section">
	        <div class="container">
	            <!-- home 3 blog bg -->
	            <div class="home3-blog-bg">
	                <!-- section title -->
	                <div class="row">
	                    <div class="col-xl-8 col-lg-10">
	                        <div class="section-title text-left baloo-title pr-0 pl-0">
	                            <?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>
					            <h2><?php echo wp_kses_post($settings['heading']); ?></h2>
					            <?php endif; ?>
					            <?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>
					            <p><?php echo wp_kses_post($settings['subheading']); ?></p>
					            <?php endif; ?>
	                        </div>
	                    </div>
	                </div>
	                <!-- blog content -->
	                <div class="row">
	                	<?php
			                $args = new \WP_Query(array(   
			                            'post_type' => 'post', 
			                        ));  
			                        while ($wp_query -> have_posts()) : $wp_query -> the_post(); 
			            ?>
			            <?php $featured_image_3 = get_post_meta(get_the_ID(),'_cmb_featured_image_3', true); ?>
	                    <!-- blog single item -->
	                    <div class="col-xl-6 col-lg-6 pb-35">
	                        <!--  second row -->
	                        <div class="row">
	                            <div class="col-md-5 col-12">
	                                <!-- blog img -->
	                                <div class="blog-single-item-img">
	                                    <img src="<?php echo wp_get_attachment_url($featured_image_3);?>" alt="blog img">
	                                </div>
	                            </div>
	                            <div class=" col-md-7 p-0">
	                                <!-- blog content -->
	                                <div class="blog-single-item-content">
	                                    <h2><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
	                                    <div class="blog-single-item-author d-flex">
	                                        <div class="blog-author-profile">
	                                            <a href="#"><i class="fa fa-user"></i> <span><?php the_author_posts_link(); ?></span></a>
	                                        </div>
	                                        <div class="blog-publish-date">
	                                            <p><i class="fa fa-calendar"></i> <span><?php the_time(get_option( 'date_format' ));?></span></p>
	                                        </div>
	                                    </div>
	                                    <p><?php if(isset($nolez_redux_demo['blog_excerpt_1'])){?>
						                <?php echo esc_attr(nolez1_excerpt($nolez_redux_demo['blog_excerpt_1'])); ?>
						                <?php }else{?>
						                <?php echo esc_attr(nolez1_excerpt(40)); 
						                ?> 
						            	<?php } ?></p>
	                                    <!-- blog author  -->
	                                    
	                                </div>
	                            </div>
	                        </div>
	                        <!-- second row -->
	                    </div>
	                    <?php   
					        endwhile; 
					        wp_reset_postdata();
					    ?>
	                </div>
	            </div>
	        </div>
	    </section>
		  <?php endif; ?>



<?php if (is_admin()) { ?>
    <script type="text/javascript">
    
        
           $('.latest-event-h2').slick({

    dots: false,

    infinite: true,

    autoplay: false,

    arrows: false,

    speed: 300,

    slidesToShow: 3,

    slidesToScroll: 1,

    responsive: [{

        breakpoint: 1500,

        settings: {

          arrows: true,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 3,

          slidesToScroll: 1

        }

      }, {

        breakpoint: 1350,

        settings: {

          arrows: false,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 3,

          slidesToScroll: 1

        }

      }, {

        breakpoint: 992,

        settings: {

          arrows: false,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 2,

          slidesToScroll: 1

        }

      }, {

        breakpoint: 768,

        settings: {

          arrows: false,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 1,

          slidesToScroll: 1

        }

      }

      // You can unslick at a given breakpoint now by adding:

      // settings: "unslick"

      // instead of a settings object

    ]

  });
        
        
    </script>   
    <?php } ?>
	<?php
	}
}