<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsContact extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-contact';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Contact', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'contact' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_content_heading',
			[
				'label' => esc_html__( 'Contact', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'chose_style',
			[
				'label'     => esc_html__( 'Chose Style', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'contact_style_1'  => esc_html__( 'Contact Style 1', 'bdevs-elementor' ),
					'contact_style_2' => esc_html__( 'Contact Style 2', 'bdevs-elementor' ),
				],
				'default'   => 'contact_style_1',
			]
		);

		$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'Contact Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [
					[
						'name'       => 'icon',
						'label'      => esc_html__( 'Icon', 'bdevs-elementor' ),
						'type'       => Controls_Manager::TEXT,
						'dynamic'    => [ 'active' => true ],
						'default'    => esc_html__( 'Icon', 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'       => 'title',
						'label'      => esc_html__( 'Title', 'bdevs-elementor' ),
						'type'       => Controls_Manager::TEXT,
						'dynamic'    => [ 'active' => true ],
						'default'    => esc_html__( 'Title', 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'       => 'info',
						'label'      => esc_html__( 'Information', 'bdevs-elementor' ),
						'type'       => Controls_Manager::TEXTAREA,
						'dynamic'    => [ 'active' => true ],
						'default'    => esc_html__( 'Information', 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_contact_2',
			[
				'label' => esc_html__( 'Contact Style 2', 'bdevs-elementor' ),
				'condition' => [
					'chose_style' => ['contact_style_2']
				],
			]
		);

		$this->add_control(
			'tabs2',
			[
				'label' => esc_html__( 'Contact Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [
					[
						'name'       => 'title',
						'label'      => esc_html__( 'Title', 'bdevs-elementor' ),
						'type'       => Controls_Manager::TEXT,
						'dynamic'    => [ 'active' => true ],
						'default'    => esc_html__( 'Title', 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'       => 'address',
						'label'      => esc_html__( 'Address', 'bdevs-elementor' ),
						'type'       => Controls_Manager::TEXTAREA,
						'dynamic'    => [ 'active' => true ],
						'default'    => esc_html__( 'Address', 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'       => 'email',
						'label'      => esc_html__( 'Email', 'bdevs-elementor' ),
						'type'       => Controls_Manager::TEXTAREA,
						'dynamic'    => [ 'active' => true ],
						'default'    => esc_html__( 'Email', 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'       => 'phone',
						'label'      => esc_html__( 'Phone', 'bdevs-elementor' ),
						'type'       => Controls_Manager::TEXTAREA,
						'dynamic'    => [ 'active' => true ],
						'default'    => esc_html__( 'Phone', 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);		

		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display(); 
		extract($settings);		
		$chose_style = $settings['chose_style'];
	   	?>
	   	<?php if( $chose_style == 'contact_style_1' ): ?>
	   	<!-- Contact info Area -->
		  <section class="contact-info-wrap">
		    <div class="container">
		      <div class="contact-details-area">
		        <div class="row justify-content-lg-between justify-content-xl-start">
	        	<?php $i= 0;
	                foreach ( $settings['tabs'] as $item ) : 
	                $i ++;
				?>
				<?php if($i == 1){ ?>
		          <!-- Single Contact Info -->
		          <div class="col-lg-4 col-xl-4 offset-xl-1 pl-xl-0 pr-lg-0">
		            <div class="single-c-details d-flex align-items-center mb-5 mb-lg-0">
		              <div class="details-icon">
		                <span><i class="<?php print wp_kses_post($item['icon']); ?>"></i></span>
		              </div>
		              <div class="details-text">
		                <h4><?php print wp_kses_post($item['title']); ?></h4>
		                <?php print wp_kses_post($item['info']); ?>
		              </div>
		            </div>
		          </div>
		          <!-- Single Contact Info End -->
		         <?php }elseif($i == 2){ ?>
		          <!-- Single Contact Info -->
		          <div class="col-lg-4 col-xl-3">
		            <div class="single-c-details d-flex align-items-center mb-5 mb-lg-0">
		              <div class="details-icon">
		                <span><i class="<?php print wp_kses_post($item['icon']); ?>"></i></span>
		              </div>
		              <div class="details-text">
		                <h4><?php print wp_kses_post($item['title']); ?></h4>
		                <?php print wp_kses_post($item['info']); ?>
		              </div>
		            </div>
		          </div>
		          <!-- Single Contact Info End -->
		         <?php }else{ ?>
		          <!-- Single Contact Info -->
		          <div class="col-lg-3 col-xl-3 offset-xl-1 pl-xl-0">
		            <div class="single-c-details d-flex align-items-center">
		              <div class="details-icon">
		                <span><i class="<?php print wp_kses_post($item['icon']); ?>"></i></span>
		              </div>
		              <div class="details-text">
		                <h4><?php print wp_kses_post($item['title']); ?></h4>
		                <?php print wp_kses_post($item['info']); ?>
		              </div>
		            </div>
		          </div>
		      	  <?php } ?>
		          <!-- Single Contact Info End -->
		          <?php endforeach; ?>
		        </div>
		      </div>
		    </div>
		  </section>
		  <!-- Contact info Area End -->
		  <?php elseif( $chose_style == 'contact_style_2' ): ?>
		  <section class="location-info-wrap pb-130">
		    <div class="container">
		      <div class="row">
		      	<?php $i= 0;
	                foreach ( $settings['tabs2'] as $item ) : 
	                $i ++;
				?>
				<?php if($i == 1){ ?>
		        <!-- Single Location Info -->
		        <div class="col-lg-6">
		          <div class="location-info mb-5 mb-lg-0">
		            <div class="info-title">
		              <h4><?php print wp_kses_post($item['title']); ?></h4>
		            </div>
		            <div class="location-text">
		              <p><i class="fas fa-map-marker-alt"></i><?php print wp_kses_post($item['address']); ?></p>
		              <p><i class="far fa-envelope-open"></i><?php print wp_kses_post($item['email']); ?></p>
		              <p><i class="fas fa-phone"></i><?php print wp_kses_post($item['phone']); ?></p>
		            </div>
		          </div>
		        </div>
		        <!-- Single Location Info End -->
		    	<?php }else{ ?>
		        <!-- Single Location Info -->
		        <div class="col-lg-6">
		          <div class="location-info">
		            <div class="info-title">
		              <h4><?php print wp_kses_post($item['title']); ?></h4>
		            </div>
		            <div class="location-text">
		              <p><i class="fas fa-map-marker-alt"></i><?php print wp_kses_post($item['address']); ?></p>
		              <p><i class="far fa-envelope-open"></i><?php print wp_kses_post($item['email']); ?></p>
		              <p><i class="fas fa-phone"></i><?php print wp_kses_post($item['phone']); ?></p>
		            </div>
		          </div>
		        </div>
		        <!-- Single Location Info End -->
		    	<?php } ?>
		        <?php endforeach; ?>
		      </div>
		    </div>
		  </section>
		  <?php endif; ?>
	<?php
	}

}