<?php

namespace BdevsElementor\Widget;



use Elementor\Controls_Manager;

use Elementor\Group_Control_Typography;

use Elementor\Scheme_Typography;

use Elementor\Group_Control_Border;

use Elementor\Group_Control_Box_Shadow;



/**

 * Bdevs Elementor Widget.

 *

 * Elementor widget that inserts an embbedable content into the page, from any given URL.

 *

 * @since 1.0.0

 */

class BdevsCourse extends \Elementor\Widget_Base {



	/**

	 * Get widget name.

	 *

	 * Retrieve Bdevs Elementor widget name.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget name.

	 */

	public function get_name() {

		return 'bdevs-course';

	}



	/**

	 * Get widget title.

	 *

	 * Retrieve Bdevs Elementor widget title.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget title.

	 */

	public function get_title() {

		return __( 'Course', 'bdevs-elementor' );

	}



	/**

	 * Get widget icon.

	 *

	 * Retrieve Bdevs Course widget icon.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget icon.

	 */

	public function get_icon() {

		return 'eicon-favorite';

	}



	/**

	 * Get widget categories.

	 *

	 * Retrieve the list of categories the Bdevs Course widget belongs to.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return array Widget categories.

	 */

	public function get_categories() {

		return [ 'bdevs-elementor' ];

	}



	public function get_keywords() {

		return [ 'course', 'carousel' ];

	}



	public function get_script_depends() {

		return [ 'bdevs-elementor'];

	}



	// BDT Position

	protected function element_pack_position() {

	    $position_options = [

	        ''              => esc_html__('Default', 'bdevs-elementor'),

	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,

	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,

	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,

	        'center'        => esc_html__('Center', 'bdevs-elementor') ,

	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,

	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,

	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,

	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,

	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,

	    ];



	    return $position_options;

	}



	protected function _register_controls() {

		$this->start_controls_section(

			'section_content_heading',

			[

				'label' => esc_html__( 'Course', 'bdevs-elementor' ),

			]

		);



		$this->add_control(

			'chose_style',

			[

				'label'     => esc_html__( 'Chose Style', 'bdevs-elementor' ),

				'type'      => Controls_Manager::SELECT,

				'options'   => [

					'course_style_1'  => esc_html__( 'Course Style 1', 'bdevs-elementor' ),

					'course_style_2' => esc_html__( 'Course Style 2', 'bdevs-elementor' ),

					'course_style_3' => esc_html__( 'Course Style 3', 'bdevs-elementor' ),

					'course_style_4' => esc_html__( 'Course Style 4', 'bdevs-elementor' ),

					'course_style_5' => esc_html__( 'Course Style 5', 'bdevs-elementor' ),

				],

				'default'   => 'course_style_1',

			]

		);



		$this->add_control(

			'heading',

			[

				'label'       => __( 'Heading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),

				'default'     => __( 'It is heading', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->add_control(

			'subheading',

			[

				'label'       => __( 'Subheading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your subheading', 'bdevs-elementor' ),

				'default'     => __( 'It is subheading', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->add_control(

			'post_number',

			[

				'label'     => esc_html__( 'Post Count', 'bdevs-elementor' ),

				'type'      => Controls_Manager::TEXT,

				'default'     => __( '6', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->end_controls_section();



		$this->start_controls_section(

			'section_content_heading_2',

			[

				'label' => esc_html__( 'Course Style 2', 'bdevs-elementor' ),

				'condition' => [

					'chose_style' => ['course_style_2']

				],

			]

		);



		$this->add_control(

			'background_bg',

			[

				'label'   => esc_html__( 'Background Image', 'bdevs-elementor' ),

				'type'    => Controls_Manager::MEDIA,

				'dynamic' => [ 'active' => true ],

				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),

			]

		);



		$this->end_controls_section();



		$this->start_controls_section(

			'section_content_heading_5',

			[

				'label' => esc_html__( 'Course Style 5', 'bdevs-elementor' ),

				'condition' => [

					'chose_style' => ['course_style_5']

				],

			]

		);



		$this->add_control(

			'background_bg_2',

			[

				'label'   => esc_html__( 'Background Image', 'bdevs-elementor' ),

				'type'    => Controls_Manager::MEDIA,

				'dynamic' => [ 'active' => true ],

				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),

			]

		);



		$this->end_controls_section();



		$this->start_controls_section(

			'section_content_heading_3',

			[

				'label' => esc_html__( 'Course Style 3', 'bdevs-elementor' ),

				'condition' => [

					'chose_style' => ['course_style_3']

				],

			]

		);



		$this->add_control(

			'tabs',

			[

				'label' => esc_html__( 'Course Items', 'bdevs-elementor' ),

				'type' => Controls_Manager::REPEATER,

				'fields' => [

					[

						'name'        => 'icon',

						'label'       => esc_html__( 'Icon', 'bdevs-elementor' ),

						'type'        => Controls_Manager::TEXT,

						'dynamic'     => [ 'active' => true ],

						'default'     => esc_html__( '' , 'bdevs-elementor' ),

						'label_block' => true,

					],

					[

						'name'        => 'title',

						'label'       => esc_html__( 'Title', 'bdevs-elementor' ),

						'type'        => Controls_Manager::TEXTAREA,

						'dynamic'     => [ 'active' => true ],

						'default'     => esc_html__( 'It is title ' , 'bdevs-elementor' ),

						'label_block' => true,

					],

					[

						'name'        => 'price',

						'label'       => esc_html__( 'Price', 'bdevs-elementor' ),

						'type'        => Controls_Manager::TEXT,

						'dynamic'     => [ 'active' => true ],

						'default'     => esc_html__( '$200' , 'bdevs-elementor' ),

						'label_block' => true,

					],

					[

						'name'        => 'link',

						'label'       => esc_html__( 'Link', 'bdevs-elementor' ),

						'type'        => Controls_Manager::TEXT,

						'dynamic'     => [ 'active' => true ],

						'default'     => esc_html__( '#' , 'bdevs-elementor' ),

						'label_block' => true,

					],

				],

			]

		);



		$this->end_controls_section();



		$this->start_controls_section(

			'section_content_layout',

			[

				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),

			]

		);



		$this->add_responsive_control(

			'align',

			[

				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),

				'type'    => Controls_Manager::CHOOSE,

				'options' => [

					'left' => [

						'title' => esc_html__( 'Left', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-left',

					],

					'center' => [

						'title' => esc_html__( 'Center', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-center',

					],

					'right' => [

						'title' => esc_html__( 'Right', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-right',

					],

					'justify' => [

						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-justify',

					],

				],

				'prefix_class' => 'elementor%s-align-',

				'description'  => 'Use align to match position',

				'default'      => 'left',

			]

		);



		$this->add_control(

			'show_heading',

			[

				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);			



		$this->add_control(

			'show_subheading',

			[

				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);	



		$this->end_controls_section();





	}



	public function render() {



		$settings  = $this->get_settings_for_display();

		extract($settings);

		$post_number = $settings['post_number'];

		$chose_style = $settings['chose_style'];

	    $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'course',  'orderby' => 'ID', 'order' => 'ASC'));

	   

	    //other style

	    $args = array('posts_per_page' => $post_number,'post_type' => 'course',  'orderby' => 'ID', 'order' => 'ASC');

		?>

		<?php if( $chose_style == 'course_style_1' ): ?>

		<section class="latest-course pt-125 pb-70">

		    <div class="container">

		      <!-- section title -->

		      <div class="row justify-content-center">

		        <div class="col-xl-8">

		          <div class="section-title text-center">

		          	<?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>

		            <h2><?php echo wp_kses_post($settings['heading']); ?></h2>

		            <?php endif; ?>

		            <?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>

		            <p><?php echo wp_kses_post($settings['subheading']); ?></p>

		            <?php endif; ?>

		          </div>

		        </div>

		      </div>

		      <div class="row">

		      	<?php

	                $args = new \WP_Query(array(   

	                            'post_type' => 'course', 

	                        ));  

	                        while ($wp_query -> have_posts()) : $wp_query -> the_post(); 

	            ?>

	            <?php $instructor_image = get_post_meta(get_the_ID(),'_cmb_instructor_image', true); ?>

	            <?php $course_image = get_post_meta(get_the_ID(),'_cmb_course_image', true); ?>

				<?php $instructor = get_post_meta(get_the_ID(),'_cmb_instructor', true); ?>

				<?php $profile = get_post_meta(get_the_ID(),'_cmb_profile', true); ?>

				<?php $number_student = get_post_meta(get_the_ID(),'_cmb_number_student', true); ?>

				<?php $course_select = get_post_meta(get_the_ID(),'_cmb_course_select', true); ?>

				<?php $time_course = get_post_meta(get_the_ID(),'_cmb_time_course', true); ?>

				<?php $price_course = get_post_meta(get_the_ID(),'_cmb_price_course', true); ?>

				<?php $category_course = get_post_meta(get_the_ID(),'_cmb_category_course', true); ?>

		        <!-- single latest course -->

		        <div class="col-xl-4 col-lg-4 col-md-6 col-sm-6">

		          <div class="single-lat-course">

		            <div class="lat-course-img">

		              <img src="<?php echo wp_get_attachment_url($course_image);?>" alt="Course-Image">

		              	<?php  $categories = get_the_terms(get_the_ID(),'category2');

	                        foreach( (array)$categories as $categorie){



	                        $cat_name = $categorie->name; 

	                        $cat_slug = $categorie->slug;

	                        ?>

		                <a href="#" class="course-tag"><?php echo esc_attr($cat_name);?></a>

		                <?php } ?>

		            </div>

		            <div class="lat-course-content">

		              <div class="rating">

		                  <?php  if ($course_select=='one') { ?>

		                  <span><i class="fas fa-star"></i></span>

		                  <?php } elseif ($course_select=='two') {?>

		                  <span><i class="fas fa-star"></i></span>

		                  <span><i class="fas fa-star"></i></span>

		                  <?php } elseif ($course_select=='three') {?>

		                  <span><i class="fas fa-star"></i></span>

		                  <span><i class="fas fa-star"></i></span>

		                  <span><i class="fas fa-star"></i></span>

		                  <?php } elseif ($course_select=='four') {?>

		                  <span><i class="fas fa-star"></i></span>

		                  <span><i class="fas fa-star"></i></span>

		                  <span><i class="fas fa-star"></i></span>

		                  <span><i class="fas fa-star"></i></span>

		                  <?php }else{ ?>

		                  <span><i class="fas fa-star"></i></span>

		                  <span><i class="fas fa-star"></i></span>

		                  <span><i class="fas fa-star"></i></span>

		                  <span><i class="fas fa-star"></i></span>

		                  <span><i class="fas fa-star"></i></span>

		              	  <?php } ?>

		              </div>

		              <div class="lat-course-title">

		                <h5><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h5>

		                <p><?php echo esc_attr($category_course);?></p>

		              </div>

		              <div class="lat-course-meta">

		                <span><i class="far fa-user"></i> <?php echo esc_attr($number_student);?></span>

		                <span><i class="far fa-clock"></i> <?php echo esc_attr($time_course);?></span>

		              </div>

		              <div class="lat-course-teacher d-flex align-items-center">

		                <div class="lat-teacher-img">

		                  <img src="<?php echo wp_get_attachment_url($instructor_image);?>" alt="Teacher">

		                </div>

		                <div class="lat-teacher-details">

		                  <h6><?php echo esc_attr($instructor);?></h6>

		                  <p><?php echo esc_attr($profile);?></p>

		                </div>

		              </div>

		              <div class="lat-course-footer d-flex justify-content-between">

		                <p>Price <span><?php echo esc_attr($price_course);?></span></p>

		                <a href="<?php the_permalink(); ?>"><i class="fas fa-tags"></i> 

	                	<?php if(isset($nolez_redux_demo['course_readmore'])){?>

		                <?php echo wp_specialchars_decode(esc_attr($nolez_redux_demo['course_readmore']));?>

		                <?php }else{?>

		                <?php echo esc_html__( 'Get Enrolled', 'nolez' );?>

		                <?php } ?></a>

		              </div>

		            </div>

		          </div>

		        </div>

		        <!-- single latest course end -->

		        <?php   

			        endwhile; 

			        wp_reset_postdata();

			    ?>

		      </div>

		    </div>

		  </section>

	    <?php elseif( $chose_style == 'course_style_2' ): ?>

	    <section class="testimonial-area home2-course pt-130 pb-70" style="background-image: url(<?php print esc_url( $settings['background_bg']['url'] ); ?>);">

		    <div class="container">

		      <!-- section title -->

		      <div class="row justify-content-center">

		        <div class="col-xl-8">

		          <div class="section-title white-text text-center">

		            <?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>

		            <h2><?php echo wp_kses_post($settings['heading']); ?></h2>

		            <?php endif; ?>

		            <?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>

		            <p><?php echo wp_kses_post($settings['subheading']); ?></p>

		            <?php endif; ?>

		          </div>

		        </div>

		      </div>

		      <div class="latest-course-4 home2">

		      	<?php

	                $args = new \WP_Query(array(   

	                            'post_type' => 'course', 

	                        ));  

	                        while ($wp_query -> have_posts()) : $wp_query -> the_post(); 

	            ?>

	            <?php $instructor_image = get_post_meta(get_the_ID(),'_cmb_instructor_image', true); ?>

	            <?php $course_select = get_post_meta(get_the_ID(),'_cmb_course_select', true); ?>

	            <?php $course_image = get_post_meta(get_the_ID(),'_cmb_course_image', true); ?>

				<?php $instructor = get_post_meta(get_the_ID(),'_cmb_instructor', true); ?>

				<?php $profile = get_post_meta(get_the_ID(),'_cmb_profile', true); ?>

				<?php $number_student = get_post_meta(get_the_ID(),'_cmb_number_student', true); ?>

				<?php $time_course = get_post_meta(get_the_ID(),'_cmb_time_course', true); ?>

				<?php $price_course = get_post_meta(get_the_ID(),'_cmb_price_course', true); ?>

				<?php $category_course = get_post_meta(get_the_ID(),'_cmb_category_course', true); ?>

		        <!-- single latest course -->

		        <div class="col-xl-4">

		          <div class="single-lat-course">

		            <div class="lat-course-img">

		              <img src="<?php echo wp_get_attachment_url($course_image);?>" alt="Course-Image">

		              	<?php  $categories = get_the_terms(get_the_ID(),'category2');

	                        foreach( (array)$categories as $categorie){



	                        $cat_name = $categorie->name; 

	                        $cat_slug = $categorie->slug;

	                        ?>

		                <a href="#" class="course-tag"><?php echo esc_attr($cat_name);?></a>

		                <?php } ?>

		            </div>

		            <div class="lat-course-content">

		              <div class="rating">

		                  <?php  if ($course_select=='one') { ?>

		                  <span><i class="fas fa-star"></i></span>

		                  <?php } elseif ($course_select=='two') {?>

		                  <span><i class="fas fa-star"></i></span>

		                  <span><i class="fas fa-star"></i></span>

		                  <?php } elseif ($course_select=='three') {?>

		                  <span><i class="fas fa-star"></i></span>

		                  <span><i class="fas fa-star"></i></span>

		                  <span><i class="fas fa-star"></i></span>

		                  <?php } elseif ($course_select=='four') {?>

		                  <span><i class="fas fa-star"></i></span>

		                  <span><i class="fas fa-star"></i></span>

		                  <span><i class="fas fa-star"></i></span>

		                  <span><i class="fas fa-star"></i></span>

		                  <?php }else{ ?>

		                  <span><i class="fas fa-star"></i></span>

		                  <span><i class="fas fa-star"></i></span>

		                  <span><i class="fas fa-star"></i></span>

		                  <span><i class="fas fa-star"></i></span>

		                  <span><i class="fas fa-star"></i></span>

		              	  <?php } ?>

		              </div>

		              <div class="lat-course-title">

		                <h5><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h5>

		                <p><?php echo esc_attr($category_course);?></p>

		              </div>

		              <div class="lat-course-meta">

		                <span><i class="far fa-user"></i> <?php echo esc_attr($number_student);?></span>

		                <span><i class="far fa-clock"></i> <?php echo esc_attr($time_course);?></span>

		              </div>

		              <div class="lat-course-teacher d-flex align-items-center">

		                <div class="lat-teacher-img">

		                  <img src="<?php echo wp_get_attachment_url($instructor_image);?>" alt="Teacher">

		                </div>

		                <div class="lat-teacher-details">

		                  <h6><?php echo esc_attr($instructor);?></h6>

		                  <p><?php echo esc_attr($profile);?></p>

		                </div>

		              </div>

		              <div class="lat-course-footer d-flex justify-content-between">

		                <p>Price <span><?php echo esc_attr($price_course);?></span></p>

		                <a href="<?php the_permalink(); ?>"><i class="fas fa-tags"></i> 

	                	<?php if(isset($nolez_redux_demo['course_readmore'])){?>

		                <?php echo wp_specialchars_decode(esc_attr($nolez_redux_demo['course_readmore']));?>

		                <?php }else{?>

		                <?php echo esc_html__( 'Get Enrolled', 'nolez' );?>

		                <?php } ?></a>

		              </div>

		            </div>

		          </div>

		        </div>

		        <!-- single latest course end -->

		        <?php   

			        endwhile; 

			        wp_reset_postdata();

			    ?>

		      </div>

		    </div>

		  </section>

		<?php elseif( $chose_style == 'course_style_3' ): ?>

		<section class="course-area pt-120 pb-130">

		    <div class="container">

		      <!-- section title -->

		      <div class="row justify-content-center">

		        <div class="col-xl-8 col-lg-10">

		          <div class="section-title text-center">

		            <?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>

		            <h2><?php echo wp_kses_post($settings['heading']); ?></h2>

		            <?php endif; ?>

		            <?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>

		            <p><?php echo wp_kses_post($settings['subheading']); ?></p>

		            <?php endif; ?>

		          </div>

		        </div>

		      </div>

		      <div class="course-slider custom-row">

		      	<?php $i=0;

                    foreach ( $settings['tabs'] as $item ) : 

                    $i++;

				?>

				<?php if($i == 1){ ?>

		        <!-- single course -->

		        <div class="col-xl-3 text-center">

		          <div class="single-course">

		            <div class="course-icon">

		              <span><i class="<?php print wp_kses_post($item['icon']); ?>"></i></span>

		            </div>

		            <div class="course-content">

		              <h5><a href="<?php print wp_kses_post($item['link']); ?>"><?php print wp_kses_post($item['title']); ?></a></h5>

		              <a href="<?php print wp_kses_post($item['link']); ?>" class="course-btn"><?php print wp_kses_post($item['price']); ?></a>

		            </div>

		          </div>

		        </div>

		        <!-- single course -->

		    	<?php }elseif($i == 2){ ?>

		        <!-- single course -->

		        <div class="col-xl-3 text-center course-2">

		          <div class="single-course">

		            <div class="course-icon">

		              <span><i class="<?php print wp_kses_post($item['icon']); ?>"></i></span>

		            </div>

		            <div class="course-content">

		              <h5><a href="<?php print wp_kses_post($item['link']); ?>"><?php print wp_kses_post($item['title']); ?></a></h5>

		              <a href="<?php print wp_kses_post($item['link']); ?>" class="course-btn"><?php print wp_kses_post($item['price']); ?></a>

		            </div>

		          </div>

		        </div>

		        <!-- single course -->

		    	<?php }elseif($i == 3){ ?>

		        <!-- single course -->

		        <div class="col-xl-3 text-center course-3">

		          <div class="single-course">

		            <div class="course-icon">

		              <span><i class="<?php print wp_kses_post($item['icon']); ?>"></i></span>

		            </div>

		            <div class="course-content">

		              <h5><a href="<?php print wp_kses_post($item['link']); ?>"><?php print wp_kses_post($item['title']); ?></a></h5>

		              <a href="<?php print wp_kses_post($item['link']); ?>" class="course-btn"><?php print wp_kses_post($item['price']); ?></a>

		            </div>

		          </div>

		        </div>

		        <!-- single course -->

		    	<?php }elseif($i == 4){ ?>

		        <!-- single course -->

		        <div class="col-xl-3 text-center course-4">

		          <div class="single-course">

		            <div class="course-icon">

		              <span><i class="<?php print wp_kses_post($item['icon']); ?>"></i></span>

		            </div>

		            <div class="course-content">

		              <h5><a href="<?php print wp_kses_post($item['link']); ?>"><?php print wp_kses_post($item['title']); ?></a></h5>

		              <a href="<?php print wp_kses_post($item['link']); ?>" class="course-btn"><?php print wp_kses_post($item['price']); ?></a>

		            </div>

		          </div>

		        </div>

		        <!-- single course -->

		    	<?php }else{ ?>

		        <!-- single course -->

		        <div class="col-xl-3 text-center course-5">

		          <div class="single-course">

		            <div class="course-icon">

		              <span><i class="<?php print wp_kses_post($item['icon']); ?>"></i></span>

		            </div>

		            <div class="course-content">

		              <h5><a href="<?php print wp_kses_post($item['link']); ?>"><?php print wp_kses_post($item['title']); ?></a></h5>

		              <a href="<?php print wp_kses_post($item['link']); ?>" class="course-btn"><?php print wp_kses_post($item['price']); ?></a>

		            </div>

		          </div>

		        </div>

		        <!-- single course -->

		    	<?php } ?>

		    	<?php endforeach; ?>

		      </div>

		    </div>

		  </section>

		  <?php elseif( $chose_style == 'course_style_4' ): ?>

		  <section class="latest-course-4-wrap pt-130 pb-130">

		    <div class="container">

		      <!-- Section Title -->

		      <div class="row justify-content-center text-center">

		        <div class="col-md-11 col-lg-8 col-xl-7">

		          <div class="section-title-4 pr-0 pr-xl-3 pl-0 pl-xl-3">

		            <?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>

		            <h2><?php echo wp_kses_post($settings['heading']); ?></h2>

		            <?php endif; ?>

		            <?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>

		            <p><?php echo wp_kses_post($settings['subheading']); ?></p>

		            <?php endif; ?>

		          </div>

		        </div>

		      </div>

		      <!-- Course Wrapper -->

		      <div class="latest-course-4 custom-row">

		      	<?php

	                $args = new \WP_Query(array(   

	                            'post_type' => 'course', 

	                        ));  

	                        while ($wp_query -> have_posts()) : $wp_query -> the_post(); 

	            ?>

	            <?php $course_image_3 = get_post_meta(get_the_ID(),'_cmb_course_image_3', true); ?>

				<?php $category_course = get_post_meta(get_the_ID(),'_cmb_category_course', true); ?>

		        <!-- Single Latest Course Start -->

		        <div class="col-xl-4">

		          <div class="sing-latest-course-4">

		            <div class="course-img-4">

		              <img src="<?php echo wp_get_attachment_url($course_image_3);?>" alt="Image">

		            </div>

		            <div class="course-content-4">

		              <div class="course-cat">

		              	<?php  $categories = get_the_terms(get_the_ID(),'category2');

	                        foreach( (array)$categories as $categorie){



	                        $cat_name = $categorie->name; 

	                        $cat_slug = $categorie->slug;

	                        ?>

		                <a href="#"><?php echo esc_attr($cat_name);?></a>

		                <?php } ?>

		              </div>

		              <div class="course-text">

		                <h4><?php the_title(); ?></h4>

		                <p><?php if(isset($nolez_redux_demo['course_excerpt'])){?>

			                <?php echo esc_attr(nolez2_excerpt($nolez_redux_demo['course_excerpt'])); ?>

			                <?php }else{?>

			                <?php echo esc_attr(nolez2_excerpt(40)); 

			                ?> 

			            	<?php } ?></p>

		              </div>

		              <div class="course-link">

		                <a href="<?php the_permalink(); ?>"><i class="fas fa-book"></i>

		                <?php if(isset($nolez_redux_demo['course_readmore'])){?>

		                <?php echo wp_specialchars_decode(esc_attr($nolez_redux_demo['course_readmore']));?>

		                <?php }else{?>

		                <?php echo esc_html__( 'apply now', 'nolez' );?>

		                <?php } ?></a>

		              </div>

		            </div>

		          </div>

		        </div>

		        <!-- Single Latest Course Start -->

		        <?php   

			        endwhile; 

			        wp_reset_postdata();

			    ?>

		      </div>

		      <!-- Course Wrapper End -->

		    </div>

		  </section>

		  <?php elseif( $chose_style == 'course_style_5' ): ?>

		  <section class="program-area home-3 pb-230" style="background-image: url(<?php print esc_url( $settings['background_bg_2']['url'] ); ?>);">

	        <div class="container">

	            <!-- section title -->

	            <div class="row justify-content-center">

	                <div class="col-xl-8 col-lg-10">

	                    <div class="section-title white-text text-center baloo-title">

	                        <?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>

				            <h2><?php echo wp_kses_post($settings['heading']); ?></h2>

				            <?php endif; ?>

				            <?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>

				            <p><?php echo wp_kses_post($settings['subheading']); ?></p>

				            <?php endif; ?>

	                    </div>

	                </div>

	            </div>



	            <div class="latest-event-h2">

	            	<?php

		                $args = new \WP_Query(array(   

		                            'post_type' => 'course', 

		                        ));  

		                        while ($wp_query -> have_posts()) : $wp_query -> the_post(); 

		            ?>

		            <?php $instructor_image = get_post_meta(get_the_ID(),'_cmb_instructor_image', true); ?>

					<?php $instructor = get_post_meta(get_the_ID(),'_cmb_instructor', true); ?>

					<?php $profile = get_post_meta(get_the_ID(),'_cmb_profile', true); ?>

					<?php $number_student = get_post_meta(get_the_ID(),'_cmb_number_student', true); ?>

					<?php $time_course = get_post_meta(get_the_ID(),'_cmb_time_course', true); ?>

					<?php $price_course = get_post_meta(get_the_ID(),'_cmb_price_course', true); ?>

					<?php $category_course = get_post_meta(get_the_ID(),'_cmb_category_course', true); ?>

		            <?php $course_image_3 = get_post_meta(get_the_ID(),'_cmb_course_image_3', true); ?>

		            <?php $course_select = get_post_meta(get_the_ID(),'_cmb_course_select', true); ?>

	                <!-- single latest course -->

	                <div class="col-xl-4 col-lg-4 col-md-6 col-sm-6">

	                    <div class="single-lat-course">

	                        <div class="lat-course-img">

	                            <img src="<?php echo wp_get_attachment_url($course_image_3);?>" alt="Course-Image">

	                            <div class="crs-tag">

	                            	<?php  $categories = get_the_terms(get_the_ID(),'category2');

				                        foreach( (array)$categories as $categorie){



				                        $cat_name = $categorie->name; 

				                        $cat_slug = $categorie->slug;

				                        ?>

					                <a href="#" class="course-tag"><?php echo esc_attr($cat_name);?></a>

					                <?php } ?>

					            </div>

	                        </div>

	                        <div class="lat-course-content">

	                            <div class="rating">

	                                  <?php  if ($course_select=='one') { ?>

					                  <span><i class="fas fa-star"></i></span>

					                  <?php } elseif ($course_select=='two') {?>

					                  <span><i class="fas fa-star"></i></span>

					                  <span><i class="fas fa-star"></i></span>

					                  <?php } elseif ($course_select=='three') {?>

					                  <span><i class="fas fa-star"></i></span>

					                  <span><i class="fas fa-star"></i></span>

					                  <span><i class="fas fa-star"></i></span>

					                  <?php } elseif ($course_select=='four') {?>

					                  <span><i class="fas fa-star"></i></span>

					                  <span><i class="fas fa-star"></i></span>

					                  <span><i class="fas fa-star"></i></span>

					                  <span><i class="fas fa-star"></i></span>

					                  <?php }else{ ?>

					                  <span><i class="fas fa-star"></i></span>

					                  <span><i class="fas fa-star"></i></span>

					                  <span><i class="fas fa-star"></i></span>

					                  <span><i class="fas fa-star"></i></span>

					                  <span><i class="fas fa-star"></i></span>

					              	  <?php } ?>

	                            </div>

	                            <div class="lat-course-title">

	                                <h5><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h5>

	                				<p><?php echo esc_attr($category_course);?></p>

	                            </div>

	                            <div class="lat-course-meta">

					                <span><i class="far fa-user"></i> <?php echo esc_attr($number_student);?></span>

					                <span><i class="far fa-clock"></i> <?php echo esc_attr($time_course);?></span>

					              </div>

					              <div class="lat-course-teacher d-flex align-items-center">

					                <div class="lat-teacher-img">

					                  <img src="<?php echo wp_get_attachment_url($instructor_image);?>" alt="Teacher">

					                </div>

					                <div class="lat-teacher-details">

					                  <h6><?php echo esc_attr($instructor);?></h6>

					                  <p><?php echo esc_attr($profile);?></p>

					                </div>

					              </div>

					              <div class="lat-course-footer d-flex justify-content-between">

					                <p>Price <span><?php echo esc_attr($price_course);?></span></p>

					                <a href="<?php the_permalink(); ?>"><i class="fas fa-tags"></i> 

				                	<?php if(isset($nolez_redux_demo['course_readmore'])){?>

					                <?php echo wp_specialchars_decode(esc_attr($nolez_redux_demo['course_readmore']));?>

					                <?php }else{?>

					                <?php echo esc_html__( 'Get Enrolled', 'nolez' );?>

					                <?php } ?></a>

					              </div>

	                        </div>

	                    </div>

	                </div>

	                <!-- single latest course end -->

	                <?php   

				        endwhile; 

				        wp_reset_postdata();

				    ?>

	            </div>

	        </div>

	    </section>

	    <?php endif; ?>


<?php if (is_admin()) { ?>
    <script type="text/javascript">
    		$('.course-slider').slick({

    dots: false,

    arrows: false,

    infinite: true,

    speed: 300,

    slidesToShow: 5,

    slidesToScroll: 5,

    responsive: [{

        breakpoint: 1200,

        settings: {

          arrows: false,

          dots: false,

          slidesToShow: 4,

          slidesToScroll: 1,

          infinite: true

        }

      },

      {

        breakpoint: 992,

        settings: {

          arrows: false,

          slidesToShow: 3,

          slidesToScroll: 1

        }

      },

      {

        breakpoint: 768,

        settings: {

          arrows: false,

          slidesToShow: 2,

          slidesToScroll: 1

        }

      },

      {

        breakpoint: 480,

        settings: {

          arrows: false,

          slidesToShow: 1,

          slidesToScroll: 1

        }

      }

      // You can unslick at a given breakpoint now by adding:

      // settings: "unslick"

      // instead of a settings object

    ]

  });
        
           $('.latest-course-4').slick({

    dots: false,

    infinite: true,

    autoplay: false,

    fade: false,

    prevArrow: '<button type="button" class="slick-prev"><i class="fas fa-chevron-left"></i></button>',

    nextArrow: '<button type="button" class="slick-next"><i class="fas fa-chevron-right"></i></button>',

    speed: 300,

    slidesToShow: 3,

    slidesToScroll: 1,

    responsive: [{

        breakpoint: 1500,

        settings: {

          arrows: true,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 3,

          slidesToScroll: 1

        }

      }, {

        breakpoint: 1350,

        settings: {

          arrows: false,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 3,

          slidesToScroll: 1

        }

      }, {

        breakpoint: 992,

        settings: {

          arrows: false,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 2,

          slidesToScroll: 1

        }

      }, {

        breakpoint: 768,

        settings: {

          arrows: false,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 1,

          slidesToScroll: 1

        }

      }

      // You can unslick at a given breakpoint now by adding:

      // settings: "unslick"

      // instead of a settings object

    ]

  });

  // Latest event slider

  $('.latest-event-h2').slick({

    dots: false,

    infinite: true,

    autoplay: false,

    arrows: false,

    speed: 300,

    slidesToShow: 3,

    slidesToScroll: 1,

    responsive: [{

        breakpoint: 1500,

        settings: {

          arrows: true,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 3,

          slidesToScroll: 1

        }

      }, {

        breakpoint: 1350,

        settings: {

          arrows: false,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 3,

          slidesToScroll: 1

        }

      }, {

        breakpoint: 992,

        settings: {

          arrows: false,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 2,

          slidesToScroll: 1

        }

      }, {

        breakpoint: 768,

        settings: {

          arrows: false,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 1,

          slidesToScroll: 1

        }

      }

      // You can unslick at a given breakpoint now by adding:

      // settings: "unslick"

      // instead of a settings object

    ]

  });



  //   Latest Events Slider

  $('.latest-events-4').slick({

    dots: false,

    infinite: true,

    autoplay: false,

    fade: false,

    prevArrow: '<button type="button" class="slick-prev"><i class="fas fa-chevron-left"></i></button>',

    nextArrow: '<button type="button" class="slick-next"><i class="fas fa-chevron-right"></i></button>',

    speed: 300,

    slidesToShow: 3,

    slidesToScroll: 1,

    responsive: [{

        breakpoint: 1500,

        settings: {

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 3,

          slidesToScroll: 1

        }

      }, {

        breakpoint: 992,

        settings: {

          arrows: false,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 2,

          slidesToScroll: 1

        }

      }, {

        breakpoint: 768,

        settings: {

          arrows: false,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 1,

          slidesToScroll: 1

        }

      }

      // You can unslick at a given breakpoint now by adding:

      // settings: "unslick"

      // instead of a settings object

    ]

  });
        
        
    </script>   
    <?php } ?>
	<?php

	}



}