<?php

namespace BdevsElementor\Widget;



use Elementor\Controls_Manager;

use Elementor\Group_Control_Typography;

use Elementor\Scheme_Typography;

use Elementor\Group_Control_Border;

use Elementor\Group_Control_Box_Shadow;



/**

 * Bdevs Elementor Widget.

 *

 * Elementor widget that inserts an embbedable content into the page, from any given URL.

 *

 * @since 1.0.0

 */

class BdevsEvent extends \Elementor\Widget_Base {



	/**

	 * Get widget name.

	 *

	 * Retrieve Bdevs Elementor widget name.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget name.

	 */

	public function get_name() {

		return 'bdevs-event';

	}



	/**

	 * Get widget title.

	 *

	 * Retrieve Bdevs Elementor widget title.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget title.

	 */

	public function get_title() {

		return __( 'Event', 'bdevs-elementor' );

	}



	/**

	 * Get widget icon.

	 *

	 * Retrieve Bdevs Event widget icon.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget icon.

	 */

	public function get_icon() {

		return 'eicon-favorite';

	}



	/**

	 * Get widget categories.

	 *

	 * Retrieve the list of categories the Bdevs Event widget belongs to.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return array Widget categories.

	 */

	public function get_categories() {

		return [ 'bdevs-elementor' ];

	}



	public function get_keywords() {

		return [ 'event' ];

	}



	public function get_script_depends() {

		return [ 'bdevs-elementor'];

	}



	protected function _register_controls() {





		$this->start_controls_section(

			'section_content_heading',

			[

				'label' => esc_html__( 'Event', 'bdevs-elementor' ),

			]

		);



		$this->add_control(

			'chose_style',

			[

				'label'     => esc_html__( 'Chose Style', 'bdevs-elementor' ),

				'type'      => Controls_Manager::SELECT,

				'options'   => [

					'event_style_1' => esc_html__( 'Event Style 1', 'bdevs-elementor' ),

					'event_style_2' => esc_html__( 'Event Style 2', 'bdevs-elementor' ),

					'event_style_3' => esc_html__( 'Event Style 3', 'bdevs-elementor' ),

					'event_style_4' => esc_html__( 'Event Style 4', 'bdevs-elementor' ),

					'event_style_5' => esc_html__( 'Event Style 5', 'bdevs-elementor' ),

				],

				'default'   => 'event_style_1',

			]

		);

		

		$this->add_control(

			'heading',

			[

				'label'       => __( 'Heading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),

				'default'     => __( 'It is heading', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->add_control(

			'subheading',

			[

				'label'       => __( 'Subheading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your subheading', 'bdevs-elementor' ),

				'default'     => __( 'It is subheading', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->add_control(

			'button',

			[

				'label'       => __( 'Button', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'default'     => __( 'Button', 'bdevs-elementor' ),

				'placeholder' => __( 'Enter your button', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);	



		$this->add_control(

			'link_button',

			[

				'label'       => __( 'Link Button', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'default'     => __( '#', 'bdevs-elementor' ),

				'placeholder' => __( 'Link Button', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);	



		$this->add_control(

			'post_number',

			[

				'label'     => esc_html__( 'Event Count', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'placeholder' => __( 'Enter your count', 'bdevs-elementor' ),

				'default'   => '4',

				'label_block' => true,

			]

		);



		$this->end_controls_section();



		$this->start_controls_section(

			'section_content_heading_2',

			[

				'label' => esc_html__( 'Style 2', 'bdevs-elementor' ),

				'condition' => [

					'chose_style' => ['event_style_2']

				],

			]

		);



		$this->add_control(

			'background_bg',

			[

				'label'   => esc_html__( 'Background Image', 'bdevs-elementor' ),

				'type'    => Controls_Manager::MEDIA,

				'dynamic' => [ 'active' => true ],

				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),

			]

		);



		$this->end_controls_section();



		$this->start_controls_section(

			'section_content_heading_4',

			[

				'label' => esc_html__( 'Style 4', 'bdevs-elementor' ),

				'condition' => [

					'chose_style' => ['event_style_4']

				],

			]

		);



		$this->add_control(

			'background_bg_4',

			[

				'label'   => esc_html__( 'Background Image', 'bdevs-elementor' ),

				'type'    => Controls_Manager::MEDIA,

				'dynamic' => [ 'active' => true ],

				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),

			]

		);



		$this->end_controls_section();





		$this->start_controls_section(

			'section_content_layout',

			[

				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),

			]

		);



		$this->add_responsive_control(

			'align',

			[

				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),

				'type'    => Controls_Manager::CHOOSE,

				'options' => [

					'left' => [

						'title' => esc_html__( 'Left', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-left',

					],

					'center' => [

						'title' => esc_html__( 'Center', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-center',

					],

					'right' => [

						'title' => esc_html__( 'Right', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-right',

					],

					'justify' => [

						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-justify',

					],

				],

				'prefix_class' => 'elementor%s-align-',

				'description'  => 'Use align to match position',

				'default'      => 'left',

			]

		);



		$this->add_control(

			'show_heading',

			[

				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);	



		$this->add_control(

			'show_subheading',

			[

				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);	



		$this->add_control(

			'show_button',

			[

				'label'   => esc_html__( 'Show Button', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);	



		$this->end_controls_section();



	}



	public function render() {

	$settings  = $this->get_settings_for_display(); 

	extract($settings);

	$chose_style = $settings['chose_style'];

	$post_number = $settings['post_number'];



    $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'event',  'orderby' => 'ID', 'order' => 'ASC'));

   

    //other style

    $args = array('posts_per_page' => $post_number,'post_type' => 'event',  'orderby' => 'ID', 'order' => 'ASC');	

	?>

	<?php if( $chose_style == 'event_style_1' ): ?>

	<section class="latest-events-4-wrap gray-bg evnt-page home-2 pb-110">

	    <div class="container">

	      <div class="row justify-content-between">

	        <div class="col-md-8 col-lg-7 col-xl-6">

	          <!-- Section Title -->

	          <div class="section-title-2 pt-20 evnt-page">

	            <?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>

	            <h2><?php echo wp_kses_post($settings['heading']); ?></h2>

	            <?php endif; ?>

            	<?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>

	            <p><?php echo wp_kses_post($settings['subheading']); ?></p>

	            <?php endif; ?>

	          </div>

	        </div>

	        <?php if (( '' !== $settings['button'] ) && ( $settings['show_button'] )) : ?>

	        <div class="col-md-4 col-xl-3">

	          <div class="upcoming-events-link-2 text-right">

	            <a href="<?php echo wp_kses_post($settings['link_button']); ?>"><i class="fas fa-book"></i><?php echo wp_kses_post($settings['button']); ?></a>

	          </div>

	        </div>

	        <?php endif; ?>

	      </div>

	      <!-- Events Wrapper -->

	      <div class="latest-course-4 custom-row">

	      	<?php

                $args = new \WP_Query(array(   

                            'post_type' => 'event', 

                        ));  

                        while ($wp_query -> have_posts()) : $wp_query -> the_post(); 

            ?>

			<?php $date = get_post_meta(get_the_ID(),'_cmb_date', true); ?>

			<?php $month = get_post_meta(get_the_ID(),'_cmb_month', true); ?>

	        <!-- Single Events Start -->

	        <div class="col-xl-4">

	          <div class="single-latest-event-4">

	            <div class="events-img-4">

	              <img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt="Events Image">

	              <div class="events-meta">

	                <span><?php echo wp_specialchars_decode(esc_attr($date)); ?></span>

	                <p><?php echo wp_specialchars_decode(esc_attr($month)); ?></p>

	              </div>

	            </div>

	            <div class="events-content-4">

	              <h4><?php the_title(); ?></h4>

	              <div class="latest-event-link-4">

	                <a href="<?php the_permalink(); ?>"><i class="fas fa-book"></i>

	                	<?php if(isset($nolez_redux_demo['event_readmore'])){?>

		                <?php echo wp_specialchars_decode(esc_attr($nolez_redux_demo['event_readmore']));?>

		                <?php }else{?>

		                <?php echo esc_html__( 'join event', 'nolez' );?>

		                <?php } ?>

		            </a>

	              </div>

	            </div>

	          </div>

	        </div>

	        <!-- Single Events Start End -->

	        <?php   

		        endwhile; 

		        wp_reset_postdata();

		    ?>

	      </div>

	      <!-- Events Wrapper End -->

	    </div>

	</section>
	<?php if (is_admin()) { ?>
    <script type="text/javascript">
    
        
           $('.latest-course-4').slick({

    dots: false,

    infinite: true,

    autoplay: false,

    fade: false,

    prevArrow: '<button type="button" class="slick-prev"><i class="fas fa-chevron-left"></i></button>',

    nextArrow: '<button type="button" class="slick-next"><i class="fas fa-chevron-right"></i></button>',

    speed: 300,

    slidesToShow: 3,

    slidesToScroll: 1,

    responsive: [{

        breakpoint: 1500,

        settings: {

          arrows: true,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 3,

          slidesToScroll: 1

        }

      }, {

        breakpoint: 1350,

        settings: {

          arrows: false,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 3,

          slidesToScroll: 1

        }

      }, {

        breakpoint: 992,

        settings: {

          arrows: false,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 2,

          slidesToScroll: 1

        }

      }, {

        breakpoint: 768,

        settings: {

          arrows: false,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 1,

          slidesToScroll: 1

        }

      }

      // You can unslick at a given breakpoint now by adding:

      // settings: "unslick"

      // instead of a settings object

    ]

  });
        
        
    </script>   
    <?php } ?>
    <?php elseif( $chose_style == 'event_style_2' ): ?>

    <section class="latest-events-4-wrap bg-2 evnt-page home-2 pb-110"

    style="background-image: url(<?php print esc_url( $settings['background_bg']['url'] ); ?>);">

	    <div class="container">

	      <div class="row justify-content-between">

	        <div class="col-md-8 col-lg-7 col-xl-6">

	          <!-- Section Title -->

	          <div class="section-title-2 pt-20 white-text evnt-page">

	            <?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>

	            <h2><?php echo wp_kses_post($settings['heading']); ?></h2>

	            <?php endif; ?>

	          </div>

	        </div>

	        <?php if (( '' !== $settings['button'] ) && ( $settings['show_button'] )) : ?>

	        <div class="col-md-4 col-xl-3">

	          <div class="upcoming-events-link-2 text-right">

	            <a href="<?php echo wp_kses_post($settings['link_button']); ?>"><i class="fas fa-book"></i><?php echo wp_kses_post($settings['button']); ?></a>

	          </div>

	        </div>

	        <?php endif; ?>

	      </div>

	      <!-- Events Wrapper -->

	      <div class="latest-course-5 custom-row">

	      	<?php

                $args = new \WP_Query(array(   

                            'post_type' => 'event', 

                        ));  

                        while ($wp_query -> have_posts()) : $wp_query -> the_post(); 

            ?>

			<?php $date = get_post_meta(get_the_ID(),'_cmb_date', true); ?>

			<?php $month = get_post_meta(get_the_ID(),'_cmb_month', true); ?>

	        <!-- Single Events Start -->

	        <div class="col-xl-4">

	          <div class="single-latest-event-4">

	            <div class="events-img-4">

	              <img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt="Events Image">

	              <div class="events-meta">

	                <span><?php echo wp_specialchars_decode(esc_attr($date)); ?></span>

	                <p><?php echo wp_specialchars_decode(esc_attr($month)); ?></p>

	              </div>

	            </div>

	            <div class="events-content-4">

	              <h4><?php the_title(); ?></h4>

	              <div class="latest-event-link-4">

	                <a href="<?php the_permalink(); ?>"><i class="fas fa-book"></i>

	                	<?php if(isset($nolez_redux_demo['event_readmore'])){?>

		                <?php echo wp_specialchars_decode(esc_attr($nolez_redux_demo['event_readmore']));?>

		                <?php }else{?>

		                <?php echo esc_html__( 'join event', 'nolez' );?>

		                <?php } ?>

		            </a>

	              </div>

	            </div>

	          </div>

	        </div>

	        <!-- Single Events Start End -->

	        <?php   

		        endwhile; 

		        wp_reset_postdata();

		    ?>

	      </div>

	      <!-- Events Wrapper End -->

	    </div>

	</section>
	<?php if (is_admin()) { ?>
    <script type="text/javascript">
    
        
           $('.latest-course-5').slick({

    dots: false,

    infinite: true,

    autoplay: false,

    fade: false,

    prevArrow: '<button type="button" class="slick-prev"><i class="fas fa-chevron-left"></i></button>',

    nextArrow: '<button type="button" class="slick-next"><i class="fas fa-chevron-right"></i></button>',

    speed: 300,

    slidesToShow: 3,

    slidesToScroll: 1,

    responsive: [{

        breakpoint: 1500,

        settings: {

          arrows: true,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 3,

          slidesToScroll: 1

        }

      }, {

        breakpoint: 1350,

        settings: {

          arrows: false,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 3,

          slidesToScroll: 1

        }

      }, {

        breakpoint: 992,

        settings: {

          arrows: false,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 2,

          slidesToScroll: 1

        }

      }, {

        breakpoint: 768,

        settings: {

          arrows: false,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 1,

          slidesToScroll: 1

        }

      }

      // You can unslick at a given breakpoint now by adding:

      // settings: "unslick"

      // instead of a settings object

    ]

  });
        
        
    </script>   
    <?php } ?>
	<?php elseif( $chose_style == 'event_style_3' ): ?>

	<section class="upcoming-events-2 pt-130 pb-110">

	    <div class="container">

	      <div class="row justify-content-between">

	        <div class="col-md-8 col-lg-7 col-xl-6">

	          <!-- Section Title -->

	          <div class="section-title-2 pr-20">

	            <?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>

	            <h2><?php echo wp_kses_post($settings['heading']); ?></h2>

	            <?php endif; ?>

            	<?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>

	            <p><?php echo wp_kses_post($settings['subheading']); ?></p>

	            <?php endif; ?>

	          </div>

	        </div>

	        <?php if (( '' !== $settings['button'] ) && ( $settings['show_button'] )) : ?>

	        <div class="col-md-4 col-xl-3">

	          <div class="upcoming-events-link-2 pt-35 text-right">

	            <a href="<?php echo wp_kses_post($settings['link_button']); ?>"><i class="fas fa-book"></i><?php echo wp_kses_post($settings['button']); ?></a>

	          </div>

	        </div>

	        <?php endif; ?>

	      </div>

	      <div class="row justify-content-center">

	      	<?php $i =0;

                $args = new \WP_Query(array(   

                            'post_type' => 'event', 

                        ));  

                        while ($wp_query -> have_posts()) : $wp_query -> the_post(); 

                        $i ++;

            ?>

            <?php $address = get_post_meta(get_the_ID(),'_cmb_address', true); ?>

			<?php $date = get_post_meta(get_the_ID(),'_cmb_date', true); ?>

			<?php $month = get_post_meta(get_the_ID(),'_cmb_month', true); ?>

			<?php $year = get_post_meta(get_the_ID(),'_cmb_year', true); ?>

			<?php $time = get_post_meta(get_the_ID(),'_cmb_time', true); ?>

			<?php $seat = get_post_meta(get_the_ID(),'_cmb_seat', true); ?>

			<?php if($i % 3 == 1 ){ ?>

	        <!-- Single Upcoming Events -->

	        <div class="col-md-8 col-lg-12">

	          <div class="sing-upcoming-events mb-20 d-block d-lg-flex align-items-center justify-content-between">

	            <div class="upcoming-event-content d-block d-lg-flex align-items-center">

	              <div class="upcoming-event-img mb-3 mb-lg-0">

	                <img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt="Upcoming Event">

	              </div>

	              <div class="upcoming-event-text mb-md-4 mb-lg-0 pr-20">

	              	<?php  $categories = get_the_terms(get_the_ID(),'category1');

	                        foreach( (array)$categories as $categorie){



	                        $cat_name = $categorie->name; 

	                        $cat_slug = $categorie->slug;

	                        ?>

	                <a href="#" class="bg-primary"><?php echo esc_attr($cat_name);?></a>

	                <?php } ?>

	                <h4><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>

	                <div class="u-event-meta">

	                  <p><span><i class="fas fa-map-marker-alt"></i><?php echo esc_attr($address);?></span><span><i

	                        class="far fa-calendar-alt"></i><?php echo esc_attr($date);?> <?php echo esc_attr($month);?> <?php echo esc_attr($year);?></span></p>

	                  <p><span><i class="far fa-clock"></i><?php echo esc_attr($time);?></span><span><i

	                        class="fas fa-tags"></i><?php echo esc_attr($seat);?></span></p>

	                </div>

	              </div>

	            </div>

	            <div class="upcoming-link">

	              <a href="<?php the_permalink(); ?>" class="default-btn"><i class="fas fa-book"></i>  <?php if(isset($nolez_redux_demo['event_readmore'])){?>

		                <?php echo wp_specialchars_decode(esc_attr($nolez_redux_demo['event_readmore']));?>

		                <?php }else{?>

		                <?php echo esc_html__( 'join event', 'nolez' );?>

		                <?php } ?></a>

	            </div>

	          </div>

	        </div>

	        <!-- Single Upcoming Events End -->

	    	<?php }elseif($i % 3 == 2){ ?>

	        <!-- Single Upcoming Events -->

	        <div class="col-md-8 col-lg-12">

	          <div class="sing-upcoming-events mb-20 d-block d-lg-flex align-items-center justify-content-between">

	            <div class="upcoming-event-content d-block d-lg-flex align-items-center">

	              <div class="upcoming-event-img mb-3 mb-lg-0">

	                <img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt="Upcoming Event">

	              </div>

	              <div class="upcoming-event-text mb-md-4 mb-lg-0 pr-20">

	              	<?php  $categories = get_the_terms(get_the_ID(),'category1');

	                        foreach( (array)$categories as $categorie){



	                        $cat_name = $categorie->name; 

	                        $cat_slug = $categorie->slug;

	                        ?>

	                <a href="#" class="bg-warning"><?php echo esc_attr($cat_name);?></a>

	                <?php } ?>

	                <h4><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>

	                <div class="u-event-meta">

	                  <p><span><i class="fas fa-map-marker-alt"></i><?php echo esc_attr($address);?></span><span><i

	                        class="far fa-calendar-alt"></i><?php echo esc_attr($date);?> <?php echo esc_attr($month);?> <?php echo esc_attr($year);?></span></p>

	                  <p><span><i class="far fa-clock"></i><?php echo esc_attr($time);?></span><span><i

	                        class="fas fa-tags"></i><?php echo esc_attr($seat);?></span></p>

	                </div>

	              </div>

	            </div>

	            <div class="upcoming-link">

	              <a href="<?php the_permalink(); ?>" class="default-btn"><i class="fas fa-book"></i>  <?php if(isset($nolez_redux_demo['event_readmore'])){?>

		                <?php echo wp_specialchars_decode(esc_attr($nolez_redux_demo['event_readmore']));?>

		                <?php }else{?>

		                <?php echo esc_html__( 'join event', 'nolez' );?>

		                <?php } ?></a>

	            </div>

	          </div>

	        </div>

	        <!-- Single Upcoming Events End -->

	    	<?php }else{ ?>

	        <!-- Single Upcoming Events -->

	        <div class="col-md-8 col-lg-12">

	          <div class="sing-upcoming-events mb-20 d-block d-lg-flex align-items-center justify-content-between">

	            <div class="upcoming-event-content d-block d-lg-flex align-items-center">

	              <div class="upcoming-event-img mb-3 mb-lg-0">

	                <img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt="Upcoming Event">

	              </div>

	              <div class="upcoming-event-text mb-md-4 mb-lg-0 pr-20">

	              	<?php  $categories = get_the_terms(get_the_ID(),'category1');

	                        foreach( (array)$categories as $categorie){



	                        $cat_name = $categorie->name; 

	                        $cat_slug = $categorie->slug;

	                        ?>

	                <a href="#" class="bg-danger"><?php echo esc_attr($cat_name);?></a>

	                <?php } ?>

	                <h4><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>

	                <div class="u-event-meta">

	                  <p><span><i class="fas fa-map-marker-alt"></i><?php echo esc_attr($address);?></span><span><i

	                        class="far fa-calendar-alt"></i><?php echo esc_attr($date);?> <?php echo esc_attr($month);?> <?php echo esc_attr($year);?></span></p>

	                  <p><span><i class="far fa-clock"></i><?php echo esc_attr($time);?></span><span><i

	                        class="fas fa-tags"></i><?php echo esc_attr($seat);?></span></p>

	                </div>

	              </div>

	            </div>

	            <div class="upcoming-link">

	              <a href="<?php the_permalink(); ?>" class="default-btn"><i class="fas fa-book"></i>  <?php if(isset($nolez_redux_demo['event_readmore'])){?>

		                <?php echo wp_specialchars_decode(esc_attr($nolez_redux_demo['event_readmore']));?>

		                <?php }else{?>

		                <?php echo esc_html__( 'join event', 'nolez' );?>

		                <?php } ?></a>

	            </div>

	          </div>

	        </div>

	        <!-- Single Upcoming Events End -->

	    	<?php } ?>

	        <?php   

		        endwhile; 

		        wp_reset_postdata();

		    ?>

	      </div>

	    </div>

	  </section>

	<?php elseif( $chose_style == 'event_style_4' ): ?>

	<section class="event-area home-3 pt-130 pb-55" style="background-image: url(<?php print esc_url( $settings['background_bg_4']['url'] ); ?>);">

        <div class="container">

            <!-- section title -->

            <div class="row justify-content-center">

                <div class="col-xl-8 col-lg-10">

                    <div class="section-title text-center baloo-title">

                        <?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>

			            <h2><?php echo wp_kses_post($settings['heading']); ?></h2>

			            <?php endif; ?>

		            	<?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>

			            <p><?php echo wp_kses_post($settings['subheading']); ?></p>

			            <?php endif; ?>

                    </div>

                </div>

            </div>

            <div class="row justify-content-center">

            	<?php $i =0;

	                $args = new \WP_Query(array(   

	                            'post_type' => 'event', 

	                        ));  

	                        while ($wp_query -> have_posts()) : $wp_query -> the_post(); 

	                        $i ++;

	            ?>

            	<?php $address = get_post_meta(get_the_ID(),'_cmb_address', true); ?>

				<?php $date = get_post_meta(get_the_ID(),'_cmb_date', true); ?>

				<?php $month = get_post_meta(get_the_ID(),'_cmb_month', true); ?>

				<?php $year = get_post_meta(get_the_ID(),'_cmb_year', true); ?>

				<?php $time = get_post_meta(get_the_ID(),'_cmb_time', true); ?>

				<?php $seat = get_post_meta(get_the_ID(),'_cmb_seat', true); ?>

				<?php $event_image = get_post_meta(get_the_ID(),'_cmb_event_image', true); ?>

				<?php if($i % 3 == 1 ){ ?>

                <!-- Single Upcoming Events -->

                <div class="col-md-6 col-lg-12">

                    <div

                        class="sing-upcoming-events mb-20 d-block d-lg-flex align-items-center justify-content-between">

                        <div class="upcoming-event-content d-block d-lg-flex align-items-center">

                            <div class="upcoming-event-img mb-3 mb-lg-0">

                                <img src="<?php echo wp_get_attachment_url($event_image);?>" alt="Upcoming Event">

                            </div>

                            <div class="upcoming-event-text mb-md-4 mb-lg-0 pr-20">

                                <?php  $categories = get_the_terms(get_the_ID(),'category1');

			                        	foreach( (array)$categories as $categorie){



				                        $cat_name = $categorie->name; 

				                        $cat_slug = $categorie->slug;

				                        ?>

				                <a href="#" class="bg-primary"><?php echo esc_attr($cat_name);?></a>

				                <?php } ?>

                                <h4><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>

                                <div class="u-event-meta">

                                    <p><span><i class="fas fa-map-marker-alt"></i><?php echo esc_attr($address);?></span><span><i

                                                class="far fa-calendar-alt"></i><?php echo esc_attr($date);?> <?php echo esc_attr($month);?> <?php echo esc_attr($year);?></span></p>

                                    <p><span><i class="far fa-clock"></i><?php echo esc_attr($time);?></span><span><i

                                                class="fas fa-tags"></i><?php echo esc_attr($seat);?></span></p>

                                </div>

                            </div>

                        </div>

                        <div class="upcoming-link">

                            <div class="home3-single-btn"><a href="<?php the_permalink(); ?>" class="home3-btn"><i class="fas fa-book"></i> 

                            	<?php if(isset($nolez_redux_demo['event_readmore'])){?>

				                <?php echo wp_specialchars_decode(esc_attr($nolez_redux_demo['event_readmore']));?>

				                <?php }else{?>

				                <?php echo esc_html__( 'join event', 'nolez' );?>

				                <?php } ?></a></div>

                        </div>

                    </div>

                </div>

                <!-- Single Upcoming Events End -->

            	<?php }elseif($i % 3 ==2 ){ ?>

                <!-- Single Upcoming Events -->

                <div class="col-md-6 col-lg-12">

                    <div

                        class="sing-upcoming-events mb-20 d-block d-lg-flex align-items-center justify-content-between">

                        <div class="upcoming-event-content d-block d-lg-flex align-items-center">

                            <div class="upcoming-event-img mb-3 mb-lg-0">

                                <img src="<?php echo wp_get_attachment_url($event_image);?>" alt="Upcoming Event">

                            </div>

                            <div class="upcoming-event-text mb-md-4 mb-lg-0 pr-20">

                                <?php  $categories = get_the_terms(get_the_ID(),'category1');

			                        	foreach( (array)$categories as $categorie){



				                        $cat_name = $categorie->name; 

				                        $cat_slug = $categorie->slug;

				                        ?>

				                <a href="#" class="bg-warning"><?php echo esc_attr($cat_name);?></a>

				                <?php } ?>

                                <h4><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>

                                <div class="u-event-meta">

                                    <p><span><i class="fas fa-map-marker-alt"></i><?php echo esc_attr($address);?></span><span><i

                                                class="far fa-calendar-alt"></i><?php echo esc_attr($date);?> <?php echo esc_attr($month);?> <?php echo esc_attr($year);?></span></p>

                                    <p><span><i class="far fa-clock"></i><?php echo esc_attr($time);?></span><span><i

                                                class="fas fa-tags"></i><?php echo esc_attr($seat);?></span></p>

                                </div>

                            </div>

                        </div>

                        <div class="upcoming-link">

                            <div class="home3-single-btn"><a href="<?php the_permalink(); ?>" class="home3-btn"><i class="fas fa-book"></i> 

                            	<?php if(isset($nolez_redux_demo['event_readmore'])){?>

				                <?php echo wp_specialchars_decode(esc_attr($nolez_redux_demo['event_readmore']));?>

				                <?php }else{?>

				                <?php echo esc_html__( 'join event', 'nolez' );?>

				                <?php } ?></a></div>

                        </div>

                    </div>

                </div>

                <!-- Single Upcoming Events End -->

            	<?php }else{ ?>

                <!-- Single Upcoming Events -->

                <div class="col-md-6 col-lg-12">

                    <div

                        class="sing-upcoming-events mb-20 d-block d-lg-flex align-items-center justify-content-between">

                        <div class="upcoming-event-content d-block d-lg-flex align-items-center">

                            <div class="upcoming-event-img mb-3 mb-lg-0">

                                <img src="<?php echo wp_get_attachment_url($event_image);?>" alt="Upcoming Event">

                            </div>

                            <div class="upcoming-event-text mb-md-4 mb-lg-0 pr-20">

                                <?php  $categories = get_the_terms(get_the_ID(),'category1');

			                        	foreach( (array)$categories as $categorie){



				                        $cat_name = $categorie->name; 

				                        $cat_slug = $categorie->slug;

				                        ?>

				                <a href="#" class="bg-danger"><?php echo esc_attr($cat_name);?></a>

				                <?php } ?>

                                <h4><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>

                                <div class="u-event-meta">

                                    <p><span><i class="fas fa-map-marker-alt"></i><?php echo esc_attr($address);?></span><span><i

                                                class="far fa-calendar-alt"></i><?php echo esc_attr($date);?> <?php echo esc_attr($month);?> <?php echo esc_attr($year);?></span></p>

                                    <p><span><i class="far fa-clock"></i><?php echo esc_attr($time);?></span><span><i

                                                class="fas fa-tags"></i><?php echo esc_attr($seat);?></span></p>

                                </div>

                            </div>

                        </div>

                        <div class="upcoming-link">

                            <div class="home3-single-btn"><a href="<?php the_permalink(); ?>" class="home3-btn"><i class="fas fa-book"></i> 

                            	<?php if(isset($nolez_redux_demo['event_readmore'])){?>

				                <?php echo wp_specialchars_decode(esc_attr($nolez_redux_demo['event_readmore']));?>

				                <?php }else{?>

				                <?php echo esc_html__( 'join event', 'nolez' );?>

				                <?php } ?></a></div>

                        </div>

                    </div>

                </div>

                <!-- Single Upcoming Events End -->

            	<?php } ?>

            	<?php   

			        endwhile; 

			        wp_reset_postdata();

			    ?>

            </div>

        </div>

    </section>

    <?php elseif( $chose_style == 'event_style_5' ): ?>

    <section class="event-list-area pt-130 pb-130">

	    <div class="container">

	      <div class="row justify-content-between">

	        <div class="col-md-8 col-lg-7 col-xl-6">

	          <div class="event-list-title">

	            <?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>

	            <h2><?php echo wp_kses_post($settings['heading']); ?></h2>

	            <?php endif; ?>

            	<?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>

	            <p><?php echo wp_kses_post($settings['subheading']); ?></p>

	            <?php endif; ?>

	          </div>

	        </div>

	        <?php if (( '' !== $settings['button'] ) && ( $settings['show_button'] )) : ?>

	        <div class="col-md-4 col-xl-3">

	          <div class="upcoming-events-link-2 pt-35 text-right">

	            <a href="<?php echo wp_kses_post($settings['link_button']); ?>"><i class="fas fa-book"></i><?php echo wp_kses_post($settings['button']); ?></a>

	          </div>

	        </div>

	        <?php endif; ?>

	      </div>

	      <div class="row pt-40">

	      	<?php

                $args = new \WP_Query(array(   

                            'post_type' => 'event', 

                        ));  

                        while ($wp_query -> have_posts()) : $wp_query -> the_post(); 

            ?>

            <?php $address = get_post_meta(get_the_ID(),'_cmb_address', true); ?>

			<?php $date = get_post_meta(get_the_ID(),'_cmb_date', true); ?>

			<?php $month = get_post_meta(get_the_ID(),'_cmb_month', true); ?>

			<?php $year = get_post_meta(get_the_ID(),'_cmb_year', true); ?>

			<?php $time = get_post_meta(get_the_ID(),'_cmb_time', true); ?>

			<?php $seat = get_post_meta(get_the_ID(),'_cmb_seat', true); ?>

			<?php $price = get_post_meta(get_the_ID(),'_cmb_price', true); ?>

	        <!-- single list event -->

	        <div class="col-md-6 col-lg-12 mb-60">

	          <div class="single-list-event single-latest-event-4 d-lg-flex">

	            <div class="events-img-4">

	              <img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt="Events Image">

	              <div class="events-meta">

	                <span><?php echo esc_attr($date);?></span>

	                <p><?php echo esc_attr($month);?></p>

	              </div>

	            </div>

	            <div class="events-content-4">

	              <div class="upcoming-event-text evnt-ilst-text">

	                <h4><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>

	                <div class="u-event-meta">

                        <p><span><i class="fas fa-map-marker-alt"></i><?php echo esc_attr($address);?></span><span><i

                                    class="far fa-calendar-alt"></i><?php echo esc_attr($date);?> <?php echo esc_attr($month);?> <?php echo esc_attr($year);?></span></p>

                        <p><span><i class="far fa-clock"></i><?php echo esc_attr($time);?></span><span><i

                                    class="fas fa-tags"></i><?php echo esc_attr($seat);?></span></p>

                    </div>

                    <p class=""><?php if(isset($nolez_redux_demo['event_excerpt'])){?>

						                <?php echo esc_attr(nolez3_excerpt($nolez_redux_demo['event_excerpt'])); ?>

						                <?php }else{?>

						                <?php echo esc_attr(nolez3_excerpt(40)); 

						                ?> 

						            	<?php } ?> </p>

	                <a href="#" class="prc-tag"><?php echo esc_attr($price);?></a>

	              </div>

	              <div class="latest-event-link-4 evnt-page">

	                <a href="<?php the_permalink(); ?>"><i class="fas fa-book"></i>

	                <?php if(isset($nolez_redux_demo['event_readmore'])){?>

	                <?php echo wp_specialchars_decode(esc_attr($nolez_redux_demo['event_readmore']));?>

	                <?php }else{?>

	                <?php echo esc_html__( 'join event', 'nolez' );?>

	                <?php } ?></a>

	              </div>

	            </div>

	          </div>

	        </div>

	        <!-- single list event end -->

	        <?php   

		        endwhile; 

		        wp_reset_postdata();

		    ?>

	      </div>

	    </div>

	  </section>

    <?php endif; ?>




	<?php

	}



}