<?php

namespace BdevsElementor\Widget;



use Elementor\Controls_Manager;

use Elementor\Group_Control_Typography;

use Elementor\Scheme_Typography;

use Elementor\Group_Control_Border;

use Elementor\Group_Control_Box_Shadow;



/**

 * Bdevs Elementor Widget.

 *

 * Elementor widget that inserts an embbedable content into the page, from any given URL.

 *

 * @since 1.0.0

 */

class BdevsFAQ extends \Elementor\Widget_Base {



	/**

	 * Get widget name.

	 *

	 * Retrieve Bdevs Elementor widget name.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget name.

	 */

	public function get_name() {

		return 'bdevs-faq';

	}



	/**

	 * Get widget title.

	 *

	 * Retrieve Bdevs Elementor widget title.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget title.

	 */

	public function get_title() {

		return __( 'FAQ', 'bdevs-elementor' );

	}



	/**

	 * Get widget icon.

	 *

	 * Retrieve Bdevs FAQ widget icon.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget icon.

	 */

	public function get_icon() {

		return 'eicon-favorite';

	}



	/**

	 * Get widget categories.

	 *

	 * Retrieve the list of categories the Bdevs FAQ widget belongs to.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return array Widget categories.

	 */

	public function get_categories() {

		return [ 'bdevs-elementor' ];

	}



	public function get_keywords() {

		return [ 'faq' ];

	}



	public function get_script_depends() {

		return [ 'bdevs-elementor'];

	}



	// BDT Position

	protected function element_pack_position() {

	    $position_options = [

	        ''              => esc_html__('Default', 'bdevs-elementor'),

	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,

	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,

	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,

	        'center'        => esc_html__('Center', 'bdevs-elementor') ,

	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,

	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,

	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,

	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,

	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,

	    ];



	    return $position_options;

	}



	protected function _register_controls() {



		$this->start_controls_section(

			'section_content_heading',

			[

				'label' => esc_html__( 'FAQ', 'bdevs-elementor' ),

			]

		);



		$this->add_control(

			'chose_style',

			[

				'label'     => esc_html__( 'Chose Style', 'bdevs-elementor' ),

				'type'      => Controls_Manager::SELECT,

				'options'   => [

					'faq_style_1'  => esc_html__( 'FAQ Style 1', 'bdevs-elementor' ),

					'faq_style_2' => esc_html__( 'FAQ Style 2', 'bdevs-elementor' ),

				],

				'default'   => 'faq_style_1',

			]

		);



		$this->add_control(

			'background_bg',

			[

				'label'   => esc_html__( 'FAQ Image', 'bdevs-elementor' ),

				'type'    => Controls_Manager::MEDIA,

				'dynamic' => [ 'active' => true ],

				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),

			]

		);



		$this->add_control(

			'background_bg1',

			[

				'label'   => esc_html__( 'Background Video Image', 'bdevs-elementor' ),

				'type'    => Controls_Manager::MEDIA,

				'dynamic' => [ 'active' => true ],

				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),

			]

		);



		$this->add_control(

			'video',

			[

				'label'       => __( 'Link Video', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter link video here...', 'bdevs-elementor' ),

				'default'		=> __('#', 'bdevs-elementor'),

				'label_block' => true,

			]

		);



		$this->add_control(

			'heading',

			[

				'label'       => __( 'Heading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter heading here...', 'bdevs-elementor' ),

				'default'		=> __('Its heading', 'bdevs-elementor'),

				'label_block' => true,

			]

		);



		$this->add_control(

			'subheading',

			[

				'label'       => __( 'Subheading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter subheading here...', 'bdevs-elementor' ),

				'default'		=> __('Its subheading', 'bdevs-elementor'),

				'label_block' => true,

			]

		);



		$this->end_controls_section();



		$this->start_controls_section(

			'section_content_faq',

			[

				'label' => esc_html__( 'FAQ', 'bdevs-elementor' ),

			]

		);



		$this->add_control(

			'tabs',

			[

				'label' => esc_html__( 'FAQ Items', 'bdevs-elementor' ),

				'type' => Controls_Manager::REPEATER,

				'fields' => [

					[

						'name'        => 'choose',

						'label'       => esc_html__( 'Choose Style', 'bdevs-elementor' ),

						'type'        => Controls_Manager::SELECT,

						'options'   => [

							'style_01'  => esc_html__( 'Not show', 'bdevs-elementor' ),

							'style_02' => esc_html__( 'Show', 'bdevs-elementor' ),

						],

						'default'   => ['style_01'],

						'description' => esc_html__( 'Choose Style', 'bdevs-elementor' ),

					],

					[

						'name'       => 'id_question',

						'label'      => esc_html__( 'ID Question', 'bdevs-elementor' ),

						'type'       => Controls_Manager::TEXT,

						'dynamic'    => [ 'active' => true ],

						'default'    => esc_html__( '', 'bdevs-elementor' ),

						'label_block' => true,

					],

					[

						'name'       => 'question',

						'label'      => esc_html__( 'Question', 'bdevs-elementor' ),

						'type'       => Controls_Manager::TEXTAREA,

						'dynamic'    => [ 'active' => true ],

						'default'    => esc_html__( 'Question', 'bdevs-elementor' ),

						'label_block' => true,

					],

					[

						'name'       => 'answer',

						'label'      => esc_html__( 'Answer', 'bdevs-elementor' ),

						'type'       => Controls_Manager::TEXTAREA,

						'dynamic'    => [ 'active' => true ],

						'default'    => esc_html__( 'Answer', 'bdevs-elementor' ),

						'label_block' => true,

					],

				],

			]

		);



		$this->end_controls_section();



		$this->start_controls_section(

			'section_content_heading_4',

			[

				'label' => esc_html__( 'FAQ Style 2', 'bdevs-elementor' ),

				'condition' => [

					'chose_style' => ['faq_style_2']

				],

			]

		);



		$this->add_control(

			'shortcode',

			[

				'label'   => esc_html__( 'Shortcode', 'bdevs-elementor' ),

				'type'    => Controls_Manager::TEXTAREA,

				'dynamic' => [ 'active' => true ],

				'default'		=> __('Contact Shortcode here', 'bdevs-elementor'),

				'description' => esc_html__( 'Add Your shortcode here', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->add_control(

			'background_bg2',

			[

				'label'   => esc_html__( ' Image', 'bdevs-elementor' ),

				'type'    => Controls_Manager::MEDIA,

				'dynamic' => [ 'active' => true ],

				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),

			]

		);



		$this->end_controls_section();



		$this->start_controls_section(

			'section_content_layout',

			[

				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),

			]

		);



		$this->add_responsive_control(

			'align',

			[

				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),

				'type'    => Controls_Manager::CHOOSE,

				'options' => [

					'left' => [

						'title' => esc_html__( 'Left', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-left',

					],

					'center' => [

						'title' => esc_html__( 'Center', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-center',

					],

					'right' => [

						'title' => esc_html__( 'Right', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-right',

					],

					'justify' => [

						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-justify',

					],

				],

				'prefix_class' => 'elementor%s-align-',

				'description'  => 'Use align to match position',

				'default'      => 'left',

			]

		);



		$this->add_control(

			'show_heading',

			[

				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);	



		$this->add_control(

			'show_subheading',

			[

				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);		



		$this->end_controls_section();



	}



	public function render() {

		$settings  = $this->get_settings_for_display(); 

		extract($settings);

		$chose_style = $settings['chose_style'];	

	   	?>

	   	<?php if( $chose_style == 'faq_style_1' ): ?>

	   	<section class="like-us-wrap pb-130">

		    <div class="bg-1">

		      <img src="<?php print esc_url( $settings['background_bg']['url'] ); ?>" class="img-fluid h-100" alt="Faq Bg">

		    </div>

		    <div class="bg-2 d-none d-lg-block">

		      <img src="<?php print esc_url( $settings['background_bg1']['url'] ); ?>" class="img-fluid h-100" alt="Faq Bg">

		      <div class="like-video d-none d-lg-block">

		       <a href="<?php echo wp_kses_post($settings['video']); ?>"  class="play-btn play-video video-play-popup" >

				   <button class="play-video">

				   	<i class="fa fa-play"></i>

				   </button></a>

		      </div>

		    </div>

		    <div class="container">

		      <div class="row">

		        <!-- Like Us Area -->

		        <div class="col-lg-6">

		          <div class="like-us-area pt-125">

		            <div class="like-us-title">

		            <?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>

		            <h2><?php echo wp_kses_post($settings['heading']); ?></h2>

		            <?php endif; ?>

		            <?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>

		            <p><?php echo wp_kses_post($settings['subheading']); ?></p>

		            <?php endif; ?>

		            </div>

		            <!-- Like Us Faq Area -->

		            <div class="like-us-faq" id="accordion">

		            <?php 

	                    foreach ( $settings['tabs'] as $item ) : 

					?>

					<?php if($item['choose'] == 'style_01'){ ?>

		              <!-- Single FAQ -->

		              <div class="card">

		                <div class="card-header" id="heading<?php print wp_kses_post($item['id_question']); ?>">

		                  <h5 class="mb-0">

		                    <button class="btn collapsed" type="button" data-toggle="collapse" data-target="#collapse<?php print wp_kses_post($item['id_question']); ?>"

		                      aria-expanded="false" aria-controls="collapse<?php print wp_kses_post($item['id_question']); ?>"><?php print wp_kses_post($item['question']); ?> </button>

		                  </h5>

		                </div>

		                <div id="collapse<?php print wp_kses_post($item['id_question']); ?>" class="collapse" aria-labelledby="heading<?php print wp_kses_post($item['id_question']); ?>" data-parent="#accordion">

		                  <div class="card-body">

		                    <p><?php print wp_kses_post($item['answer']); ?></p>

		                  </div>

		                </div>

		              </div>

		              <!-- Single FAQ End -->

		          	  <?php }else{ ?>

		              <!-- Single FAQ -->

		              <div class="card">

		                <div class="card-header" id="heading<?php print wp_kses_post($item['id_question']); ?>">

		                  <h5 class="mb-0">

		                    <button class="btn" type="button" data-toggle="collapse" data-target="#collapse<?php print wp_kses_post($item['id_question']); ?>"

		                      aria-expanded="true" aria-controls="collapse<?php print wp_kses_post($item['id_question']); ?>"><?php print wp_kses_post($item['question']); ?></button>

		                  </h5>

		                </div>

		                <div id="collapse<?php print wp_kses_post($item['id_question']); ?>" class="collapse show" aria-labelledby="heading<?php print wp_kses_post($item['id_question']); ?>" data-parent="#accordion">

		                  <div class="card-body">

		                    <p><?php print wp_kses_post($item['answer']); ?></p>

		                  </div>

		                </div>

		              </div>

		              <!-- Single FAQ End -->

		          	<?php } ?>

		          	<?php endforeach; ?>

		            </div>

		            <!-- Like Us Faq Area End -->

		          </div>

		        </div>

		        <!-- Like Us Area End -->

		        <!-- Like Us Video btn -->

		        <!-- Like Us Video btn End -->

		      </div>

		    </div>

		  </section>

        <?php elseif( $chose_style == 'faq_style_2' ): ?>

        <section class="faq-area-wrapper pt-125 pb-75">

		    <div class="container">

		      <div class="row">

		        <!-- Faq Area -->

		        <div class="col-xl-7 col-lg-8 col-md-7">

		          <div class="faq-wrapper">

		          	<?php 

	                    foreach ( $settings['tabs'] as $item ) : 

					?>

		            <!-- Single FAQ -->

		            <div class="single-faq">

		              <div class="faq-question">

		                <h4><?php print wp_kses_post($item['question']); ?></h4>

		              </div>

		              <div class="faq-answer">

		                <p><?php print wp_kses_post($item['answer']); ?></p>

		              </div>

		            </div>

		            <!-- Single FAQ End -->

		            <?php endforeach; ?>

		          </div>

		        </div>

		        <!-- Faq Area End -->

		        <!-- aside Start -->

		        <div class="col-lg-4 col-md-5 offset-xl-1">

		          <!-- Question Form -->

		          <div class="question-form-wrap">

		            <div class="question-form-title">

		              	<?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>

			            <h1><?php echo wp_kses_post($settings['heading']); ?></h1>

			            <?php endif; ?>

			            </div>

		            <?php print do_shortcode(html_entity_decode( $settings['shortcode'] )); ?>

		          </div>

		          <!-- Question Form End -->

		          <!-- aSide Banner -->

		          <div class="faq-aside-banner pt-65">

		            <img src="<?php print esc_url( $settings['background_bg2']['url'] ); ?>" alt="Banner">

		          </div>

		          <!-- aSide Banner End -->

		        </div>

		        <!-- aside End -->

		      </div>

		    </div>

		  </section>

        <?php endif; ?>

	<?php

	}



}