<?php

namespace BdevsElementor\Widget;



use Elementor\Controls_Manager;

use Elementor\Group_Control_Typography;

use Elementor\Scheme_Typography;

use Elementor\Group_Control_Border;

use Elementor\Group_Control_Box_Shadow;



/**

 * Bdevs Elementor Widget.

 *

 * Elementor widget that inserts an embbedable content into the page, from any given URL.

 *

 * @since 1.0.0

 */

class BdevsFeatures extends \Elementor\Widget_Base {



	/**

	 * Get widget name.

	 *

	 * Retrieve Bdevs Elementor widget name.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget name.

	 */

	public function get_name() {

		return 'bdevs-features';

	}



	/**

	 * Get widget title.

	 *

	 * Retrieve Bdevs Elementor widget title.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget title.

	 */

	public function get_title() {

		return __( 'Features', 'bdevs-elementor' );

	}



	/**

	 * Get widget icon.

	 *

	 * Retrieve Bdevs Features widget icon.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget icon.

	 */

	public function get_icon() {

		return 'eicon-favorite';

	}



	/**

	 * Get widget categories.

	 *

	 * Retrieve the list of categories the Bdevs Improve widget belongs to.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return array Widget categories.

	 */

	public function get_categories() {

		return [ 'bdevs-elementor' ];

	}



	public function get_keywords() {

		return [ 'features' ];

	}



	public function get_script_depends() {

		return [ 'bdevs-elementor'];

	}



	// BDT Position

	protected function element_pack_position() {

	    $position_options = [

	        ''              => esc_html__('Default', 'bdevs-elementor'),

	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,

	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,

	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,

	        'center'        => esc_html__('Center', 'bdevs-elementor') ,

	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,

	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,

	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,

	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,

	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,

	    ];



	    return $position_options;

	}



	protected function _register_controls() {

		$this->start_controls_section(

			'section_content_heading',

			[

				'label' => esc_html__( 'Features', 'bdevs-elementor' ),

			]	

		);



		$this->add_control(

			'chose_style',

			[

				'label'     => esc_html__( 'Chose Style', 'bdevs-elementor' ),

				'type'      => Controls_Manager::SELECT,

				'options'   => [

					'features_style_1'  => esc_html__( 'Features Style 1', 'bdevs-elementor' ),

					'features_style_2' => esc_html__( 'Features Style 2', 'bdevs-elementor' ),

				],

				'default'   => 'features_style_1',

			]

		);



		$this->add_control(

			'tabs',

			[

				'label' => esc_html__( 'Features Items', 'bdevs-elementor' ),

				'type' => Controls_Manager::REPEATER,

				'fields' => [

					[

						'name'        => 'icon',

						'label'       => esc_html__( 'Icon', 'bdevs-elementor' ),

						'type'        => Controls_Manager::TEXT,

						'dynamic'     => [ 'active' => true ],

						'default'     => esc_html__( '' , 'bdevs-elementor' ),

						'label_block' => true,

					],

					[

						'name'        => 'title',

						'label'       => esc_html__( 'Title', 'bdevs-elementor' ),

						'type'        => Controls_Manager::TEXTAREA,

						'dynamic'     => [ 'active' => true ],

						'default'     => esc_html__( 'It is title ' , 'bdevs-elementor' ),

						'label_block' => true,

					],

					[

						'name'        => 'content',

						'label'       => esc_html__( 'Content', 'bdevs-elementor' ),

						'type'        => Controls_Manager::TEXTAREA,

						'dynamic'     => [ 'active' => true ],

						'default'     => esc_html__( 'It is content' , 'bdevs-elementor' ),

						'label_block' => true,

					],

				],

			]

		);



		$this->end_controls_section();



		/** 

		*	Layout section 

		**/

		$this->start_controls_section(

			'section_content_layout',

			[

				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),

			]

		);



		$this->add_responsive_control(

			'align',

			[

				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),

				'type'    => Controls_Manager::CHOOSE,

				'options' => [

					'left' => [

						'title' => esc_html__( 'Left', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-left',

					],

					'center' => [

						'title' => esc_html__( 'Center', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-center',

					],

					'right' => [

						'title' => esc_html__( 'Right', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-right',

					],

					'justify' => [

						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-justify',

					],

				],

				'prefix_class' => 'elementor%s-align-',

				'description'  => 'Use align to match position',

				'default'      => 'left',

			]

		);	



		$this->end_controls_section();



	}



	public function render() {

		$settings  = $this->get_settings_for_display();

		$chose_style = $settings['chose_style'];

		extract($settings); ?>

		<?php if( $chose_style == 'features_style_1' ): ?>

		<section class="feature-area home-3">

	        <div class="container">

	            <div class="home3-feature">

	            	<?php 

	                    foreach ( $settings['tabs'] as $item ) : 

					?>

	                <div class="col-xl-4">

	                    <!-- feature box -->

	                    <div class="home3-feature-box text-center">

	                        <div class="home3-feature-icon">

	                            <i class=" <?php print wp_kses_post($item['icon']); ?>"></i>

	                        </div>

	                        <div class="home3-feature-content">

	                            <h2><?php print wp_kses_post($item['title']); ?></h2>

	                            <p><?php print wp_kses_post($item['content']); ?></p>

	                        </div>

	                    </div>

	                    <!-- feature-box-end -->

	                </div>

	                <?php endforeach; ?>

	            </div>

	        </div>

	    </section>

	    <?php elseif( $chose_style == 'features_style_2' ): ?>

	    <section class="about-features-wrapper pb-130">

		    <div class="container">

		      <div class="about-features-slider custom-row">

		      	<?php $i=0;

                    foreach ( $settings['tabs'] as $item ) : 

                    $i++;

				?>

				<?php if($i == 1){ ?>

		        <!-- Single Features -->

		        <div class="col-xl-4">

		          <div class="single-ab-features feature-1 text-center">

		            <div class="ab-features-icon">

		              <span><i class="<?php print wp_kses_post($item['icon']); ?>"></i></span>

		            </div>

		            <h3><?php print wp_kses_post($item['title']); ?></h3>

                    <p><?php print wp_kses_post($item['content']); ?></p>

		          </div>

		        </div>

		        <!-- Single Features -->

		    	<?php }elseif($i == 2){ ?>

		        <!-- Single Features -->

		        <div class="col-xl-4">

		          <div class="single-ab-features feature-2 text-center">

		            <div class="ab-features-icon">

		              <span><i class="<?php print wp_kses_post($item['icon']); ?>"></i></span>

		            </div>

		            <h3><?php print wp_kses_post($item['title']); ?></h3>

                    <p><?php print wp_kses_post($item['content']); ?></p>

		          </div>

		        </div>

		        <!-- Single Features -->

		   	 	<?php }else{ ?>

		        <!-- Single Features -->

		        <div class="col-xl-4">

		          <div class="single-ab-features feature-3 text-center">

		            <div class="ab-features-icon">

		              <span><i class="<?php print wp_kses_post($item['icon']); ?>"></i></span>

		            </div>

		            <h3><?php print wp_kses_post($item['title']); ?></h3>

                    <p><?php print wp_kses_post($item['content']); ?></p>

		          </div>

		        </div>

		        <!-- Single Features -->

		    	<?php } ?>

		        <?php endforeach; ?>

		      </div>

		    </div>

		  </section>

	    <?php endif; ?>
<?php if (is_admin()) { ?>
    <script type="text/javascript">
    
        
           $('.home3-feature').slick({

    dots: false,

    infinite: true,

    autoplay: true,

    arrows: false,

    speed: 300,

    slidesToShow: 3,

    slidesToScroll: 1,

    responsive: [{

        breakpoint: 992,

        settings: {

          arrows: false,

          dots: false,

          infinite: false,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 2,

          slidesToScroll: 1

        }

      }, {

        breakpoint: 768,

        settings: {

          arrows: false,

          dots: false,

          infinite: false,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 1,

          slidesToScroll: 1

        }

      }

      // You can unslick at a given breakpoint now by adding:

      // settings: "unslick"

      // instead of a settings object

    ]

  });
        
        

        $('.about-features-slider').slick({

    dots: false,

    arrows: false,

    infinite: true,

    speed: 300,

    slidesToShow: 3,

    slidesToScroll: 1,

    responsive: [{

        breakpoint: 1200,

        settings: {

          arrows: false,

          dots: false,

          slidesToShow: 3,

          slidesToScroll: 1,

          infinite: true

        }

      },

      {

        breakpoint: 992,

        settings: {

          arrows: false,

          slidesToShow: 2,

          slidesToScroll: 1

        }

      },

      {

        breakpoint: 768,

        settings: {

          arrows: false,

          slidesToShow: 2,

          slidesToScroll: 1

        }

      },

      {

        breakpoint: 560,

        settings: {

          arrows: false,

          slidesToShow: 1,

          slidesToScroll: 1

        }

      }

      // You can unslick at a given breakpoint now by adding:

      // settings: "unslick"

      // instead of a settings object

    ]

  });
    </script>   
    <?php } ?>
	<?php

	}



}