<?php

namespace BdevsElementor\Widget;



use Elementor\Controls_Manager;

use Elementor\Group_Control_Typography;

use Elementor\Scheme_Typography;

use Elementor\Group_Control_Border;

use Elementor\Group_Control_Box_Shadow;



/**

 * Bdevs Elementor Widget.

 *

 * Elementor widget that inserts an embbedable content into the page, from any given URL.

 *

 * @since 1.0.0

 */

class BdevsGallery extends \Elementor\Widget_Base {



	/**

	 * Get widget name.

	 *

	 * Retrieve Bdevs Elementor widget name.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget name.

	 */

	public function get_name() {

		return 'bdevs-gallery';

	}



	/**

	 * Get widget title.

	 *

	 * Retrieve Bdevs Elementor widget title.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget title.

	 */

	public function get_title() {

		return __( 'Gallery', 'bdevs-elementor' );

	}



	/**

	 * Get widget icon.

	 *

	 * Retrieve Bdevs Gallery widget icon.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget icon.

	 */

	public function get_icon() {

		return 'eicon-gallery-grid';

	}



	/**

	 * Get widget categories.

	 *

	 * Retrieve the list of categories the Bdevs Gallery widget belongs to.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return array Widget categories.

	 */

	public function get_categories() {

		return [ 'bdevs-elementor' ];

	}



	public function get_keywords() {

		return [ 'gallery' ];

	}



	public function get_script_depends() {

		return [ 'bdevs-elementor'];

	}



	// BDT Position

	protected function element_pack_position() {

	    $position_options = [

	        ''              => esc_html__('Default', 'bdevs-elementor'),

	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,

	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,

	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,

	        'center'        => esc_html__('Center', 'bdevs-elementor') ,

	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,

	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,

	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,

	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,

	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,

	    ];



	    return $position_options;

	}



	protected function _register_controls() {



		$this->start_controls_section(

			'section_content_heading',

			[

				'label' => esc_html__( 'Gallery', 'bdevs-elementor' ),

			]

		);



		$this->add_control(

			'chose_style',

			[

				'label'     => esc_html__( 'Chose Style', 'bdevs-elementor' ),

				'type'      => Controls_Manager::SELECT,

				'options'   => [

					'gallery_style_1'  => esc_html__( 'Gallery Style 1', 'bdevs-elementor' ),

					'gallery_style_2' => esc_html__( 'Gallery Style 2', 'bdevs-elementor' ),

					'gallery_style_3' => esc_html__( 'Gallery Style 3', 'bdevs-elementor' ),

				],

				'default'   => 'gallery_style_1',

			]

		);



		$this->add_control(

			'heading',

			[

				'label'       => __( 'Heading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter heading here...', 'bdevs-elementor' ),

				'default'		=> __('It is heading', 'bdevs-elementor'),

				'label_block' => true,

			]

		);



		$this->add_control(

			'subheading',

			[

				'label'       => __( 'Subheading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter subheading here...', 'bdevs-elementor' ),

				'default'		=> __('It is subheading', 'bdevs-elementor'),

				'label_block' => true,

			]

		);



		$this->add_control(

			'button',

			[

				'label'       => __( 'Button', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'default'     => __( 'Button', 'bdevs-elementor' ),

				'placeholder' => __( 'Enter your button', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);	



		$this->add_control(

			'link_button',

			[

				'label'       => __( 'Link Button', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'default'     => __( '#', 'bdevs-elementor' ),

				'placeholder' => __( 'Link Button', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);	



		$this->add_control(

			'post_number',

			[

				'label'     => esc_html__( 'Post Count', 'bdevs-elementor' ),

				'type'      => Controls_Manager::TEXT,

				'default'     => __( '6', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->end_controls_section();



		$this->start_controls_section(

			'section_content_heading_3',

			[

				'label' => esc_html__( 'Gallery Style 3 (Masonry)', 'bdevs-elementor' ),

				'condition' => [

					'chose_style' => ['gallery_style_3']

				],

			]

		);



		$this->add_control(

			'tabs',

			[

				'label' => esc_html__( 'Gallery Items', 'bdevs-elementor' ),

				'type' => Controls_Manager::REPEATER,

				'fields' => [

					[

						'name'    => 'tab_image',

						'label'   => esc_html__( 'Background Image', 'bdevs-elementor' ),

						'type'    => Controls_Manager::MEDIA,

						'dynamic' => [ 'active' => true ],
						'default'     => __( '', 'bdevs-elementor' ),

					],

					[

						'name'        => 'title',

						'label'       => esc_html__( 'Title', 'bdevs-elementor' ),

						'type'        => Controls_Manager::TEXTAREA,

						'dynamic'     => [ 'active' => true ],

						'default'     => esc_html__( 'It is title ' , 'bdevs-elementor' ),

						'label_block' => true,

					],

					[

						'name'        => 'button_1',

						'label'       => esc_html__( 'Text button', 'bdevs-elementor' ),

						'type'        => Controls_Manager::TEXT,

						'dynamic'     => [ 'active' => true ],

						'default'     => esc_html__( 'Button' , 'bdevs-elementor' ),

						'label_block' => true,

					],

					[

						'name'        => 'link_button_1',

						'label'       => esc_html__( 'Link', 'bdevs-elementor' ),

						'type'        => Controls_Manager::TEXT,

						'dynamic'     => [ 'active' => true ],

						'default'     => esc_html__( '#' , 'bdevs-elementor' ),

						'label_block' => true,

					],

				],

			]

		);



		$this->add_control(

			'background_bg',

			[

				'label'   => esc_html__( 'Large Image', 'bdevs-elementor' ),

				'type'    => Controls_Manager::MEDIA,

				'dynamic' => [ 'active' => true ],

				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),

			]

		);



		$this->add_control(

			'title_2',

			[

				'label'       => __( 'Title of large image', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'default'     => __( 'It is title', 'bdevs-elementor' ),

				'placeholder' => __( '', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);	



		$this->add_control(

			'button_2',

			[

				'label'       => __( 'Button', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'default'     => __( 'Button', 'bdevs-elementor' ),

				'placeholder' => __( '', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);	



		$this->add_control(

			'link_button_2',

			[

				'label'       => __( 'Link', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'default'     => __( '#', 'bdevs-elementor' ),

				'placeholder' => __( 'Link', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->end_controls_section();



		$this->start_controls_section(

			'section_content_layout',

			[

				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),

			]

		);



		$this->add_responsive_control(

			'align',

			[

				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),

				'type'    => Controls_Manager::CHOOSE,

				'options' => [

					'left' => [

						'title' => esc_html__( 'Left', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-left',

					],

					'center' => [

						'title' => esc_html__( 'Center', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-center',

					],

					'right' => [

						'title' => esc_html__( 'Right', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-right',

					],

					'justify' => [

						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-justify',

					],

				],

				'prefix_class' => 'elementor%s-align-',

				'description'  => 'Use align to match position',

				'default'      => 'left',

			]

		);



		$this->add_control(

			'show_heading',

			[

				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);	



		$this->add_control(

			'show_subheading',

			[

				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);	



		$this->add_control(

			'show_button',

			[

				'label'   => esc_html__( 'Show Button', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);			



		$this->end_controls_section();



	}



	public function render() {

		$settings  = $this->get_settings_for_display(); 

		extract($settings);	


		$post_number = $settings['post_number'];

		$chose_style = $settings['chose_style'];

	    $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'gallery',  'orderby' => 'ID', 'order' => 'ASC'));

	   

	    //other style

	    $args = array('posts_per_page' => $post_number,'post_type' => 'gallery',  'orderby' => 'ID', 'order' => 'ASC');

	   	?>

	   	<?php if( $chose_style == 'gallery_style_1' ): ?>

	   	<section class="gallery-wrapper-4 gallery-box pt-85 pb-85">

		    <div class="container">

		      <!-- Section Title -->

		      <div class="row justify-content-center">

		        <div class="col-lg-10 col-xl-8">

		          <div class="section-title text-center mb-0 mb-lg-5 pb-2 pl-0 pr-0">

		          	<?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>

		            <h2 class=""><?php echo wp_kses_post($settings['heading']); ?></h2>

		            <?php endif; ?>

		            <?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>

		            <p class="pl-0"><?php echo wp_kses_post($settings['subheading']); ?></p>

		            <?php endif; ?>

		          </div>

		        </div>

		        <!-- Gallary Menu -->

		      </div>

		      <!-- Gallery Menu Area End -->

		    </div>

		    <div class="container-fluid">

		      <!-- Gallery Images -->

		      <div class="row gallery-4-active">

		      	<?php

                    $args = new \WP_Query(array(   

                                'post_type' => 'gallery', 

                            ));  

                            while ($wp_query -> have_posts()) : $wp_query -> the_post();

                            $cates = get_the_terms(get_the_ID(),'type');

                            $cate_name ='';

                            $cate_slug = '';

                                 foreach((array)$cates as $cate){

                            if(count($cates)>0){

                            $cate_name .= $cate->name.'  ' ;

                            $cate_slug .= $cate->slug .' ';     

                            } 

                            } 

                ?>

		        <!-- Single Gallery Image -->

		        <div class="col-sm-6 col-lg-3 grid-item <?php echo esc_attr($cate_slug);?>">

		          <div class="sing-gallary-img-4 mb-30">

		            <img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt="Gallery Image">

		            <a href="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" class="video-play-btn magnify"><i class="far fa-eye"></i></a>

		          </div>

		        </div>

		        <!-- Single Gallery Image End -->

		        <?php   

			        endwhile; 

			        wp_reset_postdata();

			    ?>

		      </div>

		      <!-- Gallery Images End -->

		    </div>

		  </section>

		  <?php elseif( $chose_style == 'gallery_style_2' ): ?>

		  <section class="gallery-wrapper-4 pt-100 pb-100">

		    <div class="container">

		      <div class="row justify-content-center">

		        <div class="col-md-11 col-lg-8 col-xl-7">

		          <div class="section-title-4 pr-0 pr-xl-3 pl-0 pl-xl-3 text-center">

		            <?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>

		            <h2><?php echo wp_kses_post($settings['heading']); ?></h2>

		            <?php endif; ?>

		            <?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>

		            <p><?php echo wp_kses_post($settings['subheading']); ?></p>

		            <?php endif; ?>

		          </div>

		        </div>

		      </div>

		      <!-- Gallery Menu Area -->

		      <!-- Gallery Images -->

		      <div class="row gallery-4-active">

		      	<?php

                    $args = new \WP_Query(array(   

                                'post_type' => 'gallery', 

                            ));  

                            while ($wp_query -> have_posts()) : $wp_query -> the_post();

                            $cates = get_the_terms(get_the_ID(),'type');

                            $cate_name ='';

                            $cate_slug = '';

                                 foreach((array)$cates as $cate){

                            if(count($cates)>0){

                            $cate_name .= $cate->name.'  ' ;

                            $cate_slug .= $cate->slug .' ';     

                            } 

                            } 

                ?>

                <?php $gallery_2 = get_post_meta(get_the_ID(),'_cmb_gallery_2', true); ?>

		        <!-- Single Gallery Image -->

		        <div class="col-md-6 col-lg-4 grid-item <?php echo esc_attr($cate_slug);?>">

		          <div class="sing-gallary-img-4 mb-30">

		            <img src="<?php echo wp_get_attachment_url($gallery_2);?>" alt="Gallery Image">

		            <a href="<?php echo wp_get_attachment_url($gallery_2);?>" class="video-play-btn"><i class="far fa-eye"></i></a>

		          </div>

		        </div>

		        <!-- Single Gallery Image End -->

		        <?php   

			        endwhile; 

			        wp_reset_postdata();

			    ?>

		      </div>

		      <!-- Gallery Images End -->

		    </div>

		  </section>

		  <?php elseif( $chose_style == 'gallery_style_3' ): ?>

		  <section class="gallary-section-2">

		    <div class="container">

		      <div class="row justify-content-center text-center">

		        <div class="col-md-9 col-lg-7 col-xl-6">

		          <div class="section-title-2 pl-lg-3 pr-lg-3">

		            <?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>

		            <h2><?php echo wp_kses_post($settings['heading']); ?></h2>

		            <?php endif; ?>

		            <?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>

		            <p><?php echo wp_kses_post($settings['subheading']); ?></p>

		            <?php endif; ?>

		          </div>

		        </div>

		      </div>

		    </div>

		    <div class="container-fluid pl-0 pr-0">

		      <div class="row no-gutters">

		        <div class="col-lg-6">

		          <div class="row no-gutters">

		          	<?php 

	                    foreach ( $settings['tabs'] as $item ) : 

					?>

		            <!-- Single Gallery Image -->

		            <div class="col-md-6">

		              <div class="sing-gallery-img-2">

		                <img src="<?php print esc_url($item['tab_image']['url']); ?>" class="w-100" alt="Gallery Image">

		                <div class="gallery-content-2 text-center">

		                  <h2><?php print wp_kses_post($item['title_1']); ?></h2>

		                  <a href="<?php print wp_kses_post($item['link_button_1']); ?>" class="default-btn"><i class="fas fa-book"></i><?php print wp_kses_post($item['button_1']); ?></a>

		                </div>

		              </div>

		            </div>

		            <!-- Single Gallery Image End -->

		            <?php endforeach; ?>

		          </div>

		        </div>

		        <!-- Single Gallery Image -->

		        <div class="col-lg-6 d-none d-lg-block">

		          <div class="sing-gallery-img-2 big-img">

		            <img src="<?php print esc_url( $settings['background_bg']['url'] ); ?>" class="w-100" alt="Gallery Image">

		            <div class="gallery-content-2 text-center">

		              <h2><?php print wp_kses_post($settings['title_2']); ?></h2>

		              <a href="<?php print wp_kses_post($settings['link_button_2']); ?>" class="default-btn"><i class="fas fa-book"></i><?php print wp_kses_post($settings['button_2']); ?></a>

		            </div>

		          </div>

		        </div>

		        <!-- Single Gallery Image End -->

		      </div>

		    </div>

		  </section>

		  <?php endif; ?>


<?php if (is_admin()) { ?>
    <script type="text/javascript">
    
        
            var $grid = $('.gallery-4-active').isotope({

    itemSelector: '.grid-item',

  })
            $('.gallery-menu-4').on('click', 'button', function () {

    var filterValue = $(this).attr('data-filter');

    $grid.isotope({

      filter: filterValue

    });

  });



  //for menu active class

  $('.gallery-menu-4 button').on('click', function (event) {

    $(this).siblings('.active').removeClass('active');

    $(this).addClass('active');

    event.preventDefault();

  });
        
        
    </script>   
    <?php } ?>
	<?php

	}



}