<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsMap extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-map';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Map', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Map widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-google-maps';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Map widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'map' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	protected function _register_controls() {


		$this->start_controls_section(
			'section_content_heading',
			[
				'label' => esc_html__( 'Map', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'chose_style',
			[
				'label'     => esc_html__( 'Chose Style', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'map_style_1'  => esc_html__( 'Map Style 1', 'bdevs-elementor' ),
					'map_style_2' => esc_html__( 'Map Style 2', 'bdevs-elementor' ),
					'map_style_3' => esc_html__( 'Map Style 3', 'bdevs-elementor' ),
				],
				'default'   => 'map_style_1',
			]
		);

		$this->add_control(
			'iframe1',
			[
				'label'       => __( 'IFrame Source', 'bdevs-elementor' ),
				'description'       => __( 'Access map.google.com, choose your place, click "Share", then click "Embed Map" and copy iframe source in "".', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter iframe source', 'bdevs-elementor' ),
				'default'		=> __('', 'bdevs-elementor'),
				'label_block' => true,
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);	

		$this->end_controls_section();

	}

	public function render() {
	$settings  = $this->get_settings_for_display(); 
	extract($settings);	
	$chose_style = $settings['chose_style'];
	?>
	<?php if( $chose_style == 'map_style_1' ): ?>
	<div class="map-area">
	    <iframe
	      src="<?php echo wp_kses_post($settings['iframe1']); ?>"></iframe>
	</div>
	<?php elseif( $chose_style == 'map_style_2' ): ?>
	<div id="contact-map" class="contact-page-map">
	    <iframe
	      src="<?php echo wp_kses_post($settings['iframe1']); ?>"
	      width="100%" height="950" frameborder="0" style="border:0" allowfullscreen></iframe>
	  </div>
	<?php elseif( $chose_style == 'map_style_3' ): ?>
	<div id="contact-mapV2" class="contact-page-map">
	    <iframe
	      src="<?php echo wp_kses_post($settings['iframe1']); ?>"
	      width="100%" height="830" frameborder="0" style="border:0" allowfullscreen></iframe>
	</div>
	<?php endif; ?>
	<?php
	}

}