<?php

namespace BdevsElementor\Widget;



use Elementor\Controls_Manager;

use Elementor\Group_Control_Typography;

use Elementor\Scheme_Typography;

use Elementor\Group_Control_Border;

use Elementor\Group_Control_Box_Shadow;



/**

 * Bdevs Elementor Widget.

 *

 * Elementor widget that inserts an embbedable content into the page, from any given URL.

 *

 * @since 1.0.0

 */

class BdevsSchedule extends \Elementor\Widget_Base {



	/**

	 * Get widget name.

	 *

	 * Retrieve Bdevs Elementor widget name.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget name.

	 */

	public function get_name() {

		return 'bdevs-schedule';

	}



	/**

	 * Get widget title.

	 *

	 * Retrieve Bdevs Elementor widget title.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget title.

	 */

	public function get_title() {

		return __( 'Schedule', 'bdevs-elementor' );

	}



	/**

	 * Get widget icon.

	 *

	 * Retrieve Bdevs Schedule widget icon.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget icon.

	 */

	public function get_icon() {

		return 'eicon-favorite';

	}



	/**

	 * Get widget categories.

	 *

	 * Retrieve the list of categories the Bdevs Schedule widget belongs to.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return array Widget categories.

	 */

	public function get_categories() {

		return [ 'bdevs-elementor' ];

	}



	public function get_keywords() {

		return [ 'schedule' ];

	}



	public function get_script_depends() {

		return [ 'bdevs-elementor'];

	}



	protected function _register_controls() {

		$this->start_controls_section(

			'section_content_heading',

			[

				'label' => esc_html__( 'Schedule', 'bdevs-elementor' ),

			]

		);



		$this->add_control(

			'background_bg',

			[

				'label'   => esc_html__( 'Background Image', 'bdevs-elementor' ),

				'type'    => Controls_Manager::MEDIA,

				'dynamic' => [ 'active' => true ],

				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),

			]

		);



		$this->add_control(

			'heading',

			[

				'label'       => __( 'Heading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),

				'default'     => __( 'It is heading', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->add_control(

			'subheading',

			[

				'label'       => __( 'Subheading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your subheading', 'bdevs-elementor' ),

				'default'     => __( 'It is subheading', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->end_controls_section();



		$this->start_controls_section(

			'section_content_schedule',

			[

				'label' => esc_html__( 'Schedule Items', 'bdevs-elementor' ),

			]

		);



		$this->add_control(

			'tabs',

			[

				'label' => esc_html__( 'Schedule Items', 'bdevs-elementor' ),

				'type' => Controls_Manager::REPEATER,

				'fields' => [

					[

						'name'    => 'tab_image',

						'label'   => esc_html__( 'Image', 'bdevs-elementor' ),

						'type'    => Controls_Manager::MEDIA,

						'dynamic' => [ 'active' => true ],
						'default'     => __( '', 'bdevs-elementor' ),

					],

					[

						'name'       => 'schedule_1',

						'label'      => esc_html__( 'Schedule', 'bdevs-elementor' ),

						'type'       => Controls_Manager::TEXTAREA,

						'dynamic'    => [ 'active' => true ],

						'default'    => esc_html__( 'Schedule', 'bdevs-elementor' ),

						'label_block' => true,

					],

					[

						'name'       => 'schedule_2',

						'label'      => esc_html__( 'Schedule', 'bdevs-elementor' ),

						'type'       => Controls_Manager::TEXTAREA,

						'dynamic'    => [ 'active' => true ],

						'default'    => esc_html__( 'Schedule', 'bdevs-elementor' ),

						'label_block' => true,

					],

					[

						'name'       => 'schedule_3',

						'label'      => esc_html__( 'Schedule', 'bdevs-elementor' ),

						'type'       => Controls_Manager::TEXTAREA,

						'dynamic'    => [ 'active' => true ],

						'default'    => esc_html__( 'Schedule', 'bdevs-elementor' ),

						'label_block' => true,

					],

				],

			]

		);



		$this->end_controls_section();



		$this->start_controls_section(

			'section_content_layout',

			[

				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),

			]

		);



		$this->add_responsive_control(

			'align',

			[

				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),

				'type'    => Controls_Manager::CHOOSE,

				'options' => [

					'left' => [

						'title' => esc_html__( 'Left', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-left',

					],

					'center' => [

						'title' => esc_html__( 'Center', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-center',

					],

					'right' => [

						'title' => esc_html__( 'Right', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-right',

					],

					'justify' => [

						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-justify',

					],

				],

				'prefix_class' => 'elementor%s-align-',

				'description'  => 'Use align to match position',

				'default'      => 'left',

			]

		);	



		$this->add_control(

			'show_heading',

			[

				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);	



		$this->add_control(

			'show_subheading',

			[

				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);



		$this->end_controls_section();



	}



	public function render() {



		$settings  = $this->get_settings_for_display(); 

		?>

		<section class="schedule-area pt-120 pb-40" style="background-image: url(<?php print esc_url( $settings['background_bg']['url'] ); ?>);">

	        <div class="container">

	            <!-- section title -->

	            <div class="row justify-content-center">

	                <div class="col-xl-8 col-lg-10">

	                    <div class="section-title text-center white-text baloo-title">

	                        <?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>

				            <h2><?php echo wp_kses_post($settings['heading']); ?></h2>

				            <?php endif; ?>

				            <?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>

				            <p><?php echo wp_kses_post($settings['subheading']); ?></p>

				            <?php endif; ?>

	                    </div>

	                </div>

	            </div>



	            <!-- schedule section -->

	            <div class="row">

	            	<?php 

	                    foreach ( $settings['tabs'] as $item ) : 

					?>

	                <div class="col-xl-4 col-md-6">

	                    <!-- schedule-box -->

	                    <div class="schedule-box">

	                        <div class="schedule-bg">

	                            <img src="<?php print esc_url($item['tab_image']['url']); ?>" alt="schedule">

	                            <!-- schedule content -->

	                            <div class="schedule-content">

	                                <div class="schedule">

	                                    <?php print wp_kses_post($item['schedule_1']); ?>

	                                </div>

	                                <div class="schedule">

	                                    <?php print wp_kses_post($item['schedule_2']); ?>

	                                </div>

	                                <div class="schedule">

	                                    <?php print wp_kses_post($item['schedule_3']); ?>

	                                </div>

	                            </div>

	                        </div>

	                    </div>

	                </div>

	                <?php endforeach; ?>

	            </div>

	            <!-- row -->

	        </div>

	        <!-- container -->

	    </section>

	<?php

	}



}