<?php

namespace BdevsElementor\Widget;



use Elementor\Controls_Manager;

use Elementor\Group_Control_Typography;

use Elementor\Scheme_Typography;

use Elementor\Group_Control_Border;

use Elementor\Group_Control_Box_Shadow;



/**

 * Bdevs Elementor Widget.

 *

 * Elementor widget that inserts an embbedable content into the page, from any given URL.

 *

 * @since 1.0.0

 */

class BdevsSearchArea extends \Elementor\Widget_Base {



	/**

	 * Get widget name.

	 *

	 * Retrieve Bdevs Elementor widget name.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget name.

	 */

	public function get_name() {

		return 'bdevs-search-area';

	}



	/**

	 * Get widget title.

	 *

	 * Retrieve Bdevs Elementor widget title.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget title.

	 */

	public function get_title() {

		return __( 'Search Area', 'bdevs-elementor' );

	}



	/**

	 * Get widget icon.

	 *

	 * Retrieve Bdevs SearchArea widget icon.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget icon.

	 */

	public function get_icon() {

		return 'eicon-search';

	}



	/**

	 * Get widget categories.

	 *

	 * Retrieve the list of categories the Bdevs SearchArea widget belongs to.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return array Widget categories.

	 */

	public function get_categories() {

		return [ 'bdevs-elementor' ];

	}



	public function get_keywords() {

		return [ 'search-area', 'carousel' ];

	}



	public function get_script_depends() {

		return [ 'bdevs-elementor'];

	}



	// BDT Position

	protected function element_pack_position() {

	    $position_options = [

	        ''              => esc_html__('Default', 'bdevs-elementor'),

	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,

	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,

	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,

	        'center'        => esc_html__('Center', 'bdevs-elementor') ,

	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,

	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,

	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,

	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,

	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,

	    ];



	    return $position_options;

	}



	protected function _register_controls() {

		$this->start_controls_section(

			'section_content_heading',

			[

				'label' => esc_html__( 'Search Area', 'bdevs-elementor' ),

			]

		);



		$this->add_control(

			'chose_style',

			[

				'label'     => esc_html__( 'Chose Style', 'bdevs-elementor' ),

				'type'      => Controls_Manager::SELECT,

				'options'   => [

					'search_style_1'  => esc_html__( 'Search Style 1', 'bdevs-elementor' ),

					'search_style_2' => esc_html__( 'Search Style 2', 'bdevs-elementor' ),

				],

				'default'   => 'search_style_1',

			]

		);



		$this->end_controls_section();



		$this->start_controls_section(

			'section_content_heading_1',

			[

				'label' => esc_html__( 'Style 1', 'bdevs-elementor' ),

				'condition' => [

					'chose_style' => ['search_style_1']

				],

			]

		);



		$this->add_control(

			'label_1',

			[

				'label'       => __( 'Text Label 1', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'placeholder' => __( 'Enter your text label', 'bdevs-elementor' ),

				'default'     => __( 'Label 1', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->add_control(

			'placeholder_1',

			[

				'label'       => __( 'Placeholder 1', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'placeholder' => __( 'Enter your placeholder', 'bdevs-elementor' ),

				'default'     => __( 'Placeholder', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->add_control(

			'label_2',

			[

				'label'       => __( 'Text Label 2', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'placeholder' => __( 'Enter your text label', 'bdevs-elementor' ),

				'default'     => __( 'Label 2', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->add_control(

			'placeholder_2',

			[

				'label'       => __( 'Placeholder 2', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'placeholder' => __( 'Enter your placeholder', 'bdevs-elementor' ),

				'default'     => __( 'Placeholder', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->add_control(

			'button',

			[

				'label'       => __( 'Button', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'placeholder' => __( 'Enter your button', 'bdevs-elementor' ),

				'default'     => __( 'button', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->end_controls_section();



		$this->start_controls_section(

			'section_content_heading_2',

			[

				'label' => esc_html__( 'Style 2', 'bdevs-elementor' ),

				'condition' => [

					'chose_style' => ['search_style_2']

				],

			]

		);



		$this->add_control(

			'background_bg',

			[

				'label'   => esc_html__( 'Background Image', 'bdevs-elementor' ),

				'type'    => Controls_Manager::MEDIA,

				'dynamic' => [ 'active' => true ],

				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),

			]

		);



		$this->add_control(

			'background_bg1',

			[

				'label'   => esc_html__( 'Featured Image', 'bdevs-elementor' ),

				'type'    => Controls_Manager::MEDIA,

				'dynamic' => [ 'active' => true ],

				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),

			]

		);



		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Heading', 'bdevs-elementor' ),
				'default'     => __( 'This is heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'subheading',
			[
				'label'       => __( 'Subheading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Subheading', 'bdevs-elementor' ),
				'default'     => __( 'This is subheading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);



		$this->add_control(

			'label_11',

			[

				'label'       => __( 'Text Label 1', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'placeholder' => __( 'Enter your text label', 'bdevs-elementor' ),

				'default'     => __( 'Label 1', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->add_control(

			'placeholder_11',

			[

				'label'       => __( 'Placeholder 1', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'placeholder' => __( 'Enter your placeholder', 'bdevs-elementor' ),

				'default'     => __( 'Placeholder', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->add_control(

			'label_22',

			[

				'label'       => __( 'Text Label 2', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'placeholder' => __( 'Enter your text label', 'bdevs-elementor' ),

				'default'     => __( 'Label 2', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->add_control(

			'placeholder_22',

			[

				'label'       => __( 'Placeholder 2', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'placeholder' => __( 'Enter your placeholder', 'bdevs-elementor' ),

				'default'     => __( 'Placeholder', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->add_control(

			'label_33',

			[

				'label'       => __( 'Text Label 3', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'placeholder' => __( 'Enter your text label', 'bdevs-elementor' ),

				'default'     => __( 'Label 3', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->add_control(

			'placeholder_33',

			[

				'label'       => __( 'Placeholder 3', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'placeholder' => __( 'Enter your placeholder', 'bdevs-elementor' ),

				'default'     => __( 'Placeholder', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->add_control(

			'button2',

			[

				'label'       => __( 'Button', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'placeholder' => __( 'Enter your button', 'bdevs-elementor' ),

				'default'     => __( 'button', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->end_controls_section();



		$this->start_controls_section(

			'section_content_layout',

			[

				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),

			]

		);



		$this->add_responsive_control(

			'align',

			[

				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),

				'type'    => Controls_Manager::CHOOSE,

				'options' => [

					'left' => [

						'title' => esc_html__( 'Left', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-left',

					],

					'center' => [

						'title' => esc_html__( 'Center', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-center',

					],

					'right' => [

						'title' => esc_html__( 'Right', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-right',

					],

					'justify' => [

						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-justify',

					],

				],

				'prefix_class' => 'elementor%s-align-',

				'description'  => 'Use align to match position',

				'default'      => 'left',

			]

		);

		$this->add_control(
			'show_heading',
			[
				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->add_control(
			'show_subheading',
			[
				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		



		$this->end_controls_section();





	}



	public function render() {



		$settings  = $this->get_settings_for_display();

		extract($settings);

		$chose_style = $settings['chose_style'];

		?>

		<?php if( $chose_style == 'search_style_1' ): ?>

		<div class="srch-course-form-2">

		    <div class="container">

		      <form method="get" class="course-form-2" action="<?php echo esc_url( home_url( '/' ) );?>">

		        <div class="row">

		          <div class="col-lg-4 single-input mb-4 mb-lg-0">

		            <label for="name"><?php echo wp_kses_post($settings['label_1']); ?></label>

		            <input type="text" placeholder="<?php echo wp_kses_post($settings['placeholder_1']); ?>" id="name">

		            <i class="far fa-user"></i>

		          </div>

		          <div class="col-lg-4 single-input mb-2 mb-lg-0">

		            <label for="CourseName"><?php echo wp_kses_post($settings['label_2']); ?></label>

		            <input type="hidden" name="post_type" value="course">

                	<input type="search" class="field s" id="s" name="s" value="" placeholder="<?php echo wp_kses_post($settings['placeholder_2']); ?>">

		          </div>

		          <div class="col-lg-4 single-input">

		          	<button type="submit"><i class="fas fa-book"></i><?php echo wp_kses_post($settings['button']); ?></button>

		          </div>

		        </div>

		      </form>

		    </div>

		  </div>

	    <?php elseif( $chose_style == 'search_style_2' ): ?>

	    <section class="find-course-wrapper pt-140 pb-130" style="background-image: url(<?php print esc_url( $settings['background_bg']['url'] ); ?>);">

		    <div class="container">

		      <div class="row">

		        <!-- Course Banner -->

		        <div class="col-lg-5">

		          <div class="find-course-banner mt-10 d-none d-lg-block">

		            <img src="<?php print esc_url( $settings['background_bg1']['url'] ); ?>" alt="Banner">

		          </div>

		        </div>

		        <div class="col-lg-7">

		          <!-- Section Title -->

		          <div class="section-title-4 ml-lg-4 ml-xl-0 pr-30">

		            <?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>

		            <h2><?php echo wp_kses_post($settings['heading']); ?></h2>

		            <?php endif; ?>

		            <?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>

		            <p><?php echo wp_kses_post($settings['subheading']); ?></p>

		            <?php endif; ?>

		          </div>

		          <!-- Course Form -->

		          <form method="get" class="ml-lg-4 ml-xl-0 find-course-form" action="<?php echo esc_url( home_url( '/' ) );?>">

				    <div class="form-row">

				      <div class="form-group col-md-6">

				        <label for="name"><?php echo wp_kses_post($settings['label_11']); ?></label>

				        <input type="text" id="name" placeholder="<?php echo wp_kses_post($settings['placeholder_11']); ?>">

				        <i class="far fa-user"></i>

				      </div>

				      <div class="form-group col-md-6">

				        <label for="advisorName"><?php echo wp_kses_post($settings['label_22']); ?></label>

				        <input type="text" id="advisorName" placeholder="<?php echo wp_kses_post($settings['placeholder_22']); ?>">

				        <i class="far fa-user"></i>

				      </div>

				      <div class="form-group col-md-6">

				        <label for="courseName" class="d-block"><?php echo wp_kses_post($settings['label_33']); ?></label>

				        <input type="hidden" name="post_type" value="course">

						<input type="search" class="field s" id="s" name="s" value="" placeholder="<?php echo wp_kses_post($settings['placeholder_33']); ?>">

				      </div>

				      <div class="form-group col-md-6">

				        <label for="courseList" class="d-block">Online/ Offline Course</label>

				        <select name="courseSelect" class="course-select">

				          <option value="nothing" data-display="Course Name">Online/ Offline</option>

				          <option value="courseOne">Online Course</option>

				          <option value="courseTwo">Offline Course</option>

				        </select>

				      </div>

				      <div class="form-group col-md-6 mb-0">

				      	<button type="submit" class="submit-button"><i class="fas fa-book"></i><?php echo wp_kses_post($settings['button2']); ?></button>

				      </div>

				    </div>

				</form>

		          <!-- Course Form End -->

		        </div>

		      </div>

		    </div>

		  </section>

	    <?php endif; ?>

	<?php

	}



}