<?php

namespace BdevsElementor\Widget;



use Elementor\Controls_Manager;

use Elementor\Group_Control_Typography;

use Elementor\Scheme_Typography;

use Elementor\Group_Control_Border;

use Elementor\Group_Control_Box_Shadow;



/**

 * Bdevs Elementor Widget.

 *

 * Elementor widget that inserts an embbedable content into the page, from any given URL.

 *

 * @since 1.0.0

 */

class BdevsShortcodeForm extends \Elementor\Widget_Base {



	/**

	 * Get widget name.

	 *

	 * Retrieve Bdevs Elementor widget name.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget name.

	 */

	public function get_name() {

		return 'bdevs-shortcode';

	}



	/**

	 * Get widget title.

	 *

	 * Retrieve Bdevs Elementor widget title.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget title.

	 */

	public function get_title() {

		return __( 'Shortcode Form', 'bdevs-elementor' );

	}



	/**

	 * Get widget icon.

	 *

	 * Retrieve Bdevs Shortcode widget icon.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget icon.

	 */

	public function get_icon() {

		return 'eicon-shortcode';

	}



	/**

	 * Get widget categories.

	 *

	 * Retrieve the list of categories the Bdevs Shortcode widget belongs to.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return array Widget categories.

	 */

	public function get_categories() {

		return [ 'bdevs-elementor' ];

	}



	public function get_keywords() {

		return [ 'shortcode' ];

	}



	public function get_script_depends() {

		return [ 'bdevs-elementor'];

	}



	// BDT Position

	protected function element_pack_position() {

	    $position_options = [

	        ''              => esc_html__('Default', 'bdevs-elementor'),

	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,

	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,

	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,

	        'center'        => esc_html__('Center', 'bdevs-elementor') ,

	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,

	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,

	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,

	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,

	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,

	    ];



	    return $position_options;

	}



	protected function _register_controls() {

		$this->start_controls_section(

			'section_content_heading',

			[

				'label' => esc_html__( 'Shortcode Form', 'bdevs-elementor' ),

			]	

		);



		$this->add_control(

			'chose_style',

			[

				'label'     => esc_html__( 'Chose Style', 'bdevs-elementor' ),

				'type'      => Controls_Manager::SELECT,

				'options'   => [

					'shortcode_style_1'  => esc_html__( 'Style 1', 'bdevs-elementor' ),

					'shortcode_style_2' => esc_html__( 'Style 2', 'bdevs-elementor' ),

					'shortcode_style_3' => esc_html__( 'Style 3', 'bdevs-elementor' ),

					'shortcode_style_4' => esc_html__( 'Style 4', 'bdevs-elementor' ),

				],

				'default'   => 'shortcode_style_1',

			]

		);



		$this->add_control(

			'heading',

			[

				'label'       => __( 'Heading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),

				'default'     => __( 'It is heading', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->add_control(

			'subheading',

			[

				'label'       => __( 'Subheading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your subheading', 'bdevs-elementor' ),

				'default'     => __( 'It is subheading', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->add_control(

			'shortcode',

			[

				'label'   => esc_html__( 'Shortcode', 'bdevs-elementor' ),

				'type'    => Controls_Manager::TEXTAREA,

				'dynamic' => [ 'active' => true ],

				'default'		=> __('Contact Shortcode here', 'bdevs-elementor'),

				'description' => esc_html__( 'Add Your shortcode here', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->end_controls_section();



		$this->start_controls_section(

			'section_content_heading_4',

			[

				'label' => esc_html__( 'Style 4', 'bdevs-elementor' ),

				'condition' => [

					'chose_style' => ['shortcode_style_4']

				],

			]

		);



		$this->add_control(

			'background_bg',

			[

				'label'   => esc_html__( 'Background Image', 'bdevs-elementor' ),

				'type'    => Controls_Manager::MEDIA,

				'dynamic' => [ 'active' => true ],

				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),

			]

		);



		$this->add_control(

			'background_bg1',

			[

				'label'   => esc_html__( 'Custom Image', 'bdevs-elementor' ),

				'type'    => Controls_Manager::MEDIA,

				'dynamic' => [ 'active' => true ],

				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),

			]

		);



		$this->end_controls_section();



		/** 

		*	Layout section 

		**/

		$this->start_controls_section(

			'section_content_layout',

			[

				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),

			]

		);



		$this->add_responsive_control(

			'align',

			[

				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),

				'type'    => Controls_Manager::CHOOSE,

				'options' => [

					'left' => [

						'title' => esc_html__( 'Left', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-left',

					],

					'center' => [

						'title' => esc_html__( 'Center', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-center',

					],

					'right' => [

						'title' => esc_html__( 'Right', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-right',

					],

					'justify' => [

						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-justify',

					],

				],

				'prefix_class' => 'elementor%s-align-',

				'description'  => 'Use align to match position',

				'default'      => 'left',

			]

		);



		$this->add_control(

			'show_heading',

			[

				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);	



		$this->add_control(

			'show_subheading',

			[

				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);		



		$this->end_controls_section();



	}



	public function render() {

		$settings  = $this->get_settings_for_display();

		extract($settings);

		$chose_style = $settings['chose_style']; ?>

		<?php if( $chose_style == 'shortcode_style_1' ): ?>

		<section class="news-letter-4-wrapper">

		    <div class="container">

		      <div class="news-letter-content-4 pb-80 pt-80">

		        <div class="row justify-content-center text-center">

		          <div class="col-md-10 col-xl-8">

		          	<?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>

		            <div class="news-letter-title">

		              <h2><?php print wp_kses_post($settings['heading']); ?></h2>

		            </div>

		            <?php endif; ?>

		            <?php print do_shortcode(html_entity_decode( $settings['shortcode'] )); ?>

		          </div>

		        </div>

		      </div>

		    </div>

		</section>

	    <?php elseif( $chose_style == 'shortcode_style_2' ): ?>

	    <section class="contact-form-wrap">

		    <div class="container">

		      <div class="contact-form-area v1">

		        <!-- Section Title -->

		        <div class="row justify-content-center">

		          <div class="col-xl-8 col-lg-10">

		            <div class="section-title text-center">

		            <?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>

		            <h2><?php echo wp_kses_post($settings['heading']); ?></h2>

		            <?php endif; ?>

		            <?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>

		            <p><?php echo wp_kses_post($settings['subheading']); ?></p>

		            <?php endif; ?>

		            </div>

		          </div>

		        </div>

		        <!-- Section Title End -->

		        <div class="row justify-content-center">

		          <div class="col-xl-10 col-md-11">

		            <!-- Contact Form -->

		            <?php print do_shortcode(html_entity_decode( $settings['shortcode'] )); ?>

		            <!-- Contact Form End -->

		          </div>

		        </div>

		      </div>

		    </div>

		</section>

		<?php elseif( $chose_style == 'shortcode_style_3' ): ?>

		<section class="contact-form-wrap pb-130">

		    <div class="container">

		      <div class="contact-form-area v2">

		        <!-- Section Title -->

		        <div class="row justify-content-center">

		          <div class="col-xl-8 col-lg-10">

		            <div class="section-title text-center">

		            <?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>

		            <h2><?php echo wp_kses_post($settings['heading']); ?></h2>

		            <?php endif; ?>

		            <?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>

		            <p><?php echo wp_kses_post($settings['subheading']); ?></p>

		            <?php endif; ?>

		            </div>

		          </div>

		        </div>

		        <!-- Section Title End -->

		        <div class="row justify-content-center">

		          <div class="col-lg-10 col-md-11">

		            <!-- Contact Form -->

		            <?php print do_shortcode(html_entity_decode( $settings['shortcode'] )); ?>

		            <!-- Contact Form End -->

		          </div>

		        </div>

		      </div>

		    </div>

		  </section>

		  <?php elseif( $chose_style == 'shortcode_style_4' ): ?>

		  <section class="become-instructor-wrapper pt-110" style="background-image: url(<?php print esc_url( $settings['background_bg']['url'] ); ?>);">

		    <div class="container">

		      <div class="row justify-content-center justify-content-lg-start">

		        <!-- Instractor Image -->

		        <div class="col-lg-6">

		          <div class="instructor-img d-none d-lg-block">

		            <img src="<?php print esc_url( $settings['background_bg1']['url'] ); ?>" alt="Instructor Iamge">

		          </div>

		        </div>

		        <!-- Instractor Image End -->

		        <!-- Instructor Form Area -->

		        <div class="col-md-8 col-lg-4 offset-lg-2 offset-xl-1 pr-xl-0 pl-lg-0">

		          <div class="instructor-form-wrapper">

		            <!-- Form Title -->

		            <div class="instructor-form-title">

		            <?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>

		            <h1><?php echo wp_kses_post($settings['heading']); ?></h1>

		            <?php endif; ?>

		            <?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>

		            <p><?php echo wp_kses_post($settings['subheading']); ?></p>

		            <?php endif; ?>

		            </div>

		            <?php print do_shortcode(html_entity_decode( $settings['shortcode'] )); ?>

		          </div>

		        </div>

		        <!-- Instructor Form Area End -->

		      </div>

		    </div>

		  </section>

	   	<?php endif; ?>

	<?php

	}



}