<?php

namespace BdevsElementor\Widget;



use Elementor\Controls_Manager;

use Elementor\Group_Control_Typography;

use Elementor\Scheme_Typography;

use Elementor\Group_Control_Border;

use Elementor\Group_Control_Box_Shadow;



/**

 * Bdevs Elementor Widget.

 *

 * Elementor widget that inserts an embbedable content into the page, from any given URL.

 *

 * @since 1.0.0

 */

class BdevsSlider extends \Elementor\Widget_Base {



	/**

	 * Get widget name.

	 *

	 * Retrieve Bdevs Elementor widget name.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget name.

	 */

	public function get_name() {

		return 'bdevs-slider';

	}



	/**

	 * Get widget title.

	 *

	 * Retrieve Bdevs Elementor widget title.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget title.

	 */

	public function get_title() {

		return __( 'Slider', 'bdevs-elementor' );

	}



	/**

	 * Get widget icon.

	 *

	 * Retrieve Bdevs Slider widget icon.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget icon.

	 */

	public function get_icon() {

		return 'eicon-slideshow';

	}



	/**

	 * Get widget categories.

	 *

	 * Retrieve the list of categories the Bdevs Slider widget belongs to.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return array Widget categories.

	 */

	public function get_categories() {

		return [ 'bdevs-elementor' ];

	}



	public function get_keywords() {

		return [ 'slider', 'carousel' ];

	}



	public function get_script_depends() {

		return [ 'bdevs-elementor'];

	}



	// BDT Position

	protected function element_pack_position() {

	    $position_options = [

	        ''              => esc_html__('Default', 'bdevs-elementor'),

	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,

	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,

	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,

	        'center'        => esc_html__('Center', 'bdevs-elementor') ,

	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,

	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,

	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,

	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,

	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,

	    ];



	    return $position_options;

	}



	protected function _register_controls() {

		$this->start_controls_section(

			'section_content_heading',

			[

				'label' => esc_html__( 'Slider', 'bdevs-elementor' ),

			]

		);



		$this->add_control(

			'chose_style',

			[

				'label'     => esc_html__( 'Chose Style', 'bdevs-elementor' ),

				'type'      => Controls_Manager::SELECT,

				'options'   => [

					'slider_style_1'  => esc_html__( 'Slider Style 1', 'bdevs-elementor' ),

					'slider_style_2' => esc_html__( 'Slider Style 2', 'bdevs-elementor' ),

					'slider_style_3' => esc_html__( 'Slider Style 3', 'bdevs-elementor' ),

				],

				'default'   => 'slider_style_1',

			]

		);



		$this->add_control(

			'tabs',

			[

				'label' => esc_html__( 'Slider Items', 'bdevs-elementor' ),

				'type' => Controls_Manager::REPEATER,

				'fields' => [

					[

						'name'    => 'tab_image',

						'label'   => esc_html__( 'Background Image', 'bdevs-elementor' ),

						'type'    => Controls_Manager::MEDIA,

						'dynamic' => [ 'active' => true ],
						'default'     => __( '', 'bdevs-elementor' ),

					],

					[

						'name'       => 'heading',

						'label'      => esc_html__( 'Heading', 'bdevs-elementor' ),

						'type'       => Controls_Manager::TEXTAREA,

						'dynamic'    => [ 'active' => true ],

						'default'    => esc_html__( 'It is heading', 'bdevs-elementor' ),

						'label_block' => true,

					],

					[

						'name'       => 'subheading',

						'label'      => esc_html__( 'Subheading', 'bdevs-elementor' ),

						'type'       => Controls_Manager::TEXTAREA,

						'dynamic'    => [ 'active' => true ],

						'default'    => esc_html__( 'It is subheading', 'bdevs-elementor' ),

						'label_block' => true,

					],

					[

						'name'       => 'content',

						'label'      => esc_html__( 'Content', 'bdevs-elementor' ),

						'type'       => Controls_Manager::TEXTAREA,

						'dynamic'    => [ 'active' => true ],

						'default'    => esc_html__( 'It is content', 'bdevs-elementor' ),

						'label_block' => true,

					],

					[

						'name'       => 'button',

						'label'      => esc_html__( 'Text Button', 'bdevs-elementor' ),

						'type'       => Controls_Manager::TEXT,

						'dynamic'    => [ 'active' => true ],

						'default'    => esc_html__( 'It is button', 'bdevs-elementor' ),

						'label_block' => true,

					],

					[

						'name'       => 'link_button',

						'label'      => esc_html__( 'Link Button', 'bdevs-elementor' ),

						'type'       => Controls_Manager::TEXT,

						'dynamic'    => [ 'active' => true ],

						'default'    => esc_html__( '#', 'bdevs-elementor' ),

						'label_block' => true,

					],

				],

			]

		);



		$this->end_controls_section();



		$this->start_controls_section(

			'section_content_heading_3',

			[

				'label' => esc_html__( 'Slider Style 3', 'bdevs-elementor' ),

				'condition' => [

					'chose_style' => ['slider_style_3']

				],

			]

		);



		$this->add_control(

			'background_bg',

			[

				'label'   => esc_html__( 'Background Image', 'bdevs-elementor' ),

				'type'    => Controls_Manager::MEDIA,

				'dynamic' => [ 'active' => true ],

				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),

			]

		);



		$this->add_control(

			'heading',

			[

				'label'       => __( 'Heading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),

				'default'     => __( 'It is heading', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->add_control(

			'subheading',

			[

				'label'       => __( 'Subheading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your subheading', 'bdevs-elementor' ),

				'default'     => __( 'It is subheading', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->add_control(

			'button',

			[

				'label'       => __( 'Button', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'default'     => __( 'Button', 'bdevs-elementor' ),

				'placeholder' => __( 'Enter your button', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);	



		$this->add_control(

			'link_button',

			[

				'label'       => __( 'Link Button', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'default'     => __( '#', 'bdevs-elementor' ),

				'placeholder' => __( 'Link Button', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);	



		$this->add_control(

			'video',

			[

				'label'       => __( 'Link Video', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your link video', 'bdevs-elementor' ),

				'default'     => __( '#', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->end_controls_section();



		$this->start_controls_section(

			'section_content_layout',

			[

				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),

			]

		);



		$this->add_responsive_control(

			'align',

			[

				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),

				'type'    => Controls_Manager::CHOOSE,

				'options' => [

					'left' => [

						'title' => esc_html__( 'Left', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-left',

					],

					'center' => [

						'title' => esc_html__( 'Center', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-center',

					],

					'right' => [

						'title' => esc_html__( 'Right', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-right',

					],

					'justify' => [

						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-justify',

					],

				],

				'prefix_class' => 'elementor%s-align-',

				'description'  => 'Use align to match position',

				'default'      => 'left',

			]

		);



		$this->add_control(

			'show_heading',

			[

				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);	



		$this->add_control(

			'show_subheading',

			[

				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);	



		$this->add_control(

			'show_content',

			[

				'label'   => esc_html__( 'Show Content', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);		



		$this->add_control(

			'show_button',

			[

				'label'   => esc_html__( 'Show Button', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);



		$this->end_controls_section();





	}



	public function render() {



		$settings  = $this->get_settings_for_display();

		extract($settings);

		$chose_style = $settings['chose_style'];

		?>

		<?php if( $chose_style == 'slider_style_1' ): ?>

		<!-- slider area start -->

		<section class="slider-area">

		    <div class="slider-active">

		    <?php 

                foreach ( $settings['tabs'] as $item ) : 

			?>

		      <!-- single slider -->

		      <div class="single-slider" style="background-image: url(<?php print esc_url($item['tab_image']['url']); ?>);">

		        <div class="container">

		          <div class="row justify-content-center">

		            <div class="col-xl-8 col-lg-10">

		              <div class="slider-content text-center">

		              	<?php if (( '' !== $item['heading'] ) && ( $settings['show_heading'] )) : ?>

		                <h1 data-animation="fadeInDown" data-delay=".8s"><?php print wp_kses_post($item['heading']); ?></h1>

		                <?php endif; ?>

		                <?php if (( '' !== $item['subheading'] ) && ( $settings['show_subheading'] )) : ?>

		                <p data-animation="fadeInLeft" data-delay="2.4s"><?php print wp_kses_post($item['subheading']); ?></p>

		                <?php endif; ?>

		                <?php if (( '' !== $item['button'] ) && ( $settings['show_button'] )) : ?>

		                <a data-animation="fadeInUp" data-delay="4s" href="<?php print wp_kses_post($item['link_button']); ?>" class="slider-btn"><i class="fas fa-book"></i> <?php print wp_kses_post($item['button']); ?></a>

		                <?php endif; ?>

		              </div>

		            </div>

		          </div>

		        </div>

		      </div>

		      <!-- single slider end -->

		    <?php endforeach; ?>

		    </div>

		</section>
		<?php if (is_admin()) { ?>
    <script type="text/javascript">
    

    function mainSlider() {

    var BasicSlider = $('.slider-active');

    BasicSlider.on('init', function (e, slick) {

      var $firstAnimatingElements = $('.single-slider:first-child').find('[data-animation]');

      doAnimations($firstAnimatingElements);

    });

    BasicSlider.on('beforeChange', function (e, slick, currentSlide, nextSlide) {

      var $animatingElements = $('.single-slider[data-slick-index="' + nextSlide + '"]').find(

        '[data-animation]');

      doAnimations($animatingElements);

    });

    BasicSlider.slick({

      dots: false,

      infinite: true,

      autoplay: false,

      fade: true,

      autoplaySpeed: 10000,

      prevArrow: '<button type="button" class="slick-prev"><i class="fas fa-chevron-left"></i></button>',

      nextArrow: '<button type="button" class="slick-next"><i class="fas fa-chevron-right"></i></button>',

      responsive: [{

          breakpoint: 1200,

          settings: {

            arrows: false,

            dots: false,

            infinite: true,

            autoplay: false,

            fade: true,

            autoplaySpeed: 10000

          }

        },

        {

          breakpoint: 768,

          settings: {

            arrows: false,

            dots: false,

            infinite: true,

            autoplay: false,

            fade: true,

            autoplaySpeed: 10000

          }

        }

        // You can unslick at a given breakpoint now by adding:

        // settings: "unslick"

        // instead of a settings object

      ]

    });



    function doAnimations(elements) {

      var animationEndEvents = 'webkitAnimationEnd mozAnimationEnd MSAnimationEnd oanimationend animationend';

      elements.each(function () {

        var $this = $(this);

        var $animationDelay = $this.data('delay');

        var $animationType = 'animated ' + $this.data('animation');

        $this.css({

          'animation-delay': $animationDelay,

          '-webkit-animation-delay': $animationDelay

        });

        $this.addClass($animationType).one(animationEndEvents, function () {

          $this.removeClass($animationType);

        });

      });

    }

  }

  mainSlider();



  
        
          
        
        
    </script>   
    <?php } ?>
		<!-- slider area end -->

	    <?php elseif( $chose_style == 'slider_style_2' ): ?>

	    <!-- Slider Area -->

		  <section class="slider-section-2">

		    <!-- Slider Active -->

		    <div class="slider-active-2">

		      	<?php 

                foreach ( $settings['tabs'] as $item ) : 

				?>

		      <!-- Single Slider -->

		      <div class="single-slider-2" style="background-image: url(<?php print esc_url($item['tab_image']['url']); ?>); min-height: 830px;">

		        <div class="container">

		          <div class="row">

		            <div class="col-md-10 col-lg-8 col-xl-6">

		              <div class="slider-content-2">

		              	<?php if (( '' !== $item['subheading'] ) && ( $settings['show_subheading'] )) : ?>

		                <span data-animation="rotateInDownLeft" data-delay=".8s"><?php print wp_kses_post($item['subheading']); ?></span>

		                <?php endif; ?>

		                <?php if (( '' !== $item['heading'] ) && ( $settings['show_heading'] )) : ?>

		                <h1 data-animation="jackInTheBox" data-delay="2.4s"><?php print wp_kses_post($item['heading']); ?></h1>

		                <?php endif; ?>

		                <?php if (( '' !== $item['content'] ) && ( $settings['show_content'] )) : ?>

		                <p data-animation="jackInTheBox" data-delay="2.6s"><?php print wp_kses_post($item['content']); ?></p>

		                <?php endif; ?>

		                <?php if (( '' !== $item['button'] ) && ( $settings['show_button'] )) : ?>

		                <div class="slider-botton-2">

		                  <a data-animation="fadeInUp" data-delay="4s" href="<?php print wp_kses_post($item['link_button']); ?>" class="default-btn"><i

		                      class="fas fa-book"></i><?php print wp_kses_post($item['button']); ?></a>

		                </div>

		                <?php endif; ?>

		              </div>

		            </div>

		          </div>

		        </div>

		      </div>

		      <!-- Single Slider End -->

		      <?php endforeach; ?>

		    </div>

		  </section>
		  <?php if (is_admin()) { ?>
    <script type="text/javascript">
    

    function mainSlider() {

    var BasicSlider = $('.slider-active');

    BasicSlider.on('init', function (e, slick) {

      var $firstAnimatingElements = $('.single-slider:first-child').find('[data-animation]');

      doAnimations($firstAnimatingElements);

    });

    BasicSlider.on('beforeChange', function (e, slick, currentSlide, nextSlide) {

      var $animatingElements = $('.single-slider[data-slick-index="' + nextSlide + '"]').find(

        '[data-animation]');

      doAnimations($animatingElements);

    });

    BasicSlider.slick({

      dots: false,

      infinite: true,

      autoplay: false,

      fade: true,

      autoplaySpeed: 10000,

      prevArrow: '<button type="button" class="slick-prev"><i class="fas fa-chevron-left"></i></button>',

      nextArrow: '<button type="button" class="slick-next"><i class="fas fa-chevron-right"></i></button>',

      responsive: [{

          breakpoint: 1200,

          settings: {

            arrows: false,

            dots: false,

            infinite: true,

            autoplay: false,

            fade: true,

            autoplaySpeed: 10000

          }

        },

        {

          breakpoint: 768,

          settings: {

            arrows: false,

            dots: false,

            infinite: true,

            autoplay: false,

            fade: true,

            autoplaySpeed: 10000

          }

        }

        // You can unslick at a given breakpoint now by adding:

        // settings: "unslick"

        // instead of a settings object

      ]

    });



    function doAnimations(elements) {

      var animationEndEvents = 'webkitAnimationEnd mozAnimationEnd MSAnimationEnd oanimationend animationend';

      elements.each(function () {

        var $this = $(this);

        var $animationDelay = $this.data('delay');

        var $animationType = 'animated ' + $this.data('animation');

        $this.css({

          'animation-delay': $animationDelay,

          '-webkit-animation-delay': $animationDelay

        });

        $this.addClass($animationType).one(animationEndEvents, function () {

          $this.removeClass($animationType);

        });

      });

    }

  }

  mainSlider();




        
           function mainSliderTwo() {

    var BasicSlider = $('.slider-active-2');

    BasicSlider.on('init', function (e, slick) {

      var $firstAnimatingElements = $('.single-slider-2:first-child').find('[data-animation]');

      doAnimations($firstAnimatingElements);

    });

    BasicSlider.on('beforeChange', function (e, slick, currentSlide, nextSlide) {

      var $animatingElements = $('.single-slider-2[data-slick-index="' + nextSlide + '"]').find(

        '[data-animation]');

      doAnimations($animatingElements);

    });

    BasicSlider.slick({

      arrows: false,

      dots: false,

      infinite: true,

      autoplay: false,

      fade: true,

      autoplaySpeed: 10000,

      responsive: [{

          breakpoint: 1200,

          settings: {

            arrows: false,

            dots: false,

            infinite: true,

            autoplay: false,

            fade: true,

            autoplaySpeed: 10000

          }

        },

        {

          breakpoint: 768,

          settings: {

            arrows: false,

            dots: false,

            infinite: true,

            autoplay: false,

            fade: true,

            autoplaySpeed: 10000

          }

        }

        // You can unslick at a given breakpoint now by adding:

        // settings: "unslick"

        // instead of a settings object

      ]

    });



    function doAnimations(elements) {

      var animationEndEvents = 'webkitAnimationEnd mozAnimationEnd MSAnimationEnd oanimationend animationend';

      elements.each(function () {

        var $this = $(this);

        var $animationDelay = $this.data('delay');

        var $animationType = 'animated ' + $this.data('animation');

        $this.css({

          'animation-delay': $animationDelay,

          '-webkit-animation-delay': $animationDelay

        });

        $this.addClass($animationType).one(animationEndEvents, function () {

          $this.removeClass($animationType);

        });

      });

    }

  }

  mainSliderTwo();
        
        
    </script>   
    <?php } ?>
		  <!-- Slider Area End -->

		  <?php elseif( $chose_style == 'slider_style_3' ): ?>

		  <section class="banner-section-wrap-4" style="background-image: url(<?php print esc_url( $settings['background_bg']['url'] ); ?>); min-height: 720px;">

		    <div class="container">

		      <div class="row">

		        <!-- Banner Contents -->

		        <div class="col-md-9 col-xl-8">

		          <div class="banner-content-4">

		          	<?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>

		            <h1 class="wow rotateInDownLeft" data-wow-delay=".8s"><?php print wp_kses_post($settings['heading']); ?></h1>

		            <?php endif; ?>

		            <?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>

		            <div class="banner-text">

		              <p class="wow jackInTheBox" data-wow-delay="2.4s"><?php print wp_kses_post($settings['subheading']); ?> </p>

		            </div>

		            <?php endif; ?>

		            <?php if (( '' !== $settings['button'] ) && ( $settings['show_button'] )) : ?>

		            <div class="banner-link-btn">

		              <a class="wow fadeInUp" data-wow-delay="4s" data-animation="fadeInUp" data-delay="4s" href="<?php print wp_kses_post($settings['link_button']); ?> " ><i class="fas fa-book"></i><?php print wp_kses_post($settings['button']); ?> </a>

		            </div>

		            <?php endif; ?>

		          </div>

		        </div>

		        <!-- Video Button -->

		        <div class="col-md-2 offset-md-1 offset-xl-2 align-items-center justify-content-end d-none d-md-flex">

		          <div class="banner-video-btn-4 text-center">

		            <a href="<?php print wp_kses_post($settings['video']); ?>"  class="play-btn video-play-popup" ><i class="fa fa-play"></i></a>

		          </div>

		        </div>

		      </div>

		    </div>

		  </section>

	  	<?php endif; ?>

	<?php

	}



}