<?php

namespace BdevsElementor\Widget;



use Elementor\Controls_Manager;

use Elementor\Group_Control_Typography;

use Elementor\Scheme_Typography;

use Elementor\Group_Control_Border;

use Elementor\Group_Control_Box_Shadow;



/**

 * Bdevs Elementor Widget.

 *

 * Elementor widget that inserts an embbedable content into the page, from any given URL.

 *

 * @since 1.0.0

 */

class BdevsTeam extends \Elementor\Widget_Base {



	/**

	 * Get widget name.

	 *

	 * Retrieve Bdevs Elementor widget name.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget name.

	 */

	public function get_name() {

		return 'bdevs-team';

	}



	/**

	 * Get widget title.

	 *

	 * Retrieve Bdevs Elementor widget title.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget title.

	 */

	public function get_title() {

		return __( 'Team', 'bdevs-elementor' );

	}



	/**

	 * Get widget icon.

	 *

	 * Retrieve Bdevs Team widget icon.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget icon.

	 */

	public function get_icon() {

		return 'eicon-favorite';

	}



	/**

	 * Get widget categories.

	 *

	 * Retrieve the list of categories the Bdevs Improve widget belongs to.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return array Widget categories.

	 */

	public function get_categories() {

		return [ 'bdevs-elementor' ];

	}



	public function get_keywords() {

		return [ 'team' ];

	}



	public function get_script_depends() {

		return [ 'bdevs-elementor'];

	}



	// BDT Position

	protected function element_pack_position() {

	    $position_options = [

	        ''              => esc_html__('Default', 'bdevs-elementor'),

	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,

	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,

	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,

	        'center'        => esc_html__('Center', 'bdevs-elementor') ,

	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,

	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,

	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,

	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,

	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,

	    ];



	    return $position_options;

	}



	protected function _register_controls() {

		$this->start_controls_section(

			'section_content_heading',

			[

				'label' => esc_html__( 'Team', 'bdevs-elementor' ),

			]	

		);



		$this->add_control(

			'chose_style',

			[

				'label'     => esc_html__( 'Chose Style', 'bdevs-elementor' ),

				'type'      => Controls_Manager::SELECT,

				'options'   => [

					'team_style_1'  => esc_html__( 'Team Style 1', 'bdevs-elementor' ),

					'team_style_2' => esc_html__( 'Team Style 2', 'bdevs-elementor' ),

					'team_style_3' => esc_html__( 'Team Style 3', 'bdevs-elementor' ),

					'team_style_4' => esc_html__( 'Team Style 4', 'bdevs-elementor' ),

				],

				'default'   => 'team_style_1',

			]

		);



		$this->add_control(

			'post_number',

			[

				'label'     => esc_html__( 'Items Count', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'placeholder' => __( 'Enter your count', 'bdevs-elementor' ),

				'default'   => '6',

				'label_block' => true,

			]

		);



		$this->end_controls_section();



		$this->start_controls_section(

			'section_content_style_2',

			[

				'label' => esc_html__( 'Team Style 2', 'bdevs-elementor' ),

				'condition' => [

					'chose_style' => ['team_style_2']

				],

			]

		);



		$this->add_control(

			'heading',

			[

				'label'       => __( 'Heading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),

				'default'     => __( 'It is heading', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->add_control(

			'subheading',

			[

				'label'       => __( 'Subheading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your subheading', 'bdevs-elementor' ),

				'default'     => __( 'It is subheading', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->end_controls_section();


		$this->start_controls_section(

			'section_content_style_3',

			[

				'label' => esc_html__( 'Team Style 3', 'bdevs-elementor' ),

				'condition' => [

					'chose_style' => ['team_style_3']

				],

			]

		);



		$this->add_control(

			'heading3',

			[

				'label'       => __( 'Heading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),

				'default'     => __( 'It is heading', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->add_control(

			'subheading3',

			[

				'label'       => __( 'Subheading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your subheading', 'bdevs-elementor' ),

				'default'     => __( 'It is subheading', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->end_controls_section();



		$this->start_controls_section(

			'section_content_style_4',

			[

				'label' => esc_html__( 'Team Style 4', 'bdevs-elementor' ),

				'condition' => [

					'chose_style' => ['team_style_4']

				],

			]

		);



		$this->add_control(

			'heading4',

			[

				'label'       => __( 'Heading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),

				'default'     => __( 'It is heading', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->add_control(

			'subheading4',

			[

				'label'       => __( 'Subheading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your subheading', 'bdevs-elementor' ),

				'default'     => __( 'It is subheading', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->end_controls_section();



		/** 

		*	Layout section 

		**/

		$this->start_controls_section(

			'section_content_layout',

			[

				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),

			]

		);



		$this->add_responsive_control(

			'align',

			[

				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),

				'type'    => Controls_Manager::CHOOSE,

				'options' => [

					'left' => [

						'title' => esc_html__( 'Left', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-left',

					],

					'center' => [

						'title' => esc_html__( 'Center', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-center',

					],

					'right' => [

						'title' => esc_html__( 'Right', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-right',

					],

					'justify' => [

						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-justify',

					],

				],

				'prefix_class' => 'elementor%s-align-',

				'description'  => 'Use align to match position',

				'default'      => 'left',

			]

		);	



		$this->add_control(

			'show_heading',

			[

				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);



		$this->add_control(

			'show_subheading',

			[

				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);



		$this->end_controls_section();



	}



	public function render() {

		$settings  = $this->get_settings_for_display();

		$chose_style = $settings['chose_style'];

		$post_number = $settings['post_number'];



	    $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'instructor',  'orderby' => 'ID', 'order' => 'ASC'));

	   

	    //other style

	    $args = array('posts_per_page' => $post_number,'post_type' => 'instructor',  'orderby' => 'ID', 'order' => 'ASC');

		extract($settings); ?>

		<?php if( $chose_style == 'team_style_1' ): ?>

		<section class="instructor-area pt-130 pb-50">

		    <div class="container">

		      <div class="row">

		      	<?php

	                $args = new \WP_Query(array(   

	                            'post_type' => 'instructor', 

	                        ));  

	                        while ($wp_query -> have_posts()) : $wp_query -> the_post(); 

	            ?>

	            <?php $team_info = get_post_meta(get_the_ID(),'_cmb_team_info', true); ?>

				<?php $team_facebook = get_post_meta(get_the_ID(),'_cmb_team_facebook', true); ?>

				<?php $team_twitter = get_post_meta(get_the_ID(),'_cmb_team_twitter', true); ?>

				<?php $team_behance = get_post_meta(get_the_ID(),'_cmb_team_behance', true); ?>

				<?php $team_youtube = get_post_meta(get_the_ID(),'_cmb_team_youtube', true); ?>

				<?php $team_dribbble = get_post_meta(get_the_ID(),'_cmb_team_dribbble', true); ?>

		        <!-- Single Team -->

		        <div class="col-lg-4">

		          <div class="single-team-4 text-center inst-page mb-80">

		            <div class="team-img-4">

		              <img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" class="w-100" alt="Team member">

		            </div>

		            <div class="team-content-4">

		              <div class="team-text">

		                <a href="<?php the_permalink(); ?>">

		                  <h4><?php the_title(); ?></h4>

		                </a>

		                <p><?php echo esc_attr($team_info); ?></p>

		              </div>

		              <div class="social-link-4">

	                	  <?php if($team_facebook !='') { ?>

			              <a href="<?php echo esc_url($team_facebook); ?>"><i class="fab fa-facebook-f"></i></a>

			              <?php } ?>

			              <?php if($team_twitter !='') { ?>

			              <a href="<?php echo esc_url($team_twitter); ?>"><i class="fab fa-twitter"></i></a>

			              <?php } ?>

			              <?php if($team_behance !='') { ?>

			              <a href="<?php echo esc_url($team_behance); ?>"><i class="fab fa-behance"></i></a>

			              <?php } ?>

			              <?php if($team_youtube !='') { ?>

			              <a href="<?php echo esc_url($team_youtube); ?>"><i class="fab fa-youtube"></i></a>

			              <?php } ?>

			              <?php if($team_dribbble !='') { ?>

			              <a href="<?php echo esc_url($team_dribbble); ?>"><i class="fab fa-dribbble"></i></a>

			              <?php } ?>

		              </div>

		            </div>

		          </div>

		        </div>

		        <!-- Single Team End -->

		        <?php   

			        endwhile; 

			        wp_reset_postdata();

			    ?>

		      </div>

		    </div>

		</section>

	    <?php elseif( $chose_style == 'team_style_2' ): ?>

	    <section class="team-area home-2 pt-130 pb-130">

		    <div class="container">

		      <div class="row justify-content-center">

		        <div class="col-md-8 col-lg-7 col-xl-7">

		          <!-- Section Title -->

		          <div class="section-title white-text text-center">

		            <?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>

		            <h2><?php echo wp_kses_post($settings['heading']); ?></h2>

		            <?php endif; ?>

		            <?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>

		            <p><?php echo wp_kses_post($settings['subheading']); ?></p>

		            <?php endif; ?>

		          </div>

		        </div>

		      </div>



		      <div class="latest-event-h2">

		      	<?php

	                $args = new \WP_Query(array(   

	                            'post_type' => 'instructor', 

	                        ));  

	                        while ($wp_query -> have_posts()) : $wp_query -> the_post(); 

	            ?>

	            <?php $team_info = get_post_meta(get_the_ID(),'_cmb_team_info', true); ?>

				<?php $team_facebook = get_post_meta(get_the_ID(),'_cmb_team_facebook', true); ?>

				<?php $team_twitter = get_post_meta(get_the_ID(),'_cmb_team_twitter', true); ?>

				<?php $team_behance = get_post_meta(get_the_ID(),'_cmb_team_behance', true); ?>

				<?php $team_youtube = get_post_meta(get_the_ID(),'_cmb_team_youtube', true); ?>

				<?php $team_dribbble = get_post_meta(get_the_ID(),'_cmb_team_dribbble', true); ?>

		        <!-- Single Team -->

		        <div class="col-xl-4">

		          <div class="single-team-4 text-center">

		            <div class="team-img-4">

		              <img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" class="w-100" alt="Team member">

		            </div>

		            <div class="team-content-4">

		              <div class="team-text">

		                <a href="<?php the_permalink(); ?>">

		                  <h4><?php the_title(); ?></h4>

		                </a>

		                <p><?php echo esc_attr($team_info); ?></p>

		              </div>

		              <div class="social-link-4">

		                  <?php if($team_facebook !='') { ?>

			              <a href="<?php echo esc_url($team_facebook); ?>"><i class="fab fa-facebook-f"></i></a>

			              <?php } ?>

			              <?php if($team_twitter !='') { ?>

			              <a href="<?php echo esc_url($team_twitter); ?>"><i class="fab fa-twitter"></i></a>

			              <?php } ?>

			              <?php if($team_behance !='') { ?>

			              <a href="<?php echo esc_url($team_behance); ?>"><i class="fab fa-behance"></i></a>

			              <?php } ?>

			              <?php if($team_youtube !='') { ?>

			              <a href="<?php echo esc_url($team_youtube); ?>"><i class="fab fa-youtube"></i></a>

			              <?php } ?>

			              <?php if($team_dribbble !='') { ?>

			              <a href="<?php echo esc_url($team_dribbble); ?>"><i class="fab fa-dribbble"></i></a>

			              <?php } ?>

		              </div>

		            </div>

		          </div>

		        </div>

		        <!-- Single Team End -->

		        <?php   

			        endwhile; 

			        wp_reset_postdata();

			    ?>

		      </div>

		    </div>

		  </section>

		  <?php elseif( $chose_style == 'team_style_3' ): ?>

		  <section class="team-slider-4-wrap pt-130 pl-55 pr-55">

		    <div class="container-fluid">

		    	<div class="row justify-content-center">

			        <div class="col-md-8 col-lg-7 col-xl-7">

			          <!-- Section Title -->

			          <div class="section-title white-text text-center">

			            <?php if (( '' !== $settings['heading3'] ) && ( $settings['show_heading'] )) : ?>

			            <h2><?php echo wp_kses_post($settings['heading3']); ?></h2>

			            <?php endif; ?>

			            <?php if (( '' !== $settings['subheading3'] ) && ( $settings['show_subheading'] )) : ?>

			            <p><?php echo wp_kses_post($settings['subheading3']); ?></p>

			            <?php endif; ?>

			          </div>

			        </div>

		      </div>

		      <!-- Slider Wrapper -->

		      <div class="team-slider-4-active custom-row">

		      	<?php

	                $args = new \WP_Query(array(   

	                            'post_type' => 'instructor', 

	                        ));  

	                        while ($wp_query -> have_posts()) : $wp_query -> the_post(); 

	            ?>

	            <?php $team_info = get_post_meta(get_the_ID(),'_cmb_team_info', true); ?>

				<?php $team_facebook = get_post_meta(get_the_ID(),'_cmb_team_facebook', true); ?>

				<?php $team_twitter = get_post_meta(get_the_ID(),'_cmb_team_twitter', true); ?>

				<?php $team_behance = get_post_meta(get_the_ID(),'_cmb_team_behance', true); ?>

				<?php $team_youtube = get_post_meta(get_the_ID(),'_cmb_team_youtube', true); ?>

				<?php $team_dribbble = get_post_meta(get_the_ID(),'_cmb_team_dribbble', true); ?>

		        <!-- Single Team -->

		        <div class="col-xl-3">

		          <div class="single-team-4 text-center">

		            <div class="team-img-4">

		              <img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" class="w-100" alt="Team member">

		            </div>

		            <div class="team-content-4">

		              <div class="team-text">

		                <a href="<?php the_permalink(); ?>">

		                  <h4><?php the_title(); ?></h4>

		                </a>

		                <p><?php echo esc_attr($team_info); ?></p>

		              </div>

		              <div class="social-link-4">

		                  <?php if($team_facebook !='') { ?>

			              <a href="<?php echo esc_url($team_facebook); ?>"><i class="fab fa-facebook-f"></i></a>

			              <?php } ?>

			              <?php if($team_twitter !='') { ?>

			              <a href="<?php echo esc_url($team_twitter); ?>"><i class="fab fa-twitter"></i></a>

			              <?php } ?>

			              <?php if($team_behance !='') { ?>

			              <a href="<?php echo esc_url($team_behance); ?>"><i class="fab fa-behance"></i></a>

			              <?php } ?>

			              <?php if($team_youtube !='') { ?>

			              <a href="<?php echo esc_url($team_youtube); ?>"><i class="fab fa-youtube"></i></a>

			              <?php } ?>

			              <?php if($team_dribbble !='') { ?>

			              <a href="<?php echo esc_url($team_dribbble); ?>"><i class="fab fa-dribbble"></i></a>

			              <?php } ?>

		              </div>

		            </div>

		          </div>

		        </div>

		        <!-- Single Team End -->

		        <?php   

			        endwhile; 

			        wp_reset_postdata();

			    ?>

		      </div>

		      <!-- Slider Wrapper End -->

		    </div>

		  </section>

		  <?php elseif( $chose_style == 'team_style_4' ): ?>

		  <section class="team-area about-us pt-130 pb-95">

		    <div class="container">

		      <div class="row justify-content-center">

		        <div class="col-md-8 col-lg-7 col-xl-7">

		          <!-- Section Title -->

		          <div class="section-title text-center">

		            <?php if (( '' !== $settings['heading4'] ) && ( $settings['show_heading'] )) : ?>

		            <h2><?php echo wp_kses_post($settings['heading4']); ?></h2>

		            <?php endif; ?>

		            <?php if (( '' !== $settings['subheading4'] ) && ( $settings['show_subheading'] )) : ?>

		            <p><?php echo wp_kses_post($settings['subheading4']); ?></p>

		            <?php endif; ?>

		          </div>

		        </div>

		      </div>



		      <div class="latest-event-h2">

		      	<?php

	                $args = new \WP_Query(array(   

	                            'post_type' => 'instructor', 

	                        ));  

	                        while ($wp_query -> have_posts()) : $wp_query -> the_post(); 

	            ?>

	            <?php $team_info = get_post_meta(get_the_ID(),'_cmb_team_info', true); ?>

				<?php $team_facebook = get_post_meta(get_the_ID(),'_cmb_team_facebook', true); ?>

				<?php $team_twitter = get_post_meta(get_the_ID(),'_cmb_team_twitter', true); ?>

				<?php $team_behance = get_post_meta(get_the_ID(),'_cmb_team_behance', true); ?>

				<?php $team_youtube = get_post_meta(get_the_ID(),'_cmb_team_youtube', true); ?>

				<?php $team_dribbble = get_post_meta(get_the_ID(),'_cmb_team_dribbble', true); ?>

		        <!-- Single Team -->

		        <div class="col-xl-4">

		          <div class="single-team-4 text-center">

		            <div class="team-img-4">

		              <img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" class="w-100" alt="Team member">

		            </div>

		            <div class="team-content-4">

		              <div class="team-icon-4">

		                <a href="<?php the_permalink(); ?>"><i class="fas fa-plus"></i></a>

		              </div>

		              <div class="team-text">

		                <a href="<?php the_permalink(); ?>">

		                  <h4><?php the_title(); ?></h4>

		                </a>

		                <p><?php echo esc_attr($team_info); ?></p>

		              </div>

		              <div class="social-link-4">

		                  <?php if($team_facebook !='') { ?>

			              <a href="<?php echo esc_url($team_facebook); ?>"><i class="fab fa-facebook-f"></i></a>

			              <?php } ?>

			              <?php if($team_twitter !='') { ?>

			              <a href="<?php echo esc_url($team_twitter); ?>"><i class="fab fa-twitter"></i></a>

			              <?php } ?>

			              <?php if($team_behance !='') { ?>

			              <a href="<?php echo esc_url($team_behance); ?>"><i class="fab fa-behance"></i></a>

			              <?php } ?>

			              <?php if($team_youtube !='') { ?>

			              <a href="<?php echo esc_url($team_youtube); ?>"><i class="fab fa-youtube"></i></a>

			              <?php } ?>

			              <?php if($team_dribbble !='') { ?>

			              <a href="<?php echo esc_url($team_dribbble); ?>"><i class="fab fa-dribbble"></i></a>

			              <?php } ?>

		              </div>

		            </div>

		          </div>

		        </div>

		        <!-- Single Team End -->

		        <?php   

			        endwhile; 

			        wp_reset_postdata();

			    ?>

		      </div>

		    </div>

		  </section>

	    <?php endif; ?>
<?php if (is_admin()) { ?>
    <script type="text/javascript">
    
        
           $('.team-slider-4-active').slick({

    arrows: false,

    dots: false,

    infinite: true,

    autoplay: false,

    fade: false,

    prevArrow: '<button type="button" class="slick-prev"><i class="fas fa-chevron-left"></i></button>',

    nextArrow: '<button type="button" class="slick-next"><i class="fas fa-chevron-right"></i></button>',

    speed: 300,

    slidesToShow: 5,

    slidesToScroll: 1,

    responsive: [{

        breakpoint: 1500,

        settings: {

          arrows: false,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 4,

          slidesToScroll: 1

        }

      }, {

        breakpoint: 1199.98,

        settings: {

          arrows: false,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 3,

          slidesToScroll: 1

        }

      }, {

        breakpoint: 992,

        settings: {

          arrows: false,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 2,

          slidesToScroll: 1

        }

      }, {

        breakpoint: 768,

        settings: {

          arrows: false,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 1,

          slidesToScroll: 1

        }

      }

      // You can unslick at a given breakpoint now by adding:

      // settings: "unslick"

      // instead of a settings object

    ]

  });

  // Latest event slider

  $('.latest-event-h2').slick({

    dots: false,

    infinite: true,

    autoplay: false,

    arrows: false,

    speed: 300,

    slidesToShow: 3,

    slidesToScroll: 1,

    responsive: [{

        breakpoint: 1500,

        settings: {

          arrows: true,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 3,

          slidesToScroll: 1

        }

      }, {

        breakpoint: 1350,

        settings: {

          arrows: false,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 3,

          slidesToScroll: 1

        }

      }, {

        breakpoint: 992,

        settings: {

          arrows: false,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 2,

          slidesToScroll: 1

        }

      }, {

        breakpoint: 768,

        settings: {

          arrows: false,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 1,

          slidesToScroll: 1

        }

      }

      // You can unslick at a given breakpoint now by adding:

      // settings: "unslick"

      // instead of a settings object

    ]

  });



  //   Latest Events Slider

  $('.latest-events-4').slick({

    dots: false,

    infinite: true,

    autoplay: false,

    fade: false,

    prevArrow: '<button type="button" class="slick-prev"><i class="fas fa-chevron-left"></i></button>',

    nextArrow: '<button type="button" class="slick-next"><i class="fas fa-chevron-right"></i></button>',

    speed: 300,

    slidesToShow: 3,

    slidesToScroll: 1,

    responsive: [{

        breakpoint: 1500,

        settings: {

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 3,

          slidesToScroll: 1

        }

      }, {

        breakpoint: 992,

        settings: {

          arrows: false,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 2,

          slidesToScroll: 1

        }

      }, {

        breakpoint: 768,

        settings: {

          arrows: false,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 1,

          slidesToScroll: 1

        }

      }

      // You can unslick at a given breakpoint now by adding:

      // settings: "unslick"

      // instead of a settings object

    ]

  });
        
        
    </script>   
    <?php } ?>
	<?php

	}



}