<?php

namespace BdevsElementor\Widget;



use Elementor\Controls_Manager;

use Elementor\Group_Control_Typography;

use Elementor\Scheme_Typography;

use Elementor\Group_Control_Border;

use Elementor\Group_Control_Box_Shadow;



/**

 * Bdevs Elementor Widget.

 *

 * Elementor widget that inserts an embbedable content into the page, from any given URL.

 *

 * @since 1.0.0

 */

class BdevsTestimonial extends \Elementor\Widget_Base {



	/**

	 * Get widget name.

	 *

	 * Retrieve Bdevs Elementor widget name.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget name.

	 */

	public function get_name() {

		return 'bdevs-testimonial';

	}



	/**

	 * Get widget title.

	 *

	 * Retrieve Bdevs Elementor widget title.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget title.

	 */

	public function get_title() {

		return __( 'Testimonial', 'bdevs-elementor' );

	}



	/**

	 * Get widget icon.

	 *

	 * Retrieve Bdevs Testimonial widget icon.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget icon.

	 */

	public function get_icon() {

		return 'eicon-testimonial';

	}



	/**

	 * Get widget categories.

	 *

	 * Retrieve the list of categories the Bdevs Testimonial widget belongs to.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return array Widget categories.

	 */

	public function get_categories() {

		return [ 'bdevs-elementor' ];

	}



	public function get_keywords() {

		return [ 'testimonial', 'carousel' ];

	}



	public function get_script_depends() {

		return [ 'bdevs-elementor'];

	}



	// BDT Position

	protected function element_pack_position() {

	    $position_options = [

	        ''              => esc_html__('Default', 'bdevs-elementor'),

	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,

	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,

	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,

	        'center'        => esc_html__('Center', 'bdevs-elementor') ,

	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,

	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,

	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,

	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,

	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,

	    ];



	    return $position_options;

	}



	protected function _register_controls() {

		$this->start_controls_section(

			'section_content_heading',

			[

				'label' => esc_html__( 'Testimonial', 'bdevs-elementor' ),

			]

		);



		$this->add_control(

			'chose_style',

			[

				'label'     => esc_html__( 'Chose Style', 'bdevs-elementor' ),

				'type'      => Controls_Manager::SELECT,

				'options'   => [

					'testimonial_style_1'  => esc_html__( 'Testimonial Style 1', 'bdevs-elementor' ),

					'testimonial_style_2' => esc_html__( 'Testimonial Style 2', 'bdevs-elementor' ),

				],

				'default'   => 'testimonial_style_1',

			]

		);



		$this->add_control(

			'background_bg',

			[

				'label'   => esc_html__( 'Background Image', 'bdevs-elementor' ),

				'type'    => Controls_Manager::MEDIA,

				'dynamic' => [ 'active' => true ],

				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),

			]

		);



		$this->add_control(

			'heading',

			[

				'label'       => __( 'Heading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),

				'default'     => __( 'It is heading', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->add_control(

			'subheading',

			[

				'label'       => __( 'Subheading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your subheading', 'bdevs-elementor' ),

				'default'     => __( 'It is subheading', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->end_controls_section();



		$this->start_controls_section(

			'section_content_testimonial',

			[

				'label' => esc_html__( 'Testimonial', 'bdevs-elementor' ),

			]

		);



		$this->add_control(

			'tabs',

			[

				'label' => esc_html__( 'Testimonial Items', 'bdevs-elementor' ),

				'type' => Controls_Manager::REPEATER,

				'fields' => [

					[

						'name'    => 'tab_image',

						'label'   => esc_html__( 'Image', 'bdevs-elementor' ),

						'type'    => Controls_Manager::MEDIA,

						'dynamic' => [ 'active' => true ],
						'default'     => __( '', 'bdevs-elementor' ),

					],

					[

						'name'       => 'quote',

						'label'      => esc_html__( 'Quote', 'bdevs-elementor' ),

						'type'       => Controls_Manager::TEXTAREA,

						'dynamic'    => [ 'active' => true ],

						'default'    => esc_html__( 'Quote', 'bdevs-elementor' ),

						'label_block' => true,

					],

					[

						'name'       => 'name',

						'label'      => esc_html__( 'Name', 'bdevs-elementor' ),

						'type'       => Controls_Manager::TEXT,

						'dynamic'    => [ 'active' => true ],

						'default'    => esc_html__( 'Name', 'bdevs-elementor' ),

						'label_block' => true,

					],

					[

						'name'       => 'info',

						'label'      => esc_html__( 'Information', 'bdevs-elementor' ),

						'type'       => Controls_Manager::TEXT,

						'dynamic'    => [ 'active' => true ],

						'default'    => esc_html__( 'Information', 'bdevs-elementor' ),

						'label_block' => true,

					],

				],

			]

		);



		$this->end_controls_section();



		$this->start_controls_section(

			'section_content_layout',

			[

				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),

			]

		);



		$this->add_responsive_control(

			'align',

			[

				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),

				'type'    => Controls_Manager::CHOOSE,

				'options' => [

					'left' => [

						'title' => esc_html__( 'Left', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-left',

					],

					'center' => [

						'title' => esc_html__( 'Center', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-center',

					],

					'right' => [

						'title' => esc_html__( 'Right', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-right',

					],

					'justify' => [

						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-justify',

					],

				],

				'prefix_class' => 'elementor%s-align-',

				'description'  => 'Use align to match position',

				'default'      => 'left',

			]

		);



		$this->add_control(

			'show_heading',

			[

				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);



		$this->add_control(

			'show_subheading',

			[

				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);



		$this->end_controls_section();





	}



	public function render() {



		$settings  = $this->get_settings_for_display();

		$chose_style = $settings['chose_style'];

		?>

		<?php if( $chose_style == 'testimonial_style_1' ): ?>

		<!-- testimonial area -->

		  <section class="testimonial-area pt-130 pb-130" style="background-image: url(<?php print esc_url( $settings['background_bg']['url'] ); ?>);">

		    <div class="container">

		      <!-- section-title -->

		      <div class="row justify-content-center">

		        <div class="col-xl-8">

		          <div class="section-title white-text text-center">

		          	<?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>

		            <h2><?php echo wp_kses_post($settings['heading']); ?></h2>

		            <?php endif; ?>

		            <?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>

		            <p><?php echo wp_kses_post($settings['subheading']); ?></p>

		            <?php endif; ?>

		          </div>

		        </div>

		      </div>

		      <!-- testimonial wrapper -->

		      <div class="testimonial-silder custom-row">

		      	<?php 

                    foreach ( $settings['tabs'] as $item ) : 

				?>

		        <!-- single testimonial -->

		        <div class="col-xl-4">

		          <div class="single-testimonial">

		            <div class="testimonial-author d-flex justify-content-between align-items-end">

		              <img src="<?php print esc_url($item['tab_image']['url']); ?>" alt="Author">

		              <span><i class="fas fa-quote-right"></i></span>

		            </div>

		            <div class="testimonial-text">

		              <p><?php print wp_kses_post($item['quote']); ?> </p>

		            </div>

		            <div class="testimonial-footer d-flex justify-content-between">

		              <div class="author-details">

		                <h5><a href="#"><?php print wp_kses_post($item['name']); ?></a></h5>

		                <p><?php print wp_kses_post($item['info']); ?></p>

		              </div>

		            </div>

		          </div>

		        </div>

		        <!-- single testimonial end -->

		        <?php endforeach; ?>

		      </div>

		    </div>

		  </section>

		  <!-- testimonial area end -->

	    <?php elseif( $chose_style == 'testimonial_style_2' ): ?>

	    <section class="kid-store-area pt-130 pb-130" style="background-image: url(<?php print esc_url( $settings['background_bg']['url'] ); ?>);">

	        <div class="home-3-testimonial">

	            <div class="container">

	                <div class="row justify-content-center">

	                    <div class="col-xl-8">

	                        <div class="testimonial3-slider">

	                        	<?php 

				                    foreach ( $settings['tabs'] as $item ) : 

								?>

	                            <!-- single testimonail -->

	                            <div class="single-testimonial-3 text-center">

	                                <div class="testimonial3-img">

	                                    <a href="#"> <img src="<?php print esc_url($item['tab_image']['url']); ?>" alt=""></a>

	                                </div>

	                                <div class="testimonial3-text baloo-title">

	                                    <h4><?php print wp_kses_post($item['quote']); ?></h4>

	                                </div>

	                                <div class="testimonial3-author baloo-title">

	                                    <h5><a href="#"><?php print wp_kses_post($item['name']); ?></a></h5>

	                                    <p><?php print wp_kses_post($item['info']); ?></p>

	                                </div>

	                            </div>

	                            <?php endforeach; ?>

	                        </div>

	                    </div>

	                </div>

	            </div>

	        </div>

	    </section>

		<?php endif; ?>



<?php if (is_admin()) { ?>
    <script type="text/javascript">
    
        
           $('.testimonial-silder').slick({

    dots: false,

    arrows: true,

    prevArrow: '<button type="button" class="slick-prev"><i class="fas fa-chevron-left"></i></button>',

    nextArrow: '<button type="button" class="slick-next"><i class="fas fa-chevron-right"></i></button>',

    infinite: true,

    speed: 300,

    slidesToShow: 3,

    slidesToScroll: 1,

    responsive: [{

        breakpoint: 1500,

        settings: {

          arrows: false,

          slidesToShow: 3,

          slidesToScroll: 1,

          infinite: true,

        }

      },

      {

        breakpoint: 992,

        settings: {

          arrows: false,

          slidesToShow: 2,

          slidesToScroll: 1

        }

      },

      {

        breakpoint: 768,

        settings: {

          arrows: false,

          slidesToShow: 1,

          slidesToScroll: 1

        }

      }

      // You can unslick at a given breakpoint now by adding:

      // settings: "unslick"

      // instead of a settings object

    ]

  });
        
        

        $('.testimonial3-slider').slick({

    arrows: true,

    dots: false,

    infinite: true,

    autoplay: false,

    prevArrow: '<button type="button" class="slick-prev"><i class="fas fa-chevron-left"></i></button>',

    nextArrow: '<button type="button" class="slick-next"><i class="fas fa-chevron-right"></i></button>',

    speed: 300,

    slidesToShow: 1,

    slidesToScroll: 1,

    responsive: [{

        breakpoint: 1500,

        settings: {

          arrows: false,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 1,

          slidesToScroll: 1

        }

      }, {

        breakpoint: 1199.98,

        settings: {

          arrows: false,

          dots: false,

          infinite: true,

          autoplay: false,

          fade: false,

          speed: 300,

          slidesToShow: 1,

          slidesToScroll: 1

        }

      }

      // You can unslick at a given breakpoint now by adding:

      // settings: "unslick"

      // instead of a settings object

    ]

  });
    </script>   
    <?php } ?>
		<?php

		}



}